Class: Merge::Accounting::Account
- Inherits:
-
Object
- Object
- Merge::Accounting::Account
- Defined in:
- lib/merge_ruby_client/accounting/types/account.rb
Overview
The Account Object
Description
An Account represents a category in a company’s ledger in which a financial
transaction is recorded against. The aggregation of each Account object is
often referred to as the Chart of Accounts.
An Account can be classified into one of the following categories, determined
through the classification field:
- Asset: Accounts Receivable and Bank Accounts
- Liability: Accounts Payable and Credit Card Accounts
- Equity: Treasury Accounts and Retained Earnings
- Revenue: Income and Other Income
- Expense: Cost of Goods Sold and Office Expenses
Usage Example
Fetch from the LIST Accounts endpoint and view a company's accounts.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account_number ⇒ String
readonly
The account's number.
-
#account_type ⇒ Merge::Accounting::AccountAccountTypeEnum
readonly
Normalized account type- which is a narrower and more specific grouping within the account's classification.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#classification ⇒ Merge::Accounting::ClassificationEnum
readonly
The account's broadest grouping.
-
#company ⇒ String
readonly
The company the account belongs to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The account's currency.
-
#current_balance ⇒ Float
readonly
The account's current balance.
-
#description ⇒ String
readonly
The account's description.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#name ⇒ String
readonly
The account's name.
-
#parent_account ⇒ String
readonly
ID of the parent account.
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#status ⇒ Merge::Accounting::AccountStatusEnum
readonly
The account's status.
-
#type ⇒ String
readonly
The account's type is a narrower and more specific grouping within the account's classification.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::Account
Deserialize a JSON object to an instance of Account.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, description: OMIT, classification: OMIT, type: OMIT, account_type: OMIT, status: OMIT, current_balance: OMIT, currency: OMIT, account_number: OMIT, parent_account: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::Account constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of Account to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, description: OMIT, classification: OMIT, type: OMIT, account_type: OMIT, status: OMIT, current_balance: OMIT, currency: OMIT, account_number: OMIT, parent_account: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::Account
757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 757 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, description: OMIT, classification: OMIT, type: OMIT, account_type: OMIT, status: OMIT, current_balance: OMIT, currency: OMIT, account_number: OMIT, parent_account: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @name = name if name != OMIT @description = description if description != OMIT @classification = classification if classification != OMIT @type = type if type != OMIT @account_type = account_type if account_type != OMIT @status = status if status != OMIT @current_balance = current_balance if current_balance != OMIT @currency = currency if currency != OMIT @account_number = account_number if account_number != OMIT @parent_account = parent_account if parent_account != OMIT @company = company if company != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "name": name, "description": description, "classification": classification, "type": type, "account_type": account_type, "status": status, "current_balance": current_balance, "currency": currency, "account_number": account_number, "parent_account": parent_account, "company": company, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_data": remote_data }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account_number ⇒ String (readonly)
Returns The account's number.
383 384 385 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 383 def account_number @account_number end |
#account_type ⇒ Merge::Accounting::AccountAccountTypeEnum (readonly)
Returns Normalized account type- which is a narrower and more specific grouping within the account's classification.
BANK- BANKCREDIT_CARD- CREDIT_CARDACCOUNTS_PAYABLE- ACCOUNTS_PAYABLEACCOUNTS_RECEIVABLE- ACCOUNTS_RECEIVABLEFIXED_ASSET- FIXED_ASSETOTHER_ASSET- OTHER_ASSETOTHER_CURRENT_ASSET- OTHER_CURRENT_ASSETOTHER_EXPENSE- OTHER_EXPENSEOTHER_INCOME- OTHER_INCOMECOST_OF_GOODS_SOLD- COST_OF_GOODS_SOLDOTHER_CURRENT_LIABILITY- OTHER_CURRENT_LIABILITYLONG_TERM_LIABILITY- LONG_TERM_LIABILITYNON_POSTING- NON_POSTING.
66 67 68 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 66 def account_type @account_type end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
398 399 400 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 398 def additional_properties @additional_properties end |
#classification ⇒ Merge::Accounting::ClassificationEnum (readonly)
Returns The account's broadest grouping.
ASSET- ASSETEQUITY- EQUITYEXPENSE- EXPENSELIABILITY- LIABILITYREVENUE- REVENUE.
47 48 49 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 47 def classification @classification end |
#company ⇒ String (readonly)
Returns The company the account belongs to.
387 388 389 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 387 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 34 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The account's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
381 382 383 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 381 def currency @currency end |
#current_balance ⇒ Float (readonly)
Returns The account's current balance.
73 74 75 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 73 def current_balance @current_balance end |
#description ⇒ String (readonly)
Returns The account's description.
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 40 def description @description end |
#field_mappings ⇒ Hash{String => Object} (readonly)
394 395 396 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 394 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 30 def id @id end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 36 def modified_at @modified_at end |
#name ⇒ String (readonly)
Returns The account's name.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 38 def name @name end |
#parent_account ⇒ String (readonly)
Returns ID of the parent account.
385 386 387 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 385 def parent_account @parent_account end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
396 397 398 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 396 def remote_data @remote_data end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 32 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
392 393 394 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 392 def remote_was_deleted @remote_was_deleted end |
#status ⇒ Merge::Accounting::AccountStatusEnum (readonly)
Returns The account's status.
ACTIVE- ACTIVEPENDING- PENDINGINACTIVE- INACTIVE.
71 72 73 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 71 def status @status end |
#type ⇒ String (readonly)
Returns The account's type is a narrower and more specific grouping within the account's classification.
50 51 52 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 50 def type @type end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::Account
Deserialize a JSON object to an instance of Account
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 806 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) name = parsed_json["name"] description = parsed_json["description"] classification = parsed_json["classification"] type = parsed_json["type"] account_type = parsed_json["account_type"] status = parsed_json["status"] current_balance = parsed_json["current_balance"] currency = parsed_json["currency"] account_number = parsed_json["account_number"] parent_account = parsed_json["parent_account"] company = parsed_json["company"] remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, name: name, description: description, classification: classification, type: type, account_type: account_type, status: status, current_balance: current_balance, currency: currency, account_number: account_number, parent_account: parent_account, company: company, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_data: remote_data, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 866 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.classification&.is_a?(Merge::Accounting::ClassificationEnum) != false || raise("Passed value for field obj.classification is not the expected type, validation failed.") obj.type&.is_a?(String) != false || raise("Passed value for field obj.type is not the expected type, validation failed.") obj.account_type&.is_a?(Merge::Accounting::AccountAccountTypeEnum) != false || raise("Passed value for field obj.account_type is not the expected type, validation failed.") obj.status&.is_a?(Merge::Accounting::AccountStatusEnum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.current_balance&.is_a?(Float) != false || raise("Passed value for field obj.current_balance is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.account_number&.is_a?(String) != false || raise("Passed value for field obj.account_number is not the expected type, validation failed.") obj.parent_account&.is_a?(String) != false || raise("Passed value for field obj.parent_account is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of Account to a JSON object
856 857 858 |
# File 'lib/merge_ruby_client/accounting/types/account.rb', line 856 def to_json(*_args) @_field_set&.to_json end |