Class: Merge::Accounting::BankFeedAccount
- Inherits:
-
Object
- Object
- Merge::Accounting::BankFeedAccount
- Defined in:
- lib/merge_ruby_client/accounting/types/bank_feed_account.rb
Overview
The BankFeedAccount Object
Description
The BankFeedAccount object represents a bank feed account, detailing various
attributes including account identifiers, names, currency, and balance
information. This object is central to managing and tracking bank feed accounts
within the system.
Usage Example
Fetch from the GET BankFeedAccount endpoint to view details of a bank feed
account.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account_type ⇒ Merge::Accounting::BankFeedAccountAccountTypeEnum
readonly
The type of the account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The currency code of the bank feed.
-
#feed_start_date ⇒ DateTime
readonly
The start date of the bank feed’s transactions.
-
#feed_status ⇒ Merge::Accounting::FeedStatusEnum
readonly
The status of the bank feed.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
- #remote_data ⇒ Array<Hash{String => Object}> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#source_account_balance ⇒ Float
readonly
The current balance of funds in the source account.
-
#source_account_id ⇒ String
readonly
The unique identifier of the source account from our customer’s platform.
-
#source_account_name ⇒ String
readonly
The name of the source account as stored in our customer’s platform.
-
#source_account_number ⇒ String
readonly
The human-readable account number of the source account as stored in our customer’s platform.
-
#target_account_id ⇒ String
readonly
The unique identifier of the target account from the third party software.
-
#target_account_name ⇒ String
readonly
The name of the target account from the third party software.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::BankFeedAccount
Deserialize a JSON object to an instance of BankFeedAccount.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::BankFeedAccount constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of BankFeedAccount to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::BankFeedAccount
711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 711 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @source_account_id = source_account_id if source_account_id != OMIT @target_account_id = target_account_id if target_account_id != OMIT @source_account_name = source_account_name if source_account_name != OMIT @source_account_number = source_account_number if source_account_number != OMIT @target_account_name = target_account_name if target_account_name != OMIT @currency = currency if currency != OMIT @feed_status = feed_status if feed_status != OMIT @feed_start_date = feed_start_date if feed_start_date != OMIT @source_account_balance = source_account_balance if source_account_balance != OMIT @account_type = account_type if account_type != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "source_account_id": source_account_id, "target_account_id": target_account_id, "source_account_name": source_account_name, "source_account_number": source_account_number, "target_account_name": target_account_name, "currency": currency, "feed_status": feed_status, "feed_start_date": feed_start_date, "source_account_balance": source_account_balance, "account_type": account_type, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_data": remote_data }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account_type ⇒ Merge::Accounting::BankFeedAccountAccountTypeEnum (readonly)
Returns The type of the account.
BANK- BANKCREDIT_CARD- CREDIT_CARD.
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 360 def account_type @account_type end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 371 def additional_properties @additional_properties end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
27 28 29 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 27 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The currency code of the bank feed.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
348 349 350 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 348 def currency @currency end |
#feed_start_date ⇒ DateTime (readonly)
Returns The start date of the bank feed’s transactions.
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 354 def feed_start_date @feed_start_date end |
#feed_status ⇒ Merge::Accounting::FeedStatusEnum (readonly)
Returns The status of the bank feed.
ACTIVE- ACTIVEINACTIVE- INACTIVE.
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 352 def feed_status @feed_status end |
#field_mappings ⇒ Hash{String => Object} (readonly)
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 367 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
23 24 25 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 23 def id @id end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
29 30 31 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 29 def modified_at @modified_at end |
#remote_data ⇒ Array<Hash{String => Object}> (readonly)
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 369 def remote_data @remote_data end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
25 26 27 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 25 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 365 def remote_was_deleted @remote_was_deleted end |
#source_account_balance ⇒ Float (readonly)
Returns The current balance of funds in the source account.
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 356 def source_account_balance @source_account_balance end |
#source_account_id ⇒ String (readonly)
Returns The unique identifier of the source account from our customer’s platform.
31 32 33 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 31 def source_account_id @source_account_id end |
#source_account_name ⇒ String (readonly)
Returns The name of the source account as stored in our customer’s platform.
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 35 def source_account_name @source_account_name end |
#source_account_number ⇒ String (readonly)
Returns The human-readable account number of the source account as stored in our customer’s platform.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 38 def source_account_number @source_account_number end |
#target_account_id ⇒ String (readonly)
Returns The unique identifier of the target account from the third party software.
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 33 def target_account_id @target_account_id end |
#target_account_name ⇒ String (readonly)
Returns The name of the target account from the third party software.
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 40 def target_account_name @target_account_name end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::BankFeedAccount
Deserialize a JSON object to an instance of BankFeedAccount
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 758 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) source_account_id = parsed_json["source_account_id"] target_account_id = parsed_json["target_account_id"] source_account_name = parsed_json["source_account_name"] source_account_number = parsed_json["source_account_number"] target_account_name = parsed_json["target_account_name"] currency = parsed_json["currency"] feed_status = parsed_json["feed_status"] feed_start_date = (DateTime.parse(parsed_json["feed_start_date"]) unless parsed_json["feed_start_date"].nil?) source_account_balance = parsed_json["source_account_balance"] account_type = parsed_json["account_type"] remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"] new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, source_account_id: source_account_id, target_account_id: target_account_id, source_account_name: source_account_name, source_account_number: source_account_number, target_account_name: target_account_name, currency: currency, feed_status: feed_status, feed_start_date: feed_start_date, source_account_balance: source_account_balance, account_type: account_type, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_data: remote_data, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 813 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.source_account_id&.is_a?(String) != false || raise("Passed value for field obj.source_account_id is not the expected type, validation failed.") obj.target_account_id&.is_a?(String) != false || raise("Passed value for field obj.target_account_id is not the expected type, validation failed.") obj.source_account_name&.is_a?(String) != false || raise("Passed value for field obj.source_account_name is not the expected type, validation failed.") obj.source_account_number&.is_a?(String) != false || raise("Passed value for field obj.source_account_number is not the expected type, validation failed.") obj.target_account_name&.is_a?(String) != false || raise("Passed value for field obj.target_account_name is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.feed_status&.is_a?(Merge::Accounting::FeedStatusEnum) != false || raise("Passed value for field obj.feed_status is not the expected type, validation failed.") obj.feed_start_date&.is_a?(DateTime) != false || raise("Passed value for field obj.feed_start_date is not the expected type, validation failed.") obj.source_account_balance&.is_a?(Float) != false || raise("Passed value for field obj.source_account_balance is not the expected type, validation failed.") obj.account_type&.is_a?(Merge::Accounting::BankFeedAccountAccountTypeEnum) != false || raise("Passed value for field obj.account_type is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of BankFeedAccount to a JSON object
803 804 805 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account.rb', line 803 def to_json(*_args) @_field_set&.to_json end |