Class: Merge::Accounting::CashFlowStatement
- Inherits:
-
Object
- Object
- Merge::Accounting::CashFlowStatement
- Defined in:
- lib/merge_ruby_client/accounting/types/cash_flow_statement.rb
Overview
The CashFlowStatement Object
Description
The CashFlowStatement object shows operating activities, investing activities,
and financing activities over a period of time (month, quarter, or year).
Usage Example
Fetch from the LIST CashFlowStatements endpoint and view a company's cash flow
statements.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#cash_at_beginning_of_period ⇒ Float
readonly
Cash and cash equivalents at the beginning of the cash flow statement's period.
-
#cash_at_end_of_period ⇒ Float
readonly
Cash and cash equivalents at the beginning of the cash flow statement's period.
-
#company ⇒ Merge::Accounting::CashFlowStatementCompany
readonly
The company the cash flow statement belongs to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The cash flow statement's currency.
-
#end_period ⇒ DateTime
readonly
The cash flow statement's end period.
- #field_mappings ⇒ Hash{String => Object} readonly
- #financing_activities ⇒ Array<Merge::Accounting::ReportItem> readonly
- #id ⇒ String readonly
- #investing_activities ⇒ Array<Merge::Accounting::ReportItem> readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#name ⇒ String
readonly
The cash flow statement's name.
- #operating_activities ⇒ Array<Merge::Accounting::ReportItem> readonly
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
-
#remote_generated_at ⇒ DateTime
readonly
The time that cash flow statement was generated by the accounting system.
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#start_period ⇒ DateTime
readonly
The cash flow statement's start period.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::CashFlowStatement
Deserialize a JSON object to an instance of CashFlowStatement.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, currency: OMIT, company: OMIT, start_period: OMIT, end_period: OMIT, cash_at_beginning_of_period: OMIT, cash_at_end_of_period: OMIT, operating_activities: OMIT, investing_activities: OMIT, financing_activities: OMIT, remote_generated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::CashFlowStatement constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of CashFlowStatement to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, currency: OMIT, company: OMIT, start_period: OMIT, end_period: OMIT, cash_at_beginning_of_period: OMIT, cash_at_end_of_period: OMIT, operating_activities: OMIT, investing_activities: OMIT, financing_activities: OMIT, remote_generated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::CashFlowStatement
703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 703 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, currency: OMIT, company: OMIT, start_period: OMIT, end_period: OMIT, cash_at_beginning_of_period: OMIT, cash_at_end_of_period: OMIT, operating_activities: OMIT, investing_activities: OMIT, financing_activities: OMIT, remote_generated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @name = name if name != OMIT @currency = currency if currency != OMIT @company = company if company != OMIT @start_period = start_period if start_period != OMIT @end_period = end_period if end_period != OMIT @cash_at_beginning_of_period = cash_at_beginning_of_period if cash_at_beginning_of_period != OMIT @cash_at_end_of_period = cash_at_end_of_period if cash_at_end_of_period != OMIT = if != OMIT @investing_activities = investing_activities if investing_activities != OMIT @financing_activities = financing_activities if financing_activities != OMIT @remote_generated_at = remote_generated_at if remote_generated_at != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "name": name, "currency": currency, "company": company, "start_period": start_period, "end_period": end_period, "cash_at_beginning_of_period": cash_at_beginning_of_period, "cash_at_end_of_period": cash_at_end_of_period, "operating_activities": , "investing_activities": investing_activities, "financing_activities": financing_activities, "remote_generated_at": remote_generated_at, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_data": remote_data }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 367 def additional_properties @additional_properties end |
#cash_at_beginning_of_period ⇒ Float (readonly)
Returns Cash and cash equivalents at the beginning of the cash flow statement's period.
346 347 348 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 346 def cash_at_beginning_of_period @cash_at_beginning_of_period end |
#cash_at_end_of_period ⇒ Float (readonly)
Returns Cash and cash equivalents at the beginning of the cash flow statement's period.
348 349 350 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 348 def cash_at_end_of_period @cash_at_end_of_period end |
#company ⇒ Merge::Accounting::CashFlowStatementCompany (readonly)
Returns The company the cash flow statement belongs to.
340 341 342 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 340 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 26 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The cash flow statement's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
338 339 340 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 338 def currency @currency end |
#end_period ⇒ DateTime (readonly)
Returns The cash flow statement's end period.
344 345 346 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 344 def end_period @end_period end |
#field_mappings ⇒ Hash{String => Object} (readonly)
363 364 365 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 363 def field_mappings @field_mappings end |
#financing_activities ⇒ Array<Merge::Accounting::ReportItem> (readonly)
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 354 def financing_activities @financing_activities end |
#id ⇒ String (readonly)
22 23 24 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 22 def id @id end |
#investing_activities ⇒ Array<Merge::Accounting::ReportItem> (readonly)
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 352 def investing_activities @investing_activities end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 28 def modified_at @modified_at end |
#name ⇒ String (readonly)
Returns The cash flow statement's name.
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 30 def name @name end |
#operating_activities ⇒ Array<Merge::Accounting::ReportItem> (readonly)
350 351 352 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 350 def end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 365 def remote_data @remote_data end |
#remote_generated_at ⇒ DateTime (readonly)
Returns The time that cash flow statement was generated by the accounting system.
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 356 def remote_generated_at @remote_generated_at end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
24 25 26 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 24 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
361 362 363 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 361 def remote_was_deleted @remote_was_deleted end |
#start_period ⇒ DateTime (readonly)
Returns The cash flow statement's start period.
342 343 344 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 342 def start_period @start_period end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::CashFlowStatement
Deserialize a JSON object to an instance of CashFlowStatement
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 752 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) name = parsed_json["name"] currency = parsed_json["currency"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::CashFlowStatementCompany.from_json(json_object: company) end start_period = (DateTime.parse(parsed_json["start_period"]) unless parsed_json["start_period"].nil?) end_period = (DateTime.parse(parsed_json["end_period"]) unless parsed_json["end_period"].nil?) cash_at_beginning_of_period = parsed_json["cash_at_beginning_of_period"] cash_at_end_of_period = parsed_json["cash_at_end_of_period"] = parsed_json["operating_activities"]&.map do |item| item = item.to_json Merge::Accounting::ReportItem.from_json(json_object: item) end investing_activities = parsed_json["investing_activities"]&.map do |item| item = item.to_json Merge::Accounting::ReportItem.from_json(json_object: item) end financing_activities = parsed_json["financing_activities"]&.map do |item| item = item.to_json Merge::Accounting::ReportItem.from_json(json_object: item) end remote_generated_at = unless parsed_json["remote_generated_at"].nil? DateTime.parse(parsed_json["remote_generated_at"]) end remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, name: name, currency: currency, company: company, start_period: start_period, end_period: end_period, cash_at_beginning_of_period: cash_at_beginning_of_period, cash_at_end_of_period: cash_at_end_of_period, operating_activities: , investing_activities: investing_activities, financing_activities: financing_activities, remote_generated_at: remote_generated_at, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_data: remote_data, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 828 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::CashFlowStatementCompany.validate_raw(obj: obj.company) obj.start_period&.is_a?(DateTime) != false || raise("Passed value for field obj.start_period is not the expected type, validation failed.") obj.end_period&.is_a?(DateTime) != false || raise("Passed value for field obj.end_period is not the expected type, validation failed.") obj.cash_at_beginning_of_period&.is_a?(Float) != false || raise("Passed value for field obj.cash_at_beginning_of_period is not the expected type, validation failed.") obj.cash_at_end_of_period&.is_a?(Float) != false || raise("Passed value for field obj.cash_at_end_of_period is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.operating_activities is not the expected type, validation failed.") obj.investing_activities&.is_a?(Array) != false || raise("Passed value for field obj.investing_activities is not the expected type, validation failed.") obj.financing_activities&.is_a?(Array) != false || raise("Passed value for field obj.financing_activities is not the expected type, validation failed.") obj.remote_generated_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_generated_at is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of CashFlowStatement to a JSON object
818 819 820 |
# File 'lib/merge_ruby_client/accounting/types/cash_flow_statement.rb', line 818 def to_json(*_args) @_field_set&.to_json end |