Class: Merge::Accounting::ExpenseLine
- Inherits:
-
Object
- Object
- Merge::Accounting::ExpenseLine
- Defined in:
- lib/merge_ruby_client/accounting/types/expense_line.rb
Overview
The ExpenseLine Object
Description
The ExpenseLine object is used to represent an expense's line items.
Usage Example
Fetch from the GET Expense endpoint and view the expense's line items.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account ⇒ Merge::Accounting::ExpenseLineAccount
readonly
The expense's payment account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the expense belongs to.
-
#contact ⇒ Merge::Accounting::ExpenseLineContact
readonly
The expense's contact.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The expense line item's currency.
-
#description ⇒ String
readonly
The description of the item that was purchased by the company.
-
#employee ⇒ Merge::Accounting::ExpenseLineEmployee
readonly
The employee this overall transaction relates to.
-
#exchange_rate ⇒ String
readonly
The expense line item's exchange rate.
- #id ⇒ String readonly
-
#item ⇒ Merge::Accounting::ExpenseLineItem
readonly
The line's item.
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#net_amount ⇒ Float
readonly
The line's net amount.
- #project ⇒ Merge::Accounting::ExpenseLineProject readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#tracking_categories ⇒ Array<Merge::Accounting::ExpenseLineTrackingCategoriesItem>
readonly
The expense line item's associated tracking categories.
- #tracking_category ⇒ Merge::Accounting::ExpenseLineTrackingCategory readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseLine
Deserialize a JSON object to an instance of ExpenseLine.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseLine constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseLine to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseLine
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 705 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @item = item if item != OMIT @net_amount = net_amount if net_amount != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @company = company if company != OMIT @employee = employee if employee != OMIT @currency = currency if currency != OMIT @account = account if account != OMIT @contact = contact if contact != OMIT @project = project if project != OMIT @description = description if description != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @tax_rate = tax_rate if tax_rate != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "item": item, "net_amount": net_amount, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "company": company, "employee": employee, "currency": currency, "account": account, "contact": contact, "project": project, "description": description, "exchange_rate": exchange_rate, "tax_rate": tax_rate, "remote_was_deleted": remote_was_deleted }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::ExpenseLineAccount (readonly)
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 352 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 369 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 40 def company @company end |
#contact ⇒ Merge::Accounting::ExpenseLineContact (readonly)
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 354 def contact @contact end |
#created_at ⇒ DateTime (readonly)
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 28 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
350 351 352 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 350 def currency @currency end |
#description ⇒ String (readonly)
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 358 def description @description end |
#employee ⇒ Merge::Accounting::ExpenseLineEmployee (readonly)
42 43 44 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 42 def employee @employee end |
#exchange_rate ⇒ String (readonly)
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 360 def exchange_rate @exchange_rate end |
#id ⇒ String (readonly)
24 25 26 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 24 def id @id end |
#item ⇒ Merge::Accounting::ExpenseLineItem (readonly)
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 32 def item @item end |
#modified_at ⇒ DateTime (readonly)
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 30 def modified_at @modified_at end |
#net_amount ⇒ Float (readonly)
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 34 def net_amount @net_amount end |
#project ⇒ Merge::Accounting::ExpenseLineProject (readonly)
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 356 def project @project end |
#remote_id ⇒ String (readonly)
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 26 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 367 def remote_was_deleted @remote_was_deleted end |
#tax_rate ⇒ String (readonly)
362 363 364 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 362 def tax_rate @tax_rate end |
#tracking_categories ⇒ Array<Merge::Accounting::ExpenseLineTrackingCategoriesItem> (readonly)
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 38 def tracking_categories @tracking_categories end |
#tracking_category ⇒ Merge::Accounting::ExpenseLineTrackingCategory (readonly)
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 36 def tracking_category @tracking_category end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseLine
Deserialize a JSON object to an instance of ExpenseLine
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 754 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) if parsed_json["item"].nil? item = nil else item = parsed_json["item"].to_json item = Merge::Accounting::ExpenseLineItem.from_json(json_object: item) end net_amount = parsed_json["net_amount"] if parsed_json["tracking_category"].nil? tracking_category = nil else tracking_category = parsed_json["tracking_category"].to_json tracking_category = Merge::Accounting::ExpenseLineTrackingCategory.from_json(json_object: tracking_category) end tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::ExpenseLineTrackingCategoriesItem.from_json(json_object: item) end company = parsed_json["company"] if parsed_json["employee"].nil? employee = nil else employee = parsed_json["employee"].to_json employee = Merge::Accounting::ExpenseLineEmployee.from_json(json_object: employee) end currency = parsed_json["currency"] if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::ExpenseLineAccount.from_json(json_object: account) end if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::ExpenseLineContact.from_json(json_object: contact) end if parsed_json["project"].nil? project = nil else project = parsed_json["project"].to_json project = Merge::Accounting::ExpenseLineProject.from_json(json_object: project) end description = parsed_json["description"] exchange_rate = parsed_json["exchange_rate"] tax_rate = parsed_json["tax_rate"] remote_was_deleted = parsed_json["remote_was_deleted"] new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, item: item, net_amount: net_amount, tracking_category: tracking_category, tracking_categories: tracking_categories, company: company, employee: employee, currency: currency, account: account, contact: contact, project: project, description: description, exchange_rate: exchange_rate, tax_rate: tax_rate, remote_was_deleted: remote_was_deleted, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 844 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.item.nil? || Merge::Accounting::ExpenseLineItem.validate_raw(obj: obj.item) obj.net_amount&.is_a?(Float) != false || raise("Passed value for field obj.net_amount is not the expected type, validation failed.") obj.tracking_category.nil? || Merge::Accounting::ExpenseLineTrackingCategory.validate_raw(obj: obj.tracking_category) obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.employee.nil? || Merge::Accounting::ExpenseLineEmployee.validate_raw(obj: obj.employee) obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.account.nil? || Merge::Accounting::ExpenseLineAccount.validate_raw(obj: obj.account) obj.contact.nil? || Merge::Accounting::ExpenseLineContact.validate_raw(obj: obj.contact) obj.project.nil? || Merge::Accounting::ExpenseLineProject.validate_raw(obj: obj.project) obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseLine to a JSON object
834 835 836 |
# File 'lib/merge_ruby_client/accounting/types/expense_line.rb', line 834 def to_json(*_args) @_field_set&.to_json end |