Class: Merge::Accounting::ExpenseLineRequest
- Inherits:
-
Object
- Object
- Merge::Accounting::ExpenseLineRequest
- Defined in:
- lib/merge_ruby_client/accounting/types/expense_line_request.rb
Overview
The ExpenseLine Object
Description
The ExpenseLine object is used to represent an expense's line items.
Usage Example
Fetch from the GET Expense endpoint and view the expense's line items.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account ⇒ Merge::Accounting::ExpenseLineRequestAccount
readonly
The expense's payment account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the expense belongs to.
-
#contact ⇒ Merge::Accounting::ExpenseLineRequestContact
readonly
The expense's contact.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The expense line item's currency.
-
#description ⇒ String
readonly
The description of the item that was purchased by the company.
-
#employee ⇒ Merge::Accounting::ExpenseLineRequestEmployee
readonly
The employee this overall transaction relates to.
-
#exchange_rate ⇒ String
readonly
The expense line item's exchange rate.
- #integration_params ⇒ Hash{String => Object} readonly
-
#item ⇒ Merge::Accounting::ExpenseLineRequestItem
readonly
The line's item.
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#net_amount ⇒ Float
readonly
The line's net amount.
- #project ⇒ Merge::Accounting::ExpenseLineRequestProject readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#tracking_categories ⇒ Array<Merge::Accounting::ExpenseLineRequestTrackingCategoriesItem>
readonly
The expense line item's associated tracking categories.
- #tracking_category ⇒ Merge::Accounting::ExpenseLineRequestTrackingCategory readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseLineRequest
Deserialize a JSON object to an instance of ExpenseLineRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(remote_id: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseLineRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseLineRequest to a JSON object.
Constructor Details
#initialize(remote_id: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseLineRequest
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 696 def initialize(remote_id: OMIT, item: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, employee: OMIT, currency: OMIT, account: OMIT, contact: OMIT, project: OMIT, description: OMIT, exchange_rate: OMIT, tax_rate: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) @remote_id = remote_id if remote_id != OMIT @item = item if item != OMIT @net_amount = net_amount if net_amount != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @company = company if company != OMIT @employee = employee if employee != OMIT @currency = currency if currency != OMIT @account = account if account != OMIT @contact = contact if contact != OMIT @project = project if project != OMIT @description = description if description != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @tax_rate = tax_rate if tax_rate != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "remote_id": remote_id, "item": item, "net_amount": net_amount, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "company": company, "employee": employee, "currency": currency, "account": account, "contact": contact, "project": project, "description": description, "exchange_rate": exchange_rate, "tax_rate": tax_rate, "integration_params": integration_params, "linked_account_params": linked_account_params, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::ExpenseLineRequestAccount (readonly)
346 347 348 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 346 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
364 365 366 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 364 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 34 def company @company end |
#contact ⇒ Merge::Accounting::ExpenseLineRequestContact (readonly)
348 349 350 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 348 def contact @contact end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
344 345 346 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 344 def currency @currency end |
#description ⇒ String (readonly)
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 352 def description @description end |
#employee ⇒ Merge::Accounting::ExpenseLineRequestEmployee (readonly)
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 36 def employee @employee end |
#exchange_rate ⇒ String (readonly)
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 354 def exchange_rate @exchange_rate end |
#integration_params ⇒ Hash{String => Object} (readonly)
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 358 def integration_params @integration_params end |
#item ⇒ Merge::Accounting::ExpenseLineRequestItem (readonly)
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 26 def item @item end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 360 def linked_account_params @linked_account_params end |
#net_amount ⇒ Float (readonly)
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 28 def net_amount @net_amount end |
#project ⇒ Merge::Accounting::ExpenseLineRequestProject (readonly)
350 351 352 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 350 def project @project end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> (readonly)
362 363 364 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 362 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
24 25 26 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 24 def remote_id @remote_id end |
#tax_rate ⇒ String (readonly)
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 356 def tax_rate @tax_rate end |
#tracking_categories ⇒ Array<Merge::Accounting::ExpenseLineRequestTrackingCategoriesItem> (readonly)
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 32 def tracking_categories @tracking_categories end |
#tracking_category ⇒ Merge::Accounting::ExpenseLineRequestTrackingCategory (readonly)
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 30 def tracking_category @tracking_category end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseLineRequest
Deserialize a JSON object to an instance of ExpenseLineRequest
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 743 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) remote_id = parsed_json["remote_id"] if parsed_json["item"].nil? item = nil else item = parsed_json["item"].to_json item = Merge::Accounting::ExpenseLineRequestItem.from_json(json_object: item) end net_amount = parsed_json["net_amount"] if parsed_json["tracking_category"].nil? tracking_category = nil else tracking_category = parsed_json["tracking_category"].to_json tracking_category = Merge::Accounting::ExpenseLineRequestTrackingCategory.from_json(json_object: tracking_category) end tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::ExpenseLineRequestTrackingCategoriesItem.from_json(json_object: item) end company = parsed_json["company"] if parsed_json["employee"].nil? employee = nil else employee = parsed_json["employee"].to_json employee = Merge::Accounting::ExpenseLineRequestEmployee.from_json(json_object: employee) end currency = parsed_json["currency"] if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::ExpenseLineRequestAccount.from_json(json_object: account) end if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::ExpenseLineRequestContact.from_json(json_object: contact) end if parsed_json["project"].nil? project = nil else project = parsed_json["project"].to_json project = Merge::Accounting::ExpenseLineRequestProject.from_json(json_object: project) end description = parsed_json["description"] exchange_rate = parsed_json["exchange_rate"] tax_rate = parsed_json["tax_rate"] integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteFieldRequest.from_json(json_object: item) end new( remote_id: remote_id, item: item, net_amount: net_amount, tracking_category: tracking_category, tracking_categories: tracking_categories, company: company, employee: employee, currency: currency, account: account, contact: contact, project: project, description: description, exchange_rate: exchange_rate, tax_rate: tax_rate, integration_params: integration_params, linked_account_params: linked_account_params, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 834 def self.validate_raw(obj:) obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.item.nil? || Merge::Accounting::ExpenseLineRequestItem.validate_raw(obj: obj.item) obj.net_amount&.is_a?(Float) != false || raise("Passed value for field obj.net_amount is not the expected type, validation failed.") obj.tracking_category.nil? || Merge::Accounting::ExpenseLineRequestTrackingCategory.validate_raw(obj: obj.tracking_category) obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.employee.nil? || Merge::Accounting::ExpenseLineRequestEmployee.validate_raw(obj: obj.employee) obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.account.nil? || Merge::Accounting::ExpenseLineRequestAccount.validate_raw(obj: obj.account) obj.contact.nil? || Merge::Accounting::ExpenseLineRequestContact.validate_raw(obj: obj.contact) obj.project.nil? || Merge::Accounting::ExpenseLineRequestProject.validate_raw(obj: obj.project) obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseLineRequest to a JSON object
824 825 826 |
# File 'lib/merge_ruby_client/accounting/types/expense_line_request.rb', line 824 def to_json(*_args) @_field_set&.to_json end |