Class: Merge::Accounting::ExpenseReportLine
- Inherits:
-
Object
- Object
- Merge::Accounting::ExpenseReportLine
- Defined in:
- lib/merge_ruby_client/accounting/types/expense_report_line.rb
Overview
The ExpenseReportLine Object
Description
The ExpenseReportLine object represents an individual line item within an
expense report, containing details about
a specific expense such as amount, description, and associated metadata.
Usage Example
Fetch from the GET ExpenseReport endpoint and expand the lines field to view
all line items in the expense report.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
- #account ⇒ Merge::Accounting::ExpenseReportLineAccount readonly
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#amount ⇒ Float
readonly
The amount of the expense for the line item.
-
#company ⇒ Merge::Accounting::ExpenseReportLineCompany
readonly
The subsidiary that the expense report is created in.
- #contact ⇒ Merge::Accounting::ExpenseReportLineContact readonly
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
Currency of the expense line (if different from the report currency).
-
#description ⇒ String
readonly
Description of the individual expense.
-
#employee ⇒ Merge::Accounting::ExpenseReportLineEmployee
readonly
Identifier for the employee who submitted or is associated with the expense report.
-
#exchange_rate ⇒ String
readonly
Exchange rate used if the line item is in a foreign currency.
-
#expense_date ⇒ DateTime
readonly
The date the individual expense was incurred.
- #id ⇒ String readonly
-
#inclusive_of_tax ⇒ Boolean
readonly
Whether the amount is inclusive of tax.
-
#is_billable ⇒ Boolean
readonly
Whether the expense line is billable to a client or project.
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#non_reimbursable ⇒ Boolean
readonly
Whether the expense line is non-reimbursable (e.g., paid via company card).
- #project ⇒ Merge::Accounting::ExpenseReportLineProject readonly
-
#quantity ⇒ Float
readonly
Quantity for the expense line (e.g., miles driven, items purchased).
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#tax_amount ⇒ Float
readonly
Tax amount applicable for the line item.
- #tax_rate ⇒ Merge::Accounting::ExpenseReportLineTaxRate readonly
-
#tracking_categories ⇒ Array<String>
readonly
The related tracking categories associated with the expense report (Department, Location, Class, Expense Category).
-
#unit_price ⇒ Float
readonly
Price per unit for the expense line (if applicable).
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseReportLine
Deserialize a JSON object to an instance of ExpenseReportLine.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, description: OMIT, expense_date: OMIT, amount: OMIT, currency: OMIT, exchange_rate: OMIT, is_billable: OMIT, employee: OMIT, project: OMIT, company: OMIT, contact: OMIT, quantity: OMIT, unit_price: OMIT, non_reimbursable: OMIT, tax_amount: OMIT, inclusive_of_tax: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseReportLine constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseReportLine to a JSON object.
Constructor Details
#initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, description: OMIT, expense_date: OMIT, amount: OMIT, currency: OMIT, exchange_rate: OMIT, is_billable: OMIT, employee: OMIT, project: OMIT, company: OMIT, contact: OMIT, quantity: OMIT, unit_price: OMIT, non_reimbursable: OMIT, tax_amount: OMIT, inclusive_of_tax: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseReportLine
730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 730 def initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, description: OMIT, expense_date: OMIT, amount: OMIT, currency: OMIT, exchange_rate: OMIT, is_billable: OMIT, employee: OMIT, project: OMIT, company: OMIT, contact: OMIT, quantity: OMIT, unit_price: OMIT, non_reimbursable: OMIT, tax_amount: OMIT, inclusive_of_tax: OMIT, tax_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @account = account if account != OMIT @description = description if description != OMIT @expense_date = expense_date if expense_date != OMIT @amount = amount if amount != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @is_billable = is_billable if is_billable != OMIT @tracking_categories = tracking_categories @employee = employee if employee != OMIT @project = project if project != OMIT @company = company if company != OMIT @contact = contact if contact != OMIT @quantity = quantity if quantity != OMIT @unit_price = unit_price if unit_price != OMIT @non_reimbursable = non_reimbursable if non_reimbursable != OMIT @tax_amount = tax_amount if tax_amount != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @tax_rate = tax_rate if tax_rate != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "account": account, "description": description, "expense_date": expense_date, "amount": amount, "currency": currency, "exchange_rate": exchange_rate, "is_billable": is_billable, "tracking_categories": tracking_categories, "employee": employee, "project": project, "company": company, "contact": contact, "quantity": quantity, "unit_price": unit_price, "non_reimbursable": non_reimbursable, "tax_amount": tax_amount, "inclusive_of_tax": inclusive_of_tax, "tax_rate": tax_rate, "remote_was_deleted": remote_was_deleted, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::ExpenseReportLineAccount (readonly)
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 35 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
386 387 388 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 386 def additional_properties @additional_properties end |
#amount ⇒ Float (readonly)
Returns The amount of the expense for the line item.
41 42 43 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 41 def amount @amount end |
#company ⇒ Merge::Accounting::ExpenseReportLineCompany (readonly)
Returns The subsidiary that the expense report is created in.
363 364 365 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 363 def company @company end |
#contact ⇒ Merge::Accounting::ExpenseReportLineContact (readonly)
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 365 def contact @contact end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
31 32 33 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 31 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns Currency of the expense line (if different from the report currency).
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
349 350 351 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 349 def currency @currency end |
#description ⇒ String (readonly)
Returns Description of the individual expense.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 37 def description @description end |
#employee ⇒ Merge::Accounting::ExpenseReportLineEmployee (readonly)
Returns Identifier for the employee who submitted or is associated with the expense report.
359 360 361 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 359 def employee @employee end |
#exchange_rate ⇒ String (readonly)
Returns Exchange rate used if the line item is in a foreign currency.
351 352 353 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 351 def exchange_rate @exchange_rate end |
#expense_date ⇒ DateTime (readonly)
Returns The date the individual expense was incurred.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 39 def expense_date @expense_date end |
#id ⇒ String (readonly)
27 28 29 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 27 def id @id end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns Whether the amount is inclusive of tax.
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 375 def inclusive_of_tax @inclusive_of_tax end |
#is_billable ⇒ Boolean (readonly)
Returns Whether the expense line is billable to a client or project.
353 354 355 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 353 def is_billable @is_billable end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 33 def modified_at @modified_at end |
#non_reimbursable ⇒ Boolean (readonly)
Returns Whether the expense line is non-reimbursable (e.g., paid via company card).
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 371 def non_reimbursable @non_reimbursable end |
#project ⇒ Merge::Accounting::ExpenseReportLineProject (readonly)
361 362 363 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 361 def project @project end |
#quantity ⇒ Float (readonly)
Returns Quantity for the expense line (e.g., miles driven, items purchased).
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 367 def quantity @quantity end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
384 385 386 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 384 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
29 30 31 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 29 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
382 383 384 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 382 def remote_was_deleted @remote_was_deleted end |
#tax_amount ⇒ Float (readonly)
Returns Tax amount applicable for the line item.
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 373 def tax_amount @tax_amount end |
#tax_rate ⇒ Merge::Accounting::ExpenseReportLineTaxRate (readonly)
377 378 379 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 377 def tax_rate @tax_rate end |
#tracking_categories ⇒ Array<String> (readonly)
Returns The related tracking categories associated with the expense report (Department, Location, Class, Expense Category).
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 356 def tracking_categories @tracking_categories end |
#unit_price ⇒ Float (readonly)
Returns Price per unit for the expense line (if applicable).
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 369 def unit_price @unit_price end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseReportLine
Deserialize a JSON object to an instance of ExpenseReportLine
791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 791 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::ExpenseReportLineAccount.from_json(json_object: account) end description = parsed_json["description"] expense_date = (DateTime.parse(parsed_json["expense_date"]) unless parsed_json["expense_date"].nil?) amount = parsed_json["amount"] currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] is_billable = parsed_json["is_billable"] tracking_categories = parsed_json["tracking_categories"] if parsed_json["employee"].nil? employee = nil else employee = parsed_json["employee"].to_json employee = Merge::Accounting::ExpenseReportLineEmployee.from_json(json_object: employee) end if parsed_json["project"].nil? project = nil else project = parsed_json["project"].to_json project = Merge::Accounting::ExpenseReportLineProject.from_json(json_object: project) end if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::ExpenseReportLineCompany.from_json(json_object: company) end if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::ExpenseReportLineContact.from_json(json_object: contact) end quantity = parsed_json["quantity"] unit_price = parsed_json["unit_price"] non_reimbursable = parsed_json["non_reimbursable"] tax_amount = parsed_json["tax_amount"] inclusive_of_tax = parsed_json["inclusive_of_tax"] if parsed_json["tax_rate"].nil? tax_rate = nil else tax_rate = parsed_json["tax_rate"].to_json tax_rate = Merge::Accounting::ExpenseReportLineTaxRate.from_json(json_object: tax_rate) end remote_was_deleted = parsed_json["remote_was_deleted"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, account: account, description: description, expense_date: expense_date, amount: amount, currency: currency, exchange_rate: exchange_rate, is_billable: is_billable, tracking_categories: tracking_categories, employee: employee, project: project, company: company, contact: contact, quantity: quantity, unit_price: unit_price, non_reimbursable: non_reimbursable, tax_amount: tax_amount, inclusive_of_tax: inclusive_of_tax, tax_rate: tax_rate, remote_was_deleted: remote_was_deleted, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 893 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.account.nil? || Merge::Accounting::ExpenseReportLineAccount.validate_raw(obj: obj.account) obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.expense_date&.is_a?(DateTime) != false || raise("Passed value for field obj.expense_date is not the expected type, validation failed.") obj.amount&.is_a?(Float) != false || raise("Passed value for field obj.amount is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.is_billable&.is_a?(Boolean) != false || raise("Passed value for field obj.is_billable is not the expected type, validation failed.") obj.tracking_categories.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.employee.nil? || Merge::Accounting::ExpenseReportLineEmployee.validate_raw(obj: obj.employee) obj.project.nil? || Merge::Accounting::ExpenseReportLineProject.validate_raw(obj: obj.project) obj.company.nil? || Merge::Accounting::ExpenseReportLineCompany.validate_raw(obj: obj.company) obj.contact.nil? || Merge::Accounting::ExpenseReportLineContact.validate_raw(obj: obj.contact) obj.quantity&.is_a?(Float) != false || raise("Passed value for field obj.quantity is not the expected type, validation failed.") obj.unit_price&.is_a?(Float) != false || raise("Passed value for field obj.unit_price is not the expected type, validation failed.") obj.non_reimbursable&.is_a?(Boolean) != false || raise("Passed value for field obj.non_reimbursable is not the expected type, validation failed.") obj.tax_amount&.is_a?(Float) != false || raise("Passed value for field obj.tax_amount is not the expected type, validation failed.") obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.tax_rate.nil? || Merge::Accounting::ExpenseReportLineTaxRate.validate_raw(obj: obj.tax_rate) obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseReportLine to a JSON object
883 884 885 |
# File 'lib/merge_ruby_client/accounting/types/expense_report_line.rb', line 883 def to_json(*_args) @_field_set&.to_json end |