Class: Merge::Accounting::InvoiceLineItem
- Inherits:
-
Object
- Object
- Merge::Accounting::InvoiceLineItem
- Defined in:
- lib/merge_ruby_client/accounting/types/invoice_line_item.rb
Overview
The InvoiceLineItem Object
Description
The InvoiceLineItem object represents an itemized record of goods and/or
services sold to a customer.
Usage Example
Fetch from the GET Invoice endpoint and view the invoice's line items.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
- #account ⇒ Merge::Accounting::InvoiceLineItemAccount readonly
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the invoice belongs to.
-
#contact ⇒ Merge::Accounting::InvoiceLineItemContact
readonly
The invoice's contact.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The line item's currency.
-
#description ⇒ String
readonly
The line item's description.
-
#employee ⇒ Merge::Accounting::InvoiceLineItemEmployee
readonly
The employee this overall transaction relates to.
-
#exchange_rate ⇒ String
readonly
The line item's exchange rate.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
- #item ⇒ Merge::Accounting::InvoiceLineItemItem readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
- #project ⇒ Merge::Accounting::InvoiceLineItemProject readonly
-
#quantity ⇒ Float
readonly
The line item's quantity.
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#total_amount ⇒ Float
readonly
The line item's total amount.
-
#tracking_categories ⇒ Array<Merge::Accounting::InvoiceLineItemTrackingCategoriesItem>
readonly
The invoice line item's associated tracking categories.
- #tracking_category ⇒ Merge::Accounting::InvoiceLineItemTrackingCategory readonly
-
#unit_price ⇒ Float
readonly
The line item's unit price.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::InvoiceLineItem
Deserialize a JSON object to an instance of InvoiceLineItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, total_amount: OMIT, employee: OMIT, project: OMIT, contact: OMIT, currency: OMIT, exchange_rate: OMIT, item: OMIT, account: OMIT, tax_rate: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::InvoiceLineItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of InvoiceLineItem to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, total_amount: OMIT, employee: OMIT, project: OMIT, contact: OMIT, currency: OMIT, exchange_rate: OMIT, item: OMIT, account: OMIT, tax_rate: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::InvoiceLineItem
719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 719 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, total_amount: OMIT, employee: OMIT, project: OMIT, contact: OMIT, currency: OMIT, exchange_rate: OMIT, item: OMIT, account: OMIT, tax_rate: OMIT, tracking_category: OMIT, tracking_categories: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @description = description if description != OMIT @unit_price = unit_price if unit_price != OMIT @quantity = quantity if quantity != OMIT @total_amount = total_amount if total_amount != OMIT @employee = employee if employee != OMIT @project = project if project != OMIT @contact = contact if contact != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @item = item if item != OMIT @account = account if account != OMIT @tax_rate = tax_rate if tax_rate != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @company = company if company != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "description": description, "unit_price": unit_price, "quantity": quantity, "total_amount": total_amount, "employee": employee, "project": project, "contact": contact, "currency": currency, "exchange_rate": exchange_rate, "item": item, "account": account, "tax_rate": tax_rate, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "company": company, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::InvoiceLineItemAccount (readonly)
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 360 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
379 380 381 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 379 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
Returns The company the invoice belongs to.
368 369 370 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 368 def company @company end |
#contact ⇒ Merge::Accounting::InvoiceLineItemContact (readonly)
Returns The invoice's contact.
46 47 48 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 46 def contact @contact end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 30 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The line item's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 354 def currency @currency end |
#description ⇒ String (readonly)
Returns The line item's description.
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 34 def description @description end |
#employee ⇒ Merge::Accounting::InvoiceLineItemEmployee (readonly)
Returns The employee this overall transaction relates to.
42 43 44 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 42 def employee @employee end |
#exchange_rate ⇒ String (readonly)
Returns The line item's exchange rate.
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 356 def exchange_rate @exchange_rate end |
#field_mappings ⇒ Hash{String => Object} (readonly)
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 375 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 26 def id @id end |
#item ⇒ Merge::Accounting::InvoiceLineItemItem (readonly)
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 358 def item @item end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 32 def modified_at @modified_at end |
#project ⇒ Merge::Accounting::InvoiceLineItemProject (readonly)
44 45 46 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 44 def project @project end |
#quantity ⇒ Float (readonly)
Returns The line item's quantity.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 38 def quantity @quantity end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
377 378 379 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 377 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 28 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 373 def remote_was_deleted @remote_was_deleted end |
#tax_rate ⇒ String (readonly)
Returns The tax rate that applies to this line item.
362 363 364 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 362 def tax_rate @tax_rate end |
#total_amount ⇒ Float (readonly)
Returns The line item's total amount.
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 40 def total_amount @total_amount end |
#tracking_categories ⇒ Array<Merge::Accounting::InvoiceLineItemTrackingCategoriesItem> (readonly)
Returns The invoice line item's associated tracking categories.
366 367 368 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 366 def tracking_categories @tracking_categories end |
#tracking_category ⇒ Merge::Accounting::InvoiceLineItemTrackingCategory (readonly)
364 365 366 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 364 def tracking_category @tracking_category end |
#unit_price ⇒ Float (readonly)
Returns The line item's unit price.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 36 def unit_price @unit_price end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::InvoiceLineItem
Deserialize a JSON object to an instance of InvoiceLineItem
776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 776 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) description = parsed_json["description"] unit_price = parsed_json["unit_price"] quantity = parsed_json["quantity"] total_amount = parsed_json["total_amount"] if parsed_json["employee"].nil? employee = nil else employee = parsed_json["employee"].to_json employee = Merge::Accounting::InvoiceLineItemEmployee.from_json(json_object: employee) end if parsed_json["project"].nil? project = nil else project = parsed_json["project"].to_json project = Merge::Accounting::InvoiceLineItemProject.from_json(json_object: project) end if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::InvoiceLineItemContact.from_json(json_object: contact) end currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] if parsed_json["item"].nil? item = nil else item = parsed_json["item"].to_json item = Merge::Accounting::InvoiceLineItemItem.from_json(json_object: item) end if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::InvoiceLineItemAccount.from_json(json_object: account) end tax_rate = parsed_json["tax_rate"] if parsed_json["tracking_category"].nil? tracking_category = nil else tracking_category = parsed_json["tracking_category"].to_json tracking_category = Merge::Accounting::InvoiceLineItemTrackingCategory.from_json(json_object: tracking_category) end tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::InvoiceLineItemTrackingCategoriesItem.from_json(json_object: item) end company = parsed_json["company"] remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, description: description, unit_price: unit_price, quantity: quantity, total_amount: total_amount, employee: employee, project: project, contact: contact, currency: currency, exchange_rate: exchange_rate, item: item, account: account, tax_rate: tax_rate, tracking_category: tracking_category, tracking_categories: tracking_categories, company: company, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 877 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.unit_price&.is_a?(Float) != false || raise("Passed value for field obj.unit_price is not the expected type, validation failed.") obj.quantity&.is_a?(Float) != false || raise("Passed value for field obj.quantity is not the expected type, validation failed.") obj.total_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.employee.nil? || Merge::Accounting::InvoiceLineItemEmployee.validate_raw(obj: obj.employee) obj.project.nil? || Merge::Accounting::InvoiceLineItemProject.validate_raw(obj: obj.project) obj.contact.nil? || Merge::Accounting::InvoiceLineItemContact.validate_raw(obj: obj.contact) obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.item.nil? || Merge::Accounting::InvoiceLineItemItem.validate_raw(obj: obj.item) obj.account.nil? || Merge::Accounting::InvoiceLineItemAccount.validate_raw(obj: obj.account) obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.tracking_category.nil? || Merge::Accounting::InvoiceLineItemTrackingCategory.validate_raw(obj: obj.tracking_category) obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of InvoiceLineItem to a JSON object
867 868 869 |
# File 'lib/merge_ruby_client/accounting/types/invoice_line_item.rb', line 867 def to_json(*_args) @_field_set&.to_json end |