Class: Merge::Accounting::InvoiceRequest
- Inherits:
-
Object
- Object
- Merge::Accounting::InvoiceRequest
- Defined in:
- lib/merge_ruby_client/accounting/types/invoice_request.rb
Overview
The Invoice Object
Description
The Invoice object represents an itemized record of goods and/or services sold
to a customer or bought from a vendor.
Represents a Bill when the Invoice type is ACCOUNTS_PAYABLE. References an
Invoice when the Invoice type is ACCOUNTS_RECEIVABLE.
Usage Example
Fetch from the LIST Invoices endpoint and view a company's invoices.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#balance ⇒ Float
readonly
The invoice's remaining balance.
-
#company ⇒ Merge::Accounting::InvoiceRequestCompany
readonly
The company the invoice belongs to.
-
#contact ⇒ Merge::Accounting::InvoiceRequestContact
readonly
The invoice's contact.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The invoice's currency.
-
#due_date ⇒ DateTime
readonly
The invoice's due date.
-
#employee ⇒ Merge::Accounting::InvoiceRequestEmployee
readonly
The employee this overall transaction relates to.
-
#exchange_rate ⇒ String
readonly
The invoice's exchange rate.
-
#inclusive_of_tax ⇒ Boolean
readonly
If the transaction is inclusive or exclusive of tax.
- #integration_params ⇒ Hash{String => Object} readonly
-
#issue_date ⇒ DateTime
readonly
The invoice's issue date.
- #line_items ⇒ Array<Merge::Accounting::InvoiceLineItemRequest> readonly
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#memo ⇒ String
readonly
The invoice's private note.
-
#number ⇒ String
readonly
The invoice's number.
-
#paid_on_date ⇒ DateTime
readonly
The invoice's paid date.
-
#payment_term ⇒ Merge::Accounting::InvoiceRequestPaymentTerm
readonly
The payment term that applies to this transaction.
-
#payments ⇒ Array<Merge::Accounting::InvoiceRequestPaymentsItem>
readonly
Array of
Paymentobject IDs. - #purchase_orders ⇒ Array<Merge::Accounting::InvoiceRequestPurchaseOrdersItem> readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> readonly
-
#status ⇒ Merge::Accounting::InvoiceStatusEnum
readonly
The status of the invoice.
-
#sub_total ⇒ Float
readonly
The total amount being paid before taxes.
-
#total_amount ⇒ Float
readonly
The invoice's total amount.
-
#total_discount ⇒ Float
readonly
The total discounts applied to the total cost.
-
#total_tax_amount ⇒ Float
readonly
The total amount being paid in taxes.
- #tracking_categories ⇒ Array<Merge::Accounting::InvoiceRequestTrackingCategoriesItem> readonly
-
#type ⇒ Merge::Accounting::InvoiceTypeEnum
readonly
Whether the invoice is an accounts receivable or accounts payable.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::InvoiceRequest
Deserialize a JSON object to an instance of InvoiceRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(type: OMIT, contact: OMIT, number: OMIT, issue_date: OMIT, due_date: OMIT, paid_on_date: OMIT, employee: OMIT, memo: OMIT, status: OMIT, company: OMIT, currency: OMIT, exchange_rate: OMIT, total_discount: OMIT, sub_total: OMIT, payment_term: OMIT, total_tax_amount: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, balance: OMIT, payments: OMIT, tracking_categories: OMIT, line_items: OMIT, purchase_orders: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::InvoiceRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of InvoiceRequest to a JSON object.
Constructor Details
#initialize(type: OMIT, contact: OMIT, number: OMIT, issue_date: OMIT, due_date: OMIT, paid_on_date: OMIT, employee: OMIT, memo: OMIT, status: OMIT, company: OMIT, currency: OMIT, exchange_rate: OMIT, total_discount: OMIT, sub_total: OMIT, payment_term: OMIT, total_tax_amount: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, balance: OMIT, payments: OMIT, tracking_categories: OMIT, line_items: OMIT, purchase_orders: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::InvoiceRequest
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 752 def initialize(type: OMIT, contact: OMIT, number: OMIT, issue_date: OMIT, due_date: OMIT, paid_on_date: OMIT, employee: OMIT, memo: OMIT, status: OMIT, company: OMIT, currency: OMIT, exchange_rate: OMIT, total_discount: OMIT, sub_total: OMIT, payment_term: OMIT, total_tax_amount: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, balance: OMIT, payments: OMIT, tracking_categories: OMIT, line_items: OMIT, purchase_orders: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) @type = type if type != OMIT @contact = contact if contact != OMIT @number = number if number != OMIT @issue_date = issue_date if issue_date != OMIT @due_date = due_date if due_date != OMIT @paid_on_date = paid_on_date if paid_on_date != OMIT @employee = employee if employee != OMIT @memo = memo if memo != OMIT @status = status if status != OMIT @company = company if company != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @total_discount = total_discount if total_discount != OMIT @sub_total = sub_total if sub_total != OMIT @payment_term = payment_term if payment_term != OMIT @total_tax_amount = total_tax_amount if total_tax_amount != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @total_amount = total_amount if total_amount != OMIT @balance = balance if balance != OMIT @payments = payments if payments != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @line_items = line_items if line_items != OMIT @purchase_orders = purchase_orders if purchase_orders != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "type": type, "contact": contact, "number": number, "issue_date": issue_date, "due_date": due_date, "paid_on_date": paid_on_date, "employee": employee, "memo": memo, "status": status, "company": company, "currency": currency, "exchange_rate": exchange_rate, "total_discount": total_discount, "sub_total": sub_total, "payment_term": payment_term, "total_tax_amount": total_tax_amount, "inclusive_of_tax": inclusive_of_tax, "total_amount": total_amount, "balance": balance, "payments": payments, "tracking_categories": tracking_categories, "line_items": line_items, "purchase_orders": purchase_orders, "integration_params": integration_params, "linked_account_params": linked_account_params, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
400 401 402 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 400 def additional_properties @additional_properties end |
#balance ⇒ Float (readonly)
Returns The invoice's remaining balance.
384 385 386 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 384 def balance @balance end |
#company ⇒ Merge::Accounting::InvoiceRequestCompany (readonly)
Returns The company the invoice belongs to.
59 60 61 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 59 def company @company end |
#contact ⇒ Merge::Accounting::InvoiceRequestContact (readonly)
Returns The invoice's contact.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 37 def contact @contact end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The invoice's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 367 def currency @currency end |
#due_date ⇒ DateTime (readonly)
Returns The invoice's due date.
43 44 45 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 43 def due_date @due_date end |
#employee ⇒ Merge::Accounting::InvoiceRequestEmployee (readonly)
Returns The employee this overall transaction relates to.
47 48 49 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 47 def employee @employee end |
#exchange_rate ⇒ String (readonly)
Returns The invoice's exchange rate.
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 369 def exchange_rate @exchange_rate end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns If the transaction is inclusive or exclusive of tax. True if inclusive,
False if exclusive.
380 381 382 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 380 def inclusive_of_tax @inclusive_of_tax end |
#integration_params ⇒ Hash{String => Object} (readonly)
394 395 396 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 394 def integration_params @integration_params end |
#issue_date ⇒ DateTime (readonly)
Returns The invoice's issue date.
41 42 43 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 41 def issue_date @issue_date end |
#line_items ⇒ Array<Merge::Accounting::InvoiceLineItemRequest> (readonly)
390 391 392 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 390 def line_items @line_items end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
396 397 398 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 396 def linked_account_params @linked_account_params end |
#memo ⇒ String (readonly)
Returns The invoice's private note.
49 50 51 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 49 def memo @memo end |
#number ⇒ String (readonly)
Returns The invoice's number.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 39 def number @number end |
#paid_on_date ⇒ DateTime (readonly)
Returns The invoice's paid date.
45 46 47 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 45 def paid_on_date @paid_on_date end |
#payment_term ⇒ Merge::Accounting::InvoiceRequestPaymentTerm (readonly)
Returns The payment term that applies to this transaction.
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 375 def payment_term @payment_term end |
#payments ⇒ Array<Merge::Accounting::InvoiceRequestPaymentsItem> (readonly)
Returns Array of Payment object IDs.
386 387 388 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 386 def payments @payments end |
#purchase_orders ⇒ Array<Merge::Accounting::InvoiceRequestPurchaseOrdersItem> (readonly)
392 393 394 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 392 def purchase_orders @purchase_orders end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> (readonly)
398 399 400 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 398 def remote_fields @remote_fields end |
#status ⇒ Merge::Accounting::InvoiceStatusEnum (readonly)
Returns The status of the invoice.
PAID- PAIDDRAFT- DRAFTSUBMITTED- SUBMITTEDPARTIALLY_PAID- PARTIALLY_PAIDOPEN- OPENVOID- VOID.
57 58 59 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 57 def status @status end |
#sub_total ⇒ Float (readonly)
Returns The total amount being paid before taxes.
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 373 def sub_total @sub_total end |
#total_amount ⇒ Float (readonly)
Returns The invoice's total amount.
382 383 384 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 382 def total_amount @total_amount end |
#total_discount ⇒ Float (readonly)
Returns The total discounts applied to the total cost.
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 371 def total_discount @total_discount end |
#total_tax_amount ⇒ Float (readonly)
Returns The total amount being paid in taxes.
377 378 379 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 377 def total_tax_amount @total_tax_amount end |
#tracking_categories ⇒ Array<Merge::Accounting::InvoiceRequestTrackingCategoriesItem> (readonly)
388 389 390 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 388 def tracking_categories @tracking_categories end |
#type ⇒ Merge::Accounting::InvoiceTypeEnum (readonly)
Returns Whether the invoice is an accounts receivable or accounts payable. If type is
ACCOUNTS_PAYABLE, the invoice is a bill. If type is ACCOUNTS_RECEIVABLE,
it is an invoice.
ACCOUNTS_RECEIVABLE- ACCOUNTS_RECEIVABLEACCOUNTS_PAYABLE- ACCOUNTS_PAYABLE.
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 35 def type @type end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::InvoiceRequest
Deserialize a JSON object to an instance of InvoiceRequest
817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 817 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) type = parsed_json["type"] if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::InvoiceRequestContact.from_json(json_object: contact) end number = parsed_json["number"] issue_date = (DateTime.parse(parsed_json["issue_date"]) unless parsed_json["issue_date"].nil?) due_date = (DateTime.parse(parsed_json["due_date"]) unless parsed_json["due_date"].nil?) paid_on_date = (DateTime.parse(parsed_json["paid_on_date"]) unless parsed_json["paid_on_date"].nil?) if parsed_json["employee"].nil? employee = nil else employee = parsed_json["employee"].to_json employee = Merge::Accounting::InvoiceRequestEmployee.from_json(json_object: employee) end memo = parsed_json["memo"] status = parsed_json["status"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::InvoiceRequestCompany.from_json(json_object: company) end currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] total_discount = parsed_json["total_discount"] sub_total = parsed_json["sub_total"] if parsed_json["payment_term"].nil? payment_term = nil else payment_term = parsed_json["payment_term"].to_json payment_term = Merge::Accounting::InvoiceRequestPaymentTerm.from_json(json_object: payment_term) end total_tax_amount = parsed_json["total_tax_amount"] inclusive_of_tax = parsed_json["inclusive_of_tax"] total_amount = parsed_json["total_amount"] balance = parsed_json["balance"] payments = parsed_json["payments"]&.map do |item| item = item.to_json Merge::Accounting::InvoiceRequestPaymentsItem.from_json(json_object: item) end tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::InvoiceRequestTrackingCategoriesItem.from_json(json_object: item) end line_items = parsed_json["line_items"]&.map do |item| item = item.to_json Merge::Accounting::InvoiceLineItemRequest.from_json(json_object: item) end purchase_orders = parsed_json["purchase_orders"]&.map do |item| item = item.to_json Merge::Accounting::InvoiceRequestPurchaseOrdersItem.from_json(json_object: item) end integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteFieldRequest.from_json(json_object: item) end new( type: type, contact: contact, number: number, issue_date: issue_date, due_date: due_date, paid_on_date: paid_on_date, employee: employee, memo: memo, status: status, company: company, currency: currency, exchange_rate: exchange_rate, total_discount: total_discount, sub_total: sub_total, payment_term: payment_term, total_tax_amount: total_tax_amount, inclusive_of_tax: inclusive_of_tax, total_amount: total_amount, balance: balance, payments: payments, tracking_categories: tracking_categories, line_items: line_items, purchase_orders: purchase_orders, integration_params: integration_params, linked_account_params: linked_account_params, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 925 def self.validate_raw(obj:) obj.type&.is_a?(Merge::Accounting::InvoiceTypeEnum) != false || raise("Passed value for field obj.type is not the expected type, validation failed.") obj.contact.nil? || Merge::Accounting::InvoiceRequestContact.validate_raw(obj: obj.contact) obj.number&.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.") obj.issue_date&.is_a?(DateTime) != false || raise("Passed value for field obj.issue_date is not the expected type, validation failed.") obj.due_date&.is_a?(DateTime) != false || raise("Passed value for field obj.due_date is not the expected type, validation failed.") obj.paid_on_date&.is_a?(DateTime) != false || raise("Passed value for field obj.paid_on_date is not the expected type, validation failed.") obj.employee.nil? || Merge::Accounting::InvoiceRequestEmployee.validate_raw(obj: obj.employee) obj.memo&.is_a?(String) != false || raise("Passed value for field obj.memo is not the expected type, validation failed.") obj.status&.is_a?(Merge::Accounting::InvoiceStatusEnum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::InvoiceRequestCompany.validate_raw(obj: obj.company) obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.total_discount&.is_a?(Float) != false || raise("Passed value for field obj.total_discount is not the expected type, validation failed.") obj.sub_total&.is_a?(Float) != false || raise("Passed value for field obj.sub_total is not the expected type, validation failed.") obj.payment_term.nil? || Merge::Accounting::InvoiceRequestPaymentTerm.validate_raw(obj: obj.payment_term) obj.total_tax_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_tax_amount is not the expected type, validation failed.") obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.total_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.balance&.is_a?(Float) != false || raise("Passed value for field obj.balance is not the expected type, validation failed.") obj.payments&.is_a?(Array) != false || raise("Passed value for field obj.payments is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.line_items&.is_a?(Array) != false || raise("Passed value for field obj.line_items is not the expected type, validation failed.") obj.purchase_orders&.is_a?(Array) != false || raise("Passed value for field obj.purchase_orders is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of InvoiceRequest to a JSON object
915 916 917 |
# File 'lib/merge_ruby_client/accounting/types/invoice_request.rb', line 915 def to_json(*_args) @_field_set&.to_json end |