Class: Merge::Accounting::Item

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/accounting/types/item.rb

Overview

# The Item Object

### Description
The `Item` object refers to the goods involved in a transaction.
### Usage Example
Fetch from the `LIST Items` endpoint and view a company's items.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, status: OMIT, type: OMIT, unit_price: OMIT, purchase_price: OMIT, purchase_account: OMIT, sales_account: OMIT, company: OMIT, purchase_tax_rate: OMIT, sales_tax_rate: OMIT, remote_updated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::Item



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 105

def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, name: OMIT, status: OMIT,
               type: OMIT, unit_price: OMIT, purchase_price: OMIT, purchase_account: OMIT, sales_account: OMIT, company: OMIT, purchase_tax_rate: OMIT, sales_tax_rate: OMIT, remote_updated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil)
  @id = id if id != OMIT
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @name = name if name != OMIT
  @status = status if status != OMIT
  @type = type if type != OMIT
  @unit_price = unit_price if unit_price != OMIT
  @purchase_price = purchase_price if purchase_price != OMIT
   =  if  != OMIT
   =  if  != OMIT
  @company = company if company != OMIT
  @purchase_tax_rate = purchase_tax_rate if purchase_tax_rate != OMIT
  @sales_tax_rate = sales_tax_rate if sales_tax_rate != OMIT
  @remote_updated_at = remote_updated_at if remote_updated_at != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @field_mappings = field_mappings if field_mappings != OMIT
  @remote_data = remote_data if remote_data != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "id": id,
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "name": name,
    "status": status,
    "type": type,
    "unit_price": unit_price,
    "purchase_price": purchase_price,
    "purchase_account": ,
    "sales_account": ,
    "company": company,
    "purchase_tax_rate": purchase_tax_rate,
    "sales_tax_rate": sales_tax_rate,
    "remote_updated_at": remote_updated_at,
    "remote_was_deleted": remote_was_deleted,
    "field_mappings": field_mappings,
    "remote_data": remote_data
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



69
70
71
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 69

def additional_properties
  @additional_properties
end

#companyMerge::Accounting::ItemCompany (readonly)



52
53
54
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 52

def company
  @company
end

#created_atDateTime (readonly)



28
29
30
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 28

def created_at
  @created_at
end

#field_mappingsHash{String => Object} (readonly)



65
66
67
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 65

def field_mappings
  @field_mappings
end

#idString (readonly)



24
25
26
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 24

def id
  @id
end

#modified_atDateTime (readonly)



30
31
32
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 30

def modified_at
  @modified_at
end

#nameString (readonly)



32
33
34
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 32

def name
  @name
end

#purchase_accountMerge::Accounting::ItemPurchaseAccount (readonly)



48
49
50
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 48

def 
  
end

#purchase_priceFloat (readonly)



46
47
48
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 46

def purchase_price
  @purchase_price
end

#purchase_tax_rateMerge::Accounting::ItemPurchaseTaxRate (readonly)



54
55
56
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 54

def purchase_tax_rate
  @purchase_tax_rate
end

#remote_dataArray<Merge::Accounting::RemoteData> (readonly)



67
68
69
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 67

def remote_data
  @remote_data
end

#remote_idString (readonly)



26
27
28
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 26

def remote_id
  @remote_id
end

#remote_updated_atDateTime (readonly)



58
59
60
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 58

def remote_updated_at
  @remote_updated_at
end

#remote_was_deletedBoolean (readonly)



63
64
65
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 63

def remote_was_deleted
  @remote_was_deleted
end

#sales_accountMerge::Accounting::ItemSalesAccount (readonly)



50
51
52
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 50

def 
  
end

#sales_tax_rateMerge::Accounting::ItemSalesTaxRate (readonly)



56
57
58
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 56

def sales_tax_rate
  @sales_tax_rate
end

#statusMerge::Accounting::Status7D1Enum (readonly)



36
37
38
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 36

def status
  @status
end

#typeMerge::Accounting::Type2BbEnum (readonly)



42
43
44
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 42

def type
  @type
end

#unit_priceFloat (readonly)



44
45
46
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 44

def unit_price
  @unit_price
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Accounting::Item

Deserialize a JSON object to an instance of Item



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 154

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  id = parsed_json["id"]
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  name = parsed_json["name"]
  status = parsed_json["status"]
  type = parsed_json["type"]
  unit_price = parsed_json["unit_price"]
  purchase_price = parsed_json["purchase_price"]
  if parsed_json["purchase_account"].nil?
     = nil
  else
     = parsed_json["purchase_account"].to_json
     = Merge::Accounting::ItemPurchaseAccount.from_json(json_object: )
  end
  if parsed_json["sales_account"].nil?
     = nil
  else
     = parsed_json["sales_account"].to_json
     = Merge::Accounting::ItemSalesAccount.from_json(json_object: )
  end
  if parsed_json["company"].nil?
    company = nil
  else
    company = parsed_json["company"].to_json
    company = Merge::Accounting::ItemCompany.from_json(json_object: company)
  end
  if parsed_json["purchase_tax_rate"].nil?
    purchase_tax_rate = nil
  else
    purchase_tax_rate = parsed_json["purchase_tax_rate"].to_json
    purchase_tax_rate = Merge::Accounting::ItemPurchaseTaxRate.from_json(json_object: purchase_tax_rate)
  end
  if parsed_json["sales_tax_rate"].nil?
    sales_tax_rate = nil
  else
    sales_tax_rate = parsed_json["sales_tax_rate"].to_json
    sales_tax_rate = Merge::Accounting::ItemSalesTaxRate.from_json(json_object: sales_tax_rate)
  end
  remote_updated_at = unless parsed_json["remote_updated_at"].nil?
                        DateTime.parse(parsed_json["remote_updated_at"])
                      end
  remote_was_deleted = parsed_json["remote_was_deleted"]
  field_mappings = parsed_json["field_mappings"]
  remote_data = parsed_json["remote_data"]&.map do |item|
    item = item.to_json
    Merge::Accounting::RemoteData.from_json(json_object: item)
  end
  new(
    id: id,
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    name: name,
    status: status,
    type: type,
    unit_price: unit_price,
    purchase_price: purchase_price,
    purchase_account: ,
    sales_account: ,
    company: company,
    purchase_tax_rate: purchase_tax_rate,
    sales_tax_rate: sales_tax_rate,
    remote_updated_at: remote_updated_at,
    remote_was_deleted: remote_was_deleted,
    field_mappings: field_mappings,
    remote_data: remote_data,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 241

def self.validate_raw(obj:)
  obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.status&.is_a?(Merge::Accounting::Status7D1Enum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.")
  obj.type&.is_a?(Merge::Accounting::Type2BbEnum) != false || raise("Passed value for field obj.type is not the expected type, validation failed.")
  obj.unit_price&.is_a?(Float) != false || raise("Passed value for field obj.unit_price is not the expected type, validation failed.")
  obj.purchase_price&.is_a?(Float) != false || raise("Passed value for field obj.purchase_price is not the expected type, validation failed.")
  obj..nil? || Merge::Accounting::ItemPurchaseAccount.validate_raw(obj: obj.)
  obj..nil? || Merge::Accounting::ItemSalesAccount.validate_raw(obj: obj.)
  obj.company.nil? || Merge::Accounting::ItemCompany.validate_raw(obj: obj.company)
  obj.purchase_tax_rate.nil? || Merge::Accounting::ItemPurchaseTaxRate.validate_raw(obj: obj.purchase_tax_rate)
  obj.sales_tax_rate.nil? || Merge::Accounting::ItemSalesTaxRate.validate_raw(obj: obj.sales_tax_rate)
  obj.remote_updated_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_updated_at is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
  obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.")
  obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Item to a JSON object



231
232
233
# File 'lib/merge_ruby_client/accounting/types/item.rb', line 231

def to_json(*_args)
  @_field_set&.to_json
end