Class: Merge::Accounting::JournalEntry
- Inherits:
-
Object
- Object
- Merge::Accounting::JournalEntry
- Defined in:
- lib/merge_ruby_client/accounting/types/journal_entry.rb
Overview
The JournalEntry Object
Description
A JournalEntry is a record of a transaction or event that is entered into a
company's accounting system.
The JournalEntry common model contains records that are automatically created
as a result of a certain type of transaction, like an Invoice, and records that
are manually created against a company’s ledger.
The lines of a given JournalEntry object should always sum to 0. A positive
net_amount means the line represents a debit and a negative net_amount
represents a credit.
Usage Example
Fetch from the GET JournalEntry endpoint and view a company's journey entry.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#accounting_period ⇒ Merge::Accounting::JournalEntryAccountingPeriod
readonly
The accounting period that the JournalEntry was generated in.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#applied_payments ⇒ Array<Merge::Accounting::JournalEntryAppliedPaymentsItem>
readonly
A list of the Payment Applied to Lines common models related to a given Invoice, Credit Note, or Journal Entry.
-
#company ⇒ Merge::Accounting::JournalEntryCompany
readonly
The company the journal entry belongs to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The journal's currency.
-
#exchange_rate ⇒ String
readonly
The journal entry's exchange rate.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
-
#inclusive_of_tax ⇒ Boolean
readonly
If the transaction is inclusive or exclusive of tax.
-
#journal_number ⇒ String
readonly
Reference number for identifying journal entries.
- #lines ⇒ Array<Merge::Accounting::JournalLine> readonly
-
#memo ⇒ String
readonly
The journal entry's private note.
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#payments ⇒ Array<Merge::Accounting::JournalEntryPaymentsItem>
readonly
Array of
Paymentobject IDs. -
#posting_status ⇒ Merge::Accounting::PostingStatusEnum
readonly
The journal's posting status.
-
#remote_created_at ⇒ DateTime
readonly
When the third party's journal entry was created.
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_updated_at ⇒ DateTime
readonly
When the third party's journal entry was updated.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
- #tracking_categories ⇒ Array<Merge::Accounting::JournalEntryTrackingCategoriesItem> readonly
-
#transaction_date ⇒ DateTime
readonly
The journal entry's transaction date.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::JournalEntry
Deserialize a JSON object to an instance of JournalEntry.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_date: OMIT, payments: OMIT, applied_payments: OMIT, memo: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, inclusive_of_tax: OMIT, lines: OMIT, journal_number: OMIT, tracking_categories: OMIT, remote_was_deleted: OMIT, posting_status: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::JournalEntry constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of JournalEntry to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_date: OMIT, payments: OMIT, applied_payments: OMIT, memo: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, inclusive_of_tax: OMIT, lines: OMIT, journal_number: OMIT, tracking_categories: OMIT, remote_was_deleted: OMIT, posting_status: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::JournalEntry
737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 737 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_date: OMIT, payments: OMIT, applied_payments: OMIT, memo: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, inclusive_of_tax: OMIT, lines: OMIT, journal_number: OMIT, tracking_categories: OMIT, remote_was_deleted: OMIT, posting_status: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @transaction_date = transaction_date if transaction_date != OMIT @payments = payments if payments != OMIT @applied_payments = applied_payments if applied_payments != OMIT @memo = memo if memo != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @company = company if company != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @lines = lines if lines != OMIT @journal_number = journal_number if journal_number != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @posting_status = posting_status if posting_status != OMIT @accounting_period = accounting_period if accounting_period != OMIT @remote_created_at = remote_created_at if remote_created_at != OMIT @remote_updated_at = remote_updated_at if remote_updated_at != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "transaction_date": transaction_date, "payments": payments, "applied_payments": applied_payments, "memo": memo, "currency": currency, "exchange_rate": exchange_rate, "company": company, "inclusive_of_tax": inclusive_of_tax, "lines": lines, "journal_number": journal_number, "tracking_categories": tracking_categories, "remote_was_deleted": remote_was_deleted, "posting_status": posting_status, "accounting_period": accounting_period, "remote_created_at": remote_created_at, "remote_updated_at": remote_updated_at, "field_mappings": field_mappings, "remote_data": remote_data, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#accounting_period ⇒ Merge::Accounting::JournalEntryAccountingPeriod (readonly)
Returns The accounting period that the JournalEntry was generated in.
380 381 382 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 380 def accounting_period @accounting_period end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
392 393 394 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 392 def additional_properties @additional_properties end |
#applied_payments ⇒ Array<Merge::Accounting::JournalEntryAppliedPaymentsItem> (readonly)
Returns A list of the Payment Applied to Lines common models related to a given Invoice, Credit Note, or Journal Entry.
46 47 48 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 46 def applied_payments @applied_payments end |
#company ⇒ Merge::Accounting::JournalEntryCompany (readonly)
Returns The company the journal entry belongs to.
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 360 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 37 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The journal's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 356 def currency @currency end |
#exchange_rate ⇒ String (readonly)
Returns The journal entry's exchange rate.
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 358 def exchange_rate @exchange_rate end |
#field_mappings ⇒ Hash{String => Object} (readonly)
386 387 388 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 386 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 33 def id @id end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns If the transaction is inclusive or exclusive of tax. True if inclusive,
False if exclusive.
363 364 365 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 363 def inclusive_of_tax @inclusive_of_tax end |
#journal_number ⇒ String (readonly)
Returns Reference number for identifying journal entries.
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 367 def journal_number @journal_number end |
#lines ⇒ Array<Merge::Accounting::JournalLine> (readonly)
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 365 def lines @lines end |
#memo ⇒ String (readonly)
Returns The journal entry's private note.
48 49 50 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 48 def memo @memo end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 39 def modified_at @modified_at end |
#payments ⇒ Array<Merge::Accounting::JournalEntryPaymentsItem> (readonly)
Returns Array of Payment object IDs.
43 44 45 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 43 def payments @payments end |
#posting_status ⇒ Merge::Accounting::PostingStatusEnum (readonly)
Returns The journal's posting status.
UNPOSTED- UNPOSTEDPOSTED- POSTED.
378 379 380 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 378 def posting_status @posting_status end |
#remote_created_at ⇒ DateTime (readonly)
Returns When the third party's journal entry was created.
382 383 384 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 382 def remote_created_at @remote_created_at end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
388 389 390 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 388 def remote_data @remote_data end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
390 391 392 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 390 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 35 def remote_id @remote_id end |
#remote_updated_at ⇒ DateTime (readonly)
Returns When the third party's journal entry was updated.
384 385 386 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 384 def remote_updated_at @remote_updated_at end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
374 375 376 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 374 def remote_was_deleted @remote_was_deleted end |
#tracking_categories ⇒ Array<Merge::Accounting::JournalEntryTrackingCategoriesItem> (readonly)
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 369 def tracking_categories @tracking_categories end |
#transaction_date ⇒ DateTime (readonly)
Returns The journal entry's transaction date.
41 42 43 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 41 def transaction_date @transaction_date end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::JournalEntry
Deserialize a JSON object to an instance of JournalEntry
796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 796 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) transaction_date = (DateTime.parse(parsed_json["transaction_date"]) unless parsed_json["transaction_date"].nil?) payments = parsed_json["payments"]&.map do |item| item = item.to_json Merge::Accounting::JournalEntryPaymentsItem.from_json(json_object: item) end applied_payments = parsed_json["applied_payments"]&.map do |item| item = item.to_json Merge::Accounting::JournalEntryAppliedPaymentsItem.from_json(json_object: item) end memo = parsed_json["memo"] currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::JournalEntryCompany.from_json(json_object: company) end inclusive_of_tax = parsed_json["inclusive_of_tax"] lines = parsed_json["lines"]&.map do |item| item = item.to_json Merge::Accounting::JournalLine.from_json(json_object: item) end journal_number = parsed_json["journal_number"] tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::JournalEntryTrackingCategoriesItem.from_json(json_object: item) end remote_was_deleted = parsed_json["remote_was_deleted"] posting_status = parsed_json["posting_status"] if parsed_json["accounting_period"].nil? accounting_period = nil else accounting_period = parsed_json["accounting_period"].to_json accounting_period = Merge::Accounting::JournalEntryAccountingPeriod.from_json(json_object: accounting_period) end remote_created_at = unless parsed_json["remote_created_at"].nil? DateTime.parse(parsed_json["remote_created_at"]) end remote_updated_at = unless parsed_json["remote_updated_at"].nil? DateTime.parse(parsed_json["remote_updated_at"]) end field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, transaction_date: transaction_date, payments: payments, applied_payments: applied_payments, memo: memo, currency: currency, exchange_rate: exchange_rate, company: company, inclusive_of_tax: inclusive_of_tax, lines: lines, journal_number: journal_number, tracking_categories: tracking_categories, remote_was_deleted: remote_was_deleted, posting_status: posting_status, accounting_period: accounting_period, remote_created_at: remote_created_at, remote_updated_at: remote_updated_at, field_mappings: field_mappings, remote_data: remote_data, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 895 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.transaction_date&.is_a?(DateTime) != false || raise("Passed value for field obj.transaction_date is not the expected type, validation failed.") obj.payments&.is_a?(Array) != false || raise("Passed value for field obj.payments is not the expected type, validation failed.") obj.applied_payments&.is_a?(Array) != false || raise("Passed value for field obj.applied_payments is not the expected type, validation failed.") obj.memo&.is_a?(String) != false || raise("Passed value for field obj.memo is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::JournalEntryCompany.validate_raw(obj: obj.company) obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.lines&.is_a?(Array) != false || raise("Passed value for field obj.lines is not the expected type, validation failed.") obj.journal_number&.is_a?(String) != false || raise("Passed value for field obj.journal_number is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.posting_status&.is_a?(Merge::Accounting::PostingStatusEnum) != false || raise("Passed value for field obj.posting_status is not the expected type, validation failed.") obj.accounting_period.nil? || Merge::Accounting::JournalEntryAccountingPeriod.validate_raw(obj: obj.accounting_period) obj.remote_created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_created_at is not the expected type, validation failed.") obj.remote_updated_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_updated_at is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of JournalEntry to a JSON object
885 886 887 |
# File 'lib/merge_ruby_client/accounting/types/journal_entry.rb', line 885 def to_json(*_args) @_field_set&.to_json end |