Class: Merge::Accounting::JournalLine
- Inherits:
-
Object
- Object
- Merge::Accounting::JournalLine
- Defined in:
- lib/merge_ruby_client/accounting/types/journal_line.rb
Overview
The JournalLine Object
Description
The JournalLine object is used to represent a journal entry's line items.
Usage Example
Fetch from the GET JournalEntry endpoint and view the journal entry's line
items.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
- #account ⇒ Merge::Accounting::JournalLineAccount readonly
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the journal entry belongs to.
- #contact ⇒ String readonly
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The journal line item's currency.
-
#description ⇒ String
readonly
The line's description.
- #employee ⇒ String readonly
-
#exchange_rate ⇒ String
readonly
The journal line item's exchange rate.
- #id ⇒ String readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#net_amount ⇒ Float
readonly
The value of the line item including taxes and other fees.
- #project ⇒ Merge::Accounting::JournalLineProject readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#tracking_categories ⇒ Array<Merge::Accounting::JournalLineTrackingCategoriesItem>
readonly
The journal line item's associated tracking categories.
- #tracking_category ⇒ Merge::Accounting::JournalLineTrackingCategory readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::JournalLine
Deserialize a JSON object to an instance of JournalLine.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, currency: OMIT, company: OMIT, employee: OMIT, project: OMIT, contact: OMIT, tax_rate: OMIT, description: OMIT, exchange_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::JournalLine constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of JournalLine to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, currency: OMIT, company: OMIT, employee: OMIT, project: OMIT, contact: OMIT, tax_rate: OMIT, description: OMIT, exchange_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::JournalLine
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 704 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, account: OMIT, net_amount: OMIT, tracking_category: OMIT, tracking_categories: OMIT, currency: OMIT, company: OMIT, employee: OMIT, project: OMIT, contact: OMIT, tax_rate: OMIT, description: OMIT, exchange_rate: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @account = account if account != OMIT @net_amount = net_amount if net_amount != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @currency = currency if currency != OMIT @company = company if company != OMIT @employee = employee if employee != OMIT @project = project if project != OMIT @contact = contact if contact != OMIT @tax_rate = tax_rate if tax_rate != OMIT @description = description if description != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "account": account, "net_amount": net_amount, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "currency": currency, "company": company, "employee": employee, "project": project, "contact": contact, "tax_rate": tax_rate, "description": description, "exchange_rate": exchange_rate, "remote_was_deleted": remote_was_deleted, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::JournalLineAccount (readonly)
31 32 33 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 31 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
368 369 370 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 368 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
Returns The company the journal entry belongs to.
347 348 349 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 347 def company @company end |
#contact ⇒ String (readonly)
353 354 355 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 353 def contact @contact end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
27 28 29 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 27 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The journal line item's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
345 346 347 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 345 def currency @currency end |
#description ⇒ String (readonly)
Returns The line's description.
357 358 359 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 357 def description @description end |
#employee ⇒ String (readonly)
349 350 351 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 349 def employee @employee end |
#exchange_rate ⇒ String (readonly)
Returns The journal line item's exchange rate.
359 360 361 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 359 def exchange_rate @exchange_rate end |
#id ⇒ String (readonly)
23 24 25 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 23 def id @id end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
29 30 31 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 29 def modified_at @modified_at end |
#net_amount ⇒ Float (readonly)
Returns The value of the line item including taxes and other fees.
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 33 def net_amount @net_amount end |
#project ⇒ Merge::Accounting::JournalLineProject (readonly)
351 352 353 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 351 def project @project end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
366 367 368 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 366 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
25 26 27 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 25 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
364 365 366 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 364 def remote_was_deleted @remote_was_deleted end |
#tax_rate ⇒ String (readonly)
Returns The tax rate that applies to this line item.
355 356 357 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 355 def tax_rate @tax_rate end |
#tracking_categories ⇒ Array<Merge::Accounting::JournalLineTrackingCategoriesItem> (readonly)
Returns The journal line item's associated tracking categories.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 37 def tracking_categories @tracking_categories end |
#tracking_category ⇒ Merge::Accounting::JournalLineTrackingCategory (readonly)
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 35 def tracking_category @tracking_category end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::JournalLine
Deserialize a JSON object to an instance of JournalLine
753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 753 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::JournalLineAccount.from_json(json_object: account) end net_amount = parsed_json["net_amount"] if parsed_json["tracking_category"].nil? tracking_category = nil else tracking_category = parsed_json["tracking_category"].to_json tracking_category = Merge::Accounting::JournalLineTrackingCategory.from_json(json_object: tracking_category) end tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::JournalLineTrackingCategoriesItem.from_json(json_object: item) end currency = parsed_json["currency"] company = parsed_json["company"] employee = parsed_json["employee"] if parsed_json["project"].nil? project = nil else project = parsed_json["project"].to_json project = Merge::Accounting::JournalLineProject.from_json(json_object: project) end contact = parsed_json["contact"] tax_rate = parsed_json["tax_rate"] description = parsed_json["description"] exchange_rate = parsed_json["exchange_rate"] remote_was_deleted = parsed_json["remote_was_deleted"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, account: account, net_amount: net_amount, tracking_category: tracking_category, tracking_categories: tracking_categories, currency: currency, company: company, employee: employee, project: project, contact: contact, tax_rate: tax_rate, description: description, exchange_rate: exchange_rate, remote_was_deleted: remote_was_deleted, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 831 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.account.nil? || Merge::Accounting::JournalLineAccount.validate_raw(obj: obj.account) obj.net_amount&.is_a?(Float) != false || raise("Passed value for field obj.net_amount is not the expected type, validation failed.") obj.tracking_category.nil? || Merge::Accounting::JournalLineTrackingCategory.validate_raw(obj: obj.tracking_category) obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.employee&.is_a?(String) != false || raise("Passed value for field obj.employee is not the expected type, validation failed.") obj.project.nil? || Merge::Accounting::JournalLineProject.validate_raw(obj: obj.project) obj.contact&.is_a?(String) != false || raise("Passed value for field obj.contact is not the expected type, validation failed.") obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of JournalLine to a JSON object
821 822 823 |
# File 'lib/merge_ruby_client/accounting/types/journal_line.rb', line 821 def to_json(*_args) @_field_set&.to_json end |