Class: Merge::Accounting::PurchaseOrder
- Inherits:
-
Object
- Object
- Merge::Accounting::PurchaseOrder
- Defined in:
- lib/merge_ruby_client/accounting/types/purchase_order.rb
Overview
The PurchaseOrder Object
Description
A PurchaseOrder represents a request to purchase goods or services from a
vendor. It outlines the details of the purchase, such as the items or services
requested, quantities, prices, and delivery details.
A PurchaseOrder is a crucial component of the procurement process, but does
not typically result in any impact on the company’s general ledger. The general
ledger is typically only affected when the PurchaseOrder is fulfilled as an
Accounts Payable Invoice object (also known as a Bill).
Usage Example
Fetch from the LIST PurchaseOrders endpoint and view a company's purchase
orders.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#accounting_period ⇒ Merge::Accounting::PurchaseOrderAccountingPeriod
readonly
The accounting period that the PurchaseOrder was generated in.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ Merge::Accounting::PurchaseOrderCompany
readonly
The company the purchase order belongs to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The purchase order's currency.
-
#customer ⇒ String
readonly
The contact making the purchase order.
-
#delivery_address ⇒ Merge::Accounting::PurchaseOrderDeliveryAddress
readonly
The purchase order's delivery address.
-
#delivery_date ⇒ DateTime
readonly
The purchase order's delivery date.
-
#exchange_rate ⇒ String
readonly
The purchase order's exchange rate.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
-
#inclusive_of_tax ⇒ Boolean
readonly
If the transaction is inclusive or exclusive of tax.
-
#issue_date ⇒ DateTime
readonly
The purchase order's issue date.
- #line_items ⇒ Array<Merge::Accounting::PurchaseOrderLineItem> readonly
-
#memo ⇒ String
readonly
A memo attached to the purchase order.
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#payment_term ⇒ Merge::Accounting::PurchaseOrderPaymentTerm
readonly
The payment term that applies to this transaction.
-
#purchase_order_number ⇒ String
readonly
The human-readable number of the purchase order.
-
#remote_created_at ⇒ DateTime
readonly
When the third party's purchase order note was created.
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_updated_at ⇒ DateTime
readonly
When the third party's purchase order note was updated.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#status ⇒ Merge::Accounting::PurchaseOrderStatusEnum
readonly
The purchase order's status.
-
#total_amount ⇒ Float
readonly
The purchase order's total amount.
- #tracking_categories ⇒ Array<Merge::Accounting::PurchaseOrderTrackingCategoriesItem> readonly
-
#vendor ⇒ Merge::Accounting::PurchaseOrderVendor
readonly
The party fulfilling the purchase order.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrder
Deserialize a JSON object to an instance of PurchaseOrder.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, status: OMIT, issue_date: OMIT, purchase_order_number: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, payment_term: OMIT, line_items: OMIT, inclusive_of_tax: OMIT, tracking_categories: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrder constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrder to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, status: OMIT, issue_date: OMIT, purchase_order_number: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, payment_term: OMIT, line_items: OMIT, inclusive_of_tax: OMIT, tracking_categories: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrder
754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 754 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, status: OMIT, issue_date: OMIT, purchase_order_number: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, payment_term: OMIT, line_items: OMIT, inclusive_of_tax: OMIT, tracking_categories: OMIT, accounting_period: OMIT, remote_created_at: OMIT, remote_updated_at: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @status = status if status != OMIT @issue_date = issue_date if issue_date != OMIT @purchase_order_number = purchase_order_number if purchase_order_number != OMIT @delivery_date = delivery_date if delivery_date != OMIT @delivery_address = delivery_address if delivery_address != OMIT @customer = customer if customer != OMIT @vendor = vendor if vendor != OMIT @memo = memo if memo != OMIT @company = company if company != OMIT @total_amount = total_amount if total_amount != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @payment_term = payment_term if payment_term != OMIT @line_items = line_items if line_items != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @accounting_period = accounting_period if accounting_period != OMIT @remote_created_at = remote_created_at if remote_created_at != OMIT @remote_updated_at = remote_updated_at if remote_updated_at != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "status": status, "issue_date": issue_date, "purchase_order_number": purchase_order_number, "delivery_date": delivery_date, "delivery_address": delivery_address, "customer": customer, "vendor": vendor, "memo": memo, "company": company, "total_amount": total_amount, "currency": currency, "exchange_rate": exchange_rate, "payment_term": payment_term, "line_items": line_items, "inclusive_of_tax": inclusive_of_tax, "tracking_categories": tracking_categories, "accounting_period": accounting_period, "remote_created_at": remote_created_at, "remote_updated_at": remote_updated_at, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_data": remote_data, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#accounting_period ⇒ Merge::Accounting::PurchaseOrderAccountingPeriod (readonly)
Returns The accounting period that the PurchaseOrder was generated in.
386 387 388 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 386 def accounting_period @accounting_period end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
403 404 405 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 403 def additional_properties @additional_properties end |
#company ⇒ Merge::Accounting::PurchaseOrderCompany (readonly)
Returns The company the purchase order belongs to.
63 64 65 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 63 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 38 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The purchase order's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 373 def currency @currency end |
#customer ⇒ String (readonly)
Returns The contact making the purchase order.
57 58 59 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 57 def customer @customer end |
#delivery_address ⇒ Merge::Accounting::PurchaseOrderDeliveryAddress (readonly)
Returns The purchase order's delivery address.
55 56 57 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 55 def delivery_address @delivery_address end |
#delivery_date ⇒ DateTime (readonly)
Returns The purchase order's delivery date.
53 54 55 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 53 def delivery_date @delivery_date end |
#exchange_rate ⇒ String (readonly)
Returns The purchase order's exchange rate.
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 375 def exchange_rate @exchange_rate end |
#field_mappings ⇒ Hash{String => Object} (readonly)
397 398 399 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 397 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 34 def id @id end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns If the transaction is inclusive or exclusive of tax. True if inclusive,
False if exclusive.
382 383 384 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 382 def inclusive_of_tax @inclusive_of_tax end |
#issue_date ⇒ DateTime (readonly)
Returns The purchase order's issue date.
49 50 51 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 49 def issue_date @issue_date end |
#line_items ⇒ Array<Merge::Accounting::PurchaseOrderLineItem> (readonly)
379 380 381 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 379 def line_items @line_items end |
#memo ⇒ String (readonly)
Returns A memo attached to the purchase order.
61 62 63 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 61 def memo @memo end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 40 def modified_at @modified_at end |
#payment_term ⇒ Merge::Accounting::PurchaseOrderPaymentTerm (readonly)
Returns The payment term that applies to this transaction.
377 378 379 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 377 def payment_term @payment_term end |
#purchase_order_number ⇒ String (readonly)
Returns The human-readable number of the purchase order.
51 52 53 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 51 def purchase_order_number @purchase_order_number end |
#remote_created_at ⇒ DateTime (readonly)
Returns When the third party's purchase order note was created.
388 389 390 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 388 def remote_created_at @remote_created_at end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
399 400 401 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 399 def remote_data @remote_data end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
401 402 403 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 401 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 36 def remote_id @remote_id end |
#remote_updated_at ⇒ DateTime (readonly)
Returns When the third party's purchase order note was updated.
390 391 392 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 390 def remote_updated_at @remote_updated_at end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
395 396 397 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 395 def remote_was_deleted @remote_was_deleted end |
#status ⇒ Merge::Accounting::PurchaseOrderStatusEnum (readonly)
Returns The purchase order's status.
DRAFT- DRAFTSUBMITTED- SUBMITTEDAUTHORIZED- AUTHORIZEDBILLED- BILLEDDELETED- DELETED.
47 48 49 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 47 def status @status end |
#total_amount ⇒ Float (readonly)
Returns The purchase order's total amount.
65 66 67 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 65 def total_amount @total_amount end |
#tracking_categories ⇒ Array<Merge::Accounting::PurchaseOrderTrackingCategoriesItem> (readonly)
384 385 386 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 384 def tracking_categories @tracking_categories end |
#vendor ⇒ Merge::Accounting::PurchaseOrderVendor (readonly)
Returns The party fulfilling the purchase order.
59 60 61 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 59 def vendor @vendor end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrder
Deserialize a JSON object to an instance of PurchaseOrder
821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 821 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) status = parsed_json["status"] issue_date = (DateTime.parse(parsed_json["issue_date"]) unless parsed_json["issue_date"].nil?) purchase_order_number = parsed_json["purchase_order_number"] delivery_date = (DateTime.parse(parsed_json["delivery_date"]) unless parsed_json["delivery_date"].nil?) if parsed_json["delivery_address"].nil? delivery_address = nil else delivery_address = parsed_json["delivery_address"].to_json delivery_address = Merge::Accounting::PurchaseOrderDeliveryAddress.from_json(json_object: delivery_address) end customer = parsed_json["customer"] if parsed_json["vendor"].nil? vendor = nil else vendor = parsed_json["vendor"].to_json vendor = Merge::Accounting::PurchaseOrderVendor.from_json(json_object: vendor) end memo = parsed_json["memo"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::PurchaseOrderCompany.from_json(json_object: company) end total_amount = parsed_json["total_amount"] currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] if parsed_json["payment_term"].nil? payment_term = nil else payment_term = parsed_json["payment_term"].to_json payment_term = Merge::Accounting::PurchaseOrderPaymentTerm.from_json(json_object: payment_term) end line_items = parsed_json["line_items"]&.map do |item| item = item.to_json Merge::Accounting::PurchaseOrderLineItem.from_json(json_object: item) end inclusive_of_tax = parsed_json["inclusive_of_tax"] tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::PurchaseOrderTrackingCategoriesItem.from_json(json_object: item) end if parsed_json["accounting_period"].nil? accounting_period = nil else accounting_period = parsed_json["accounting_period"].to_json accounting_period = Merge::Accounting::PurchaseOrderAccountingPeriod.from_json(json_object: accounting_period) end remote_created_at = unless parsed_json["remote_created_at"].nil? DateTime.parse(parsed_json["remote_created_at"]) end remote_updated_at = unless parsed_json["remote_updated_at"].nil? DateTime.parse(parsed_json["remote_updated_at"]) end remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, status: status, issue_date: issue_date, purchase_order_number: purchase_order_number, delivery_date: delivery_date, delivery_address: delivery_address, customer: customer, vendor: vendor, memo: memo, company: company, total_amount: total_amount, currency: currency, exchange_rate: exchange_rate, payment_term: payment_term, line_items: line_items, inclusive_of_tax: inclusive_of_tax, tracking_categories: tracking_categories, accounting_period: accounting_period, remote_created_at: remote_created_at, remote_updated_at: remote_updated_at, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_data: remote_data, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 937 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.status&.is_a?(Merge::Accounting::PurchaseOrderStatusEnum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.issue_date&.is_a?(DateTime) != false || raise("Passed value for field obj.issue_date is not the expected type, validation failed.") obj.purchase_order_number&.is_a?(String) != false || raise("Passed value for field obj.purchase_order_number is not the expected type, validation failed.") obj.delivery_date&.is_a?(DateTime) != false || raise("Passed value for field obj.delivery_date is not the expected type, validation failed.") obj.delivery_address.nil? || Merge::Accounting::PurchaseOrderDeliveryAddress.validate_raw(obj: obj.delivery_address) obj.customer&.is_a?(String) != false || raise("Passed value for field obj.customer is not the expected type, validation failed.") obj.vendor.nil? || Merge::Accounting::PurchaseOrderVendor.validate_raw(obj: obj.vendor) obj.memo&.is_a?(String) != false || raise("Passed value for field obj.memo is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::PurchaseOrderCompany.validate_raw(obj: obj.company) obj.total_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.payment_term.nil? || Merge::Accounting::PurchaseOrderPaymentTerm.validate_raw(obj: obj.payment_term) obj.line_items&.is_a?(Array) != false || raise("Passed value for field obj.line_items is not the expected type, validation failed.") obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.accounting_period.nil? || Merge::Accounting::PurchaseOrderAccountingPeriod.validate_raw(obj: obj.accounting_period) obj.remote_created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_created_at is not the expected type, validation failed.") obj.remote_updated_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_updated_at is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrder to a JSON object
927 928 929 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order.rb', line 927 def to_json(*_args) @_field_set&.to_json end |