Class: Merge::Accounting::PurchaseOrderLineItem
- Inherits:
-
Object
- Object
- Merge::Accounting::PurchaseOrderLineItem
- Defined in:
- lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb
Overview
The PurchaseOrderLineItem Object
Description
The PurchaseOrderLineItem object is used to represent a purchase order's line
item.
Usage Example
Fetch from the GET PurchaseOrder endpoint and view a company's purchase
orders.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account ⇒ String
readonly
The purchase order line item's account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the purchase order line item belongs to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The purchase order line item's currency.
-
#description ⇒ String
readonly
A description of the good being purchased.
-
#exchange_rate ⇒ String
readonly
The purchase order line item's exchange rate.
- #id ⇒ String readonly
- #item ⇒ Merge::Accounting::PurchaseOrderLineItemItem readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#quantity ⇒ Float
readonly
The line item's quantity.
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#tax_amount ⇒ String
readonly
The purchase order line item's tax amount.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#total_line_amount ⇒ String
readonly
The purchase order line item's total amount.
-
#tracking_categories ⇒ Array<String>
readonly
The purchase order line item's associated tracking categories.
-
#tracking_category ⇒ String
readonly
The purchase order line item's associated tracking category.
-
#unit_price ⇒ Float
readonly
The line item's unit price.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderLineItem
Deserialize a JSON object to an instance of PurchaseOrderLineItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderLineItem constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderLineItem to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderLineItem
705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 705 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, remote_was_deleted: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @description = description if description != OMIT @unit_price = unit_price if unit_price != OMIT @quantity = quantity if quantity != OMIT @item = item if item != OMIT @account = account if account != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @tax_amount = tax_amount if tax_amount != OMIT @total_line_amount = total_line_amount if total_line_amount != OMIT @currency = currency if currency != OMIT @tax_rate = tax_rate if tax_rate != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @company = company if company != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "description": description, "unit_price": unit_price, "quantity": quantity, "item": item, "account": account, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "tax_amount": tax_amount, "total_line_amount": total_line_amount, "currency": currency, "tax_rate": tax_rate, "exchange_rate": exchange_rate, "company": company, "remote_was_deleted": remote_was_deleted, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ String (readonly)
Returns The purchase order line item's account.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 37 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
368 369 370 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 368 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
Returns The company the purchase order line item belongs to.
359 360 361 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 359 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
25 26 27 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 25 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The purchase order line item's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
353 354 355 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 353 def currency @currency end |
#description ⇒ String (readonly)
Returns A description of the good being purchased.
29 30 31 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 29 def description @description end |
#exchange_rate ⇒ String (readonly)
Returns The purchase order line item's exchange rate.
357 358 359 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 357 def exchange_rate @exchange_rate end |
#id ⇒ String (readonly)
21 22 23 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 21 def id @id end |
#item ⇒ Merge::Accounting::PurchaseOrderLineItemItem (readonly)
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 35 def item @item end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
27 28 29 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 27 def modified_at @modified_at end |
#quantity ⇒ Float (readonly)
Returns The line item's quantity.
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 33 def quantity @quantity end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
366 367 368 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 366 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
23 24 25 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 23 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
364 365 366 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 364 def remote_was_deleted @remote_was_deleted end |
#tax_amount ⇒ String (readonly)
Returns The purchase order line item's tax amount.
43 44 45 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 43 def tax_amount @tax_amount end |
#tax_rate ⇒ String (readonly)
Returns The tax rate that applies to this line item.
355 356 357 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 355 def tax_rate @tax_rate end |
#total_line_amount ⇒ String (readonly)
Returns The purchase order line item's total amount.
45 46 47 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 45 def total_line_amount @total_line_amount end |
#tracking_categories ⇒ Array<String> (readonly)
Returns The purchase order line item's associated tracking categories.
41 42 43 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 41 def tracking_categories @tracking_categories end |
#tracking_category ⇒ String (readonly)
Returns The purchase order line item's associated tracking category.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 39 def tracking_category @tracking_category end |
#unit_price ⇒ Float (readonly)
Returns The line item's unit price.
31 32 33 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 31 def unit_price @unit_price end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderLineItem
Deserialize a JSON object to an instance of PurchaseOrderLineItem
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 756 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) description = parsed_json["description"] unit_price = parsed_json["unit_price"] quantity = parsed_json["quantity"] if parsed_json["item"].nil? item = nil else item = parsed_json["item"].to_json item = Merge::Accounting::PurchaseOrderLineItemItem.from_json(json_object: item) end account = parsed_json["account"] tracking_category = parsed_json["tracking_category"] tracking_categories = parsed_json["tracking_categories"] tax_amount = parsed_json["tax_amount"] total_line_amount = parsed_json["total_line_amount"] currency = parsed_json["currency"] tax_rate = parsed_json["tax_rate"] exchange_rate = parsed_json["exchange_rate"] company = parsed_json["company"] remote_was_deleted = parsed_json["remote_was_deleted"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, description: description, unit_price: unit_price, quantity: quantity, item: item, account: account, tracking_category: tracking_category, tracking_categories: tracking_categories, tax_amount: tax_amount, total_line_amount: total_line_amount, currency: currency, tax_rate: tax_rate, exchange_rate: exchange_rate, company: company, remote_was_deleted: remote_was_deleted, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 823 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.unit_price&.is_a?(Float) != false || raise("Passed value for field obj.unit_price is not the expected type, validation failed.") obj.quantity&.is_a?(Float) != false || raise("Passed value for field obj.quantity is not the expected type, validation failed.") obj.item.nil? || Merge::Accounting::PurchaseOrderLineItemItem.validate_raw(obj: obj.item) obj.account&.is_a?(String) != false || raise("Passed value for field obj.account is not the expected type, validation failed.") obj.tracking_category&.is_a?(String) != false || raise("Passed value for field obj.tracking_category is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.tax_amount&.is_a?(String) != false || raise("Passed value for field obj.tax_amount is not the expected type, validation failed.") obj.total_line_amount&.is_a?(String) != false || raise("Passed value for field obj.total_line_amount is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderLineItem to a JSON object
813 814 815 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item.rb', line 813 def to_json(*_args) @_field_set&.to_json end |