Class: Merge::Accounting::PurchaseOrderLineItemRequest
- Inherits:
-
Object
- Object
- Merge::Accounting::PurchaseOrderLineItemRequest
- Defined in:
- lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb
Overview
The PurchaseOrderLineItem Object
Description
The PurchaseOrderLineItem object is used to represent a purchase order's line
item.
Usage Example
Fetch from the GET PurchaseOrder endpoint and view a company's purchase
orders.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account ⇒ String
readonly
The purchase order line item's account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the purchase order line item belongs to.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The purchase order line item's currency.
-
#description ⇒ String
readonly
A description of the good being purchased.
-
#exchange_rate ⇒ String
readonly
The purchase order line item's exchange rate.
- #integration_params ⇒ Hash{String => Object} readonly
- #item ⇒ Merge::Accounting::PurchaseOrderLineItemRequestItem readonly
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#quantity ⇒ Float
readonly
The line item's quantity.
- #remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#tax_amount ⇒ String
readonly
The purchase order line item's tax amount.
-
#tax_rate ⇒ String
readonly
The tax rate that applies to this line item.
-
#total_line_amount ⇒ String
readonly
The purchase order line item's total amount.
-
#tracking_categories ⇒ Array<String>
readonly
The purchase order line item's associated tracking categories.
-
#tracking_category ⇒ String
readonly
The purchase order line item's associated tracking category.
-
#unit_price ⇒ Float
readonly
The line item's unit price.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderLineItemRequest
Deserialize a JSON object to an instance of PurchaseOrderLineItemRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(remote_id: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderLineItemRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderLineItemRequest to a JSON object.
Constructor Details
#initialize(remote_id: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderLineItemRequest
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 692 def initialize(remote_id: OMIT, description: OMIT, unit_price: OMIT, quantity: OMIT, item: OMIT, account: OMIT, tracking_category: OMIT, tracking_categories: OMIT, tax_amount: OMIT, total_line_amount: OMIT, currency: OMIT, tax_rate: OMIT, exchange_rate: OMIT, company: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) @remote_id = remote_id if remote_id != OMIT @description = description if description != OMIT @unit_price = unit_price if unit_price != OMIT @quantity = quantity if quantity != OMIT @item = item if item != OMIT @account = account if account != OMIT @tracking_category = tracking_category if tracking_category != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @tax_amount = tax_amount if tax_amount != OMIT @total_line_amount = total_line_amount if total_line_amount != OMIT @currency = currency if currency != OMIT @tax_rate = tax_rate if tax_rate != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @company = company if company != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "remote_id": remote_id, "description": description, "unit_price": unit_price, "quantity": quantity, "item": item, "account": account, "tracking_category": tracking_category, "tracking_categories": tracking_categories, "tax_amount": tax_amount, "total_line_amount": total_line_amount, "currency": currency, "tax_rate": tax_rate, "exchange_rate": exchange_rate, "company": company, "integration_params": integration_params, "linked_account_params": linked_account_params, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ String (readonly)
Returns The purchase order line item's account.
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 30 def account @account end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 360 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
Returns The company the purchase order line item belongs to.
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 352 def company @company end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The purchase order line item's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
346 347 348 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 346 def currency @currency end |
#description ⇒ String (readonly)
Returns A description of the good being purchased.
22 23 24 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 22 def description @description end |
#exchange_rate ⇒ String (readonly)
Returns The purchase order line item's exchange rate.
350 351 352 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 350 def exchange_rate @exchange_rate end |
#integration_params ⇒ Hash{String => Object} (readonly)
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 354 def integration_params @integration_params end |
#item ⇒ Merge::Accounting::PurchaseOrderLineItemRequestItem (readonly)
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 28 def item @item end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 356 def linked_account_params @linked_account_params end |
#quantity ⇒ Float (readonly)
Returns The line item's quantity.
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 26 def quantity @quantity end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> (readonly)
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 358 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
20 21 22 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 20 def remote_id @remote_id end |
#tax_amount ⇒ String (readonly)
Returns The purchase order line item's tax amount.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 36 def tax_amount @tax_amount end |
#tax_rate ⇒ String (readonly)
Returns The tax rate that applies to this line item.
348 349 350 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 348 def tax_rate @tax_rate end |
#total_line_amount ⇒ String (readonly)
Returns The purchase order line item's total amount.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 38 def total_line_amount @total_line_amount end |
#tracking_categories ⇒ Array<String> (readonly)
Returns The purchase order line item's associated tracking categories.
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 34 def tracking_categories @tracking_categories end |
#tracking_category ⇒ String (readonly)
Returns The purchase order line item's associated tracking category.
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 32 def tracking_category @tracking_category end |
#unit_price ⇒ Float (readonly)
Returns The line item's unit price.
24 25 26 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 24 def unit_price @unit_price end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderLineItemRequest
Deserialize a JSON object to an instance of PurchaseOrderLineItemRequest
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 739 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) remote_id = parsed_json["remote_id"] description = parsed_json["description"] unit_price = parsed_json["unit_price"] quantity = parsed_json["quantity"] if parsed_json["item"].nil? item = nil else item = parsed_json["item"].to_json item = Merge::Accounting::PurchaseOrderLineItemRequestItem.from_json(json_object: item) end account = parsed_json["account"] tracking_category = parsed_json["tracking_category"] tracking_categories = parsed_json["tracking_categories"] tax_amount = parsed_json["tax_amount"] total_line_amount = parsed_json["total_line_amount"] currency = parsed_json["currency"] tax_rate = parsed_json["tax_rate"] exchange_rate = parsed_json["exchange_rate"] company = parsed_json["company"] integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteFieldRequest.from_json(json_object: item) end new( remote_id: remote_id, description: description, unit_price: unit_price, quantity: quantity, item: item, account: account, tracking_category: tracking_category, tracking_categories: tracking_categories, tax_amount: tax_amount, total_line_amount: total_line_amount, currency: currency, tax_rate: tax_rate, exchange_rate: exchange_rate, company: company, integration_params: integration_params, linked_account_params: linked_account_params, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 802 def self.validate_raw(obj:) obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.unit_price&.is_a?(Float) != false || raise("Passed value for field obj.unit_price is not the expected type, validation failed.") obj.quantity&.is_a?(Float) != false || raise("Passed value for field obj.quantity is not the expected type, validation failed.") obj.item.nil? || Merge::Accounting::PurchaseOrderLineItemRequestItem.validate_raw(obj: obj.item) obj.account&.is_a?(String) != false || raise("Passed value for field obj.account is not the expected type, validation failed.") obj.tracking_category&.is_a?(String) != false || raise("Passed value for field obj.tracking_category is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.tax_amount&.is_a?(String) != false || raise("Passed value for field obj.tax_amount is not the expected type, validation failed.") obj.total_line_amount&.is_a?(String) != false || raise("Passed value for field obj.total_line_amount is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.tax_rate&.is_a?(String) != false || raise("Passed value for field obj.tax_rate is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderLineItemRequest to a JSON object
792 793 794 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_line_item_request.rb', line 792 def to_json(*_args) @_field_set&.to_json end |