Class: Merge::Accounting::PurchaseOrderRequest
- Inherits:
-
Object
- Object
- Merge::Accounting::PurchaseOrderRequest
- Defined in:
- lib/merge_ruby_client/accounting/types/purchase_order_request.rb
Overview
The PurchaseOrder Object
Description
The PurchaseOrder object is a record of request for a product or service
between a buyer and seller.
Usage Example
Fetch from the LIST PurchaseOrders endpoint and view a company's purchase
orders.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ Merge::Accounting::PurchaseOrderRequestCompany
readonly
The company the purchase order belongs to.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The purchase order's currency.
-
#customer ⇒ String
readonly
The contact making the purchase order.
-
#delivery_address ⇒ Merge::Accounting::PurchaseOrderRequestDeliveryAddress
readonly
The purchase order's delivery address.
-
#delivery_date ⇒ DateTime
readonly
The purchase order's delivery date.
-
#exchange_rate ⇒ String
readonly
The purchase order's exchange rate.
-
#inclusive_of_tax ⇒ Boolean
readonly
If the transaction is inclusive or exclusive of tax.
- #integration_params ⇒ Hash{String => Object} readonly
-
#issue_date ⇒ DateTime
readonly
The purchase order's issue date.
- #line_items ⇒ Array<Merge::Accounting::PurchaseOrderLineItemRequest> readonly
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#memo ⇒ String
readonly
A memo attached to the purchase order.
-
#payment_term ⇒ Merge::Accounting::PurchaseOrderRequestPaymentTerm
readonly
The payment term that applies to this transaction.
- #remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> readonly
-
#status ⇒ Merge::Accounting::PurchaseOrderStatusEnum
readonly
The purchase order's status.
-
#total_amount ⇒ Float
readonly
The purchase order's total amount.
- #tracking_categories ⇒ Array<Merge::Accounting::PurchaseOrderRequestTrackingCategoriesItem> readonly
-
#vendor ⇒ Merge::Accounting::PurchaseOrderRequestVendor
readonly
The party fulfilling the purchase order.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderRequest
Deserialize a JSON object to an instance of PurchaseOrderRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(status: OMIT, issue_date: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, payment_term: OMIT, currency: OMIT, inclusive_of_tax: OMIT, exchange_rate: OMIT, tracking_categories: OMIT, line_items: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderRequest to a JSON object.
Constructor Details
#initialize(status: OMIT, issue_date: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, payment_term: OMIT, currency: OMIT, inclusive_of_tax: OMIT, exchange_rate: OMIT, tracking_categories: OMIT, line_items: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::PurchaseOrderRequest
714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 714 def initialize(status: OMIT, issue_date: OMIT, delivery_date: OMIT, delivery_address: OMIT, customer: OMIT, vendor: OMIT, memo: OMIT, company: OMIT, total_amount: OMIT, payment_term: OMIT, currency: OMIT, inclusive_of_tax: OMIT, exchange_rate: OMIT, tracking_categories: OMIT, line_items: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) @status = status if status != OMIT @issue_date = issue_date if issue_date != OMIT @delivery_date = delivery_date if delivery_date != OMIT @delivery_address = delivery_address if delivery_address != OMIT @customer = customer if customer != OMIT @vendor = vendor if vendor != OMIT @memo = memo if memo != OMIT @company = company if company != OMIT @total_amount = total_amount if total_amount != OMIT @payment_term = payment_term if payment_term != OMIT @currency = currency if currency != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @line_items = line_items if line_items != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "status": status, "issue_date": issue_date, "delivery_date": delivery_date, "delivery_address": delivery_address, "customer": customer, "vendor": vendor, "memo": memo, "company": company, "total_amount": total_amount, "payment_term": payment_term, "currency": currency, "inclusive_of_tax": inclusive_of_tax, "exchange_rate": exchange_rate, "tracking_categories": tracking_categories, "line_items": line_items, "integration_params": integration_params, "linked_account_params": linked_account_params, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 375 def additional_properties @additional_properties end |
#company ⇒ Merge::Accounting::PurchaseOrderRequestCompany (readonly)
Returns The company the purchase order belongs to.
46 47 48 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 46 def company @company end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The purchase order's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 358 def currency @currency end |
#customer ⇒ String (readonly)
Returns The contact making the purchase order.
40 41 42 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 40 def customer @customer end |
#delivery_address ⇒ Merge::Accounting::PurchaseOrderRequestDeliveryAddress (readonly)
Returns The purchase order's delivery address.
38 39 40 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 38 def delivery_address @delivery_address end |
#delivery_date ⇒ DateTime (readonly)
Returns The purchase order's delivery date.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 36 def delivery_date @delivery_date end |
#exchange_rate ⇒ String (readonly)
Returns The purchase order's exchange rate.
363 364 365 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 363 def exchange_rate @exchange_rate end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns If the transaction is inclusive or exclusive of tax. True if inclusive,
False if exclusive.
361 362 363 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 361 def inclusive_of_tax @inclusive_of_tax end |
#integration_params ⇒ Hash{String => Object} (readonly)
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 369 def integration_params @integration_params end |
#issue_date ⇒ DateTime (readonly)
Returns The purchase order's issue date.
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 34 def issue_date @issue_date end |
#line_items ⇒ Array<Merge::Accounting::PurchaseOrderLineItemRequest> (readonly)
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 367 def line_items @line_items end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 371 def linked_account_params @linked_account_params end |
#memo ⇒ String (readonly)
Returns A memo attached to the purchase order.
44 45 46 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 44 def memo @memo end |
#payment_term ⇒ Merge::Accounting::PurchaseOrderRequestPaymentTerm (readonly)
Returns The payment term that applies to this transaction.
50 51 52 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 50 def payment_term @payment_term end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteFieldRequest> (readonly)
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 373 def remote_fields @remote_fields end |
#status ⇒ Merge::Accounting::PurchaseOrderStatusEnum (readonly)
Returns The purchase order's status.
DRAFT- DRAFTSUBMITTED- SUBMITTEDAUTHORIZED- AUTHORIZEDBILLED- BILLEDDELETED- DELETED.
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 32 def status @status end |
#total_amount ⇒ Float (readonly)
Returns The purchase order's total amount.
48 49 50 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 48 def total_amount @total_amount end |
#tracking_categories ⇒ Array<Merge::Accounting::PurchaseOrderRequestTrackingCategoriesItem> (readonly)
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 365 def tracking_categories @tracking_categories end |
#vendor ⇒ Merge::Accounting::PurchaseOrderRequestVendor (readonly)
Returns The party fulfilling the purchase order.
42 43 44 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 42 def vendor @vendor end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::PurchaseOrderRequest
Deserialize a JSON object to an instance of PurchaseOrderRequest
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 763 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) status = parsed_json["status"] issue_date = (DateTime.parse(parsed_json["issue_date"]) unless parsed_json["issue_date"].nil?) delivery_date = (DateTime.parse(parsed_json["delivery_date"]) unless parsed_json["delivery_date"].nil?) if parsed_json["delivery_address"].nil? delivery_address = nil else delivery_address = parsed_json["delivery_address"].to_json delivery_address = Merge::Accounting::PurchaseOrderRequestDeliveryAddress.from_json(json_object: delivery_address) end customer = parsed_json["customer"] if parsed_json["vendor"].nil? vendor = nil else vendor = parsed_json["vendor"].to_json vendor = Merge::Accounting::PurchaseOrderRequestVendor.from_json(json_object: vendor) end memo = parsed_json["memo"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::PurchaseOrderRequestCompany.from_json(json_object: company) end total_amount = parsed_json["total_amount"] if parsed_json["payment_term"].nil? payment_term = nil else payment_term = parsed_json["payment_term"].to_json payment_term = Merge::Accounting::PurchaseOrderRequestPaymentTerm.from_json(json_object: payment_term) end currency = parsed_json["currency"] inclusive_of_tax = parsed_json["inclusive_of_tax"] exchange_rate = parsed_json["exchange_rate"] tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::PurchaseOrderRequestTrackingCategoriesItem.from_json(json_object: item) end line_items = parsed_json["line_items"]&.map do |item| item = item.to_json Merge::Accounting::PurchaseOrderLineItemRequest.from_json(json_object: item) end integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteFieldRequest.from_json(json_object: item) end new( status: status, issue_date: issue_date, delivery_date: delivery_date, delivery_address: delivery_address, customer: customer, vendor: vendor, memo: memo, company: company, total_amount: total_amount, payment_term: payment_term, currency: currency, inclusive_of_tax: inclusive_of_tax, exchange_rate: exchange_rate, tracking_categories: tracking_categories, line_items: line_items, integration_params: integration_params, linked_account_params: linked_account_params, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 849 def self.validate_raw(obj:) obj.status&.is_a?(Merge::Accounting::PurchaseOrderStatusEnum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.issue_date&.is_a?(DateTime) != false || raise("Passed value for field obj.issue_date is not the expected type, validation failed.") obj.delivery_date&.is_a?(DateTime) != false || raise("Passed value for field obj.delivery_date is not the expected type, validation failed.") obj.delivery_address.nil? || Merge::Accounting::PurchaseOrderRequestDeliveryAddress.validate_raw(obj: obj.delivery_address) obj.customer&.is_a?(String) != false || raise("Passed value for field obj.customer is not the expected type, validation failed.") obj.vendor.nil? || Merge::Accounting::PurchaseOrderRequestVendor.validate_raw(obj: obj.vendor) obj.memo&.is_a?(String) != false || raise("Passed value for field obj.memo is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::PurchaseOrderRequestCompany.validate_raw(obj: obj.company) obj.total_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.payment_term.nil? || Merge::Accounting::PurchaseOrderRequestPaymentTerm.validate_raw(obj: obj.payment_term) obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.line_items&.is_a?(Array) != false || raise("Passed value for field obj.line_items is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of PurchaseOrderRequest to a JSON object
839 840 841 |
# File 'lib/merge_ruby_client/accounting/types/purchase_order_request.rb', line 839 def to_json(*_args) @_field_set&.to_json end |