Class: Merge::Accounting::Transaction
- Inherits:
-
Object
- Object
- Merge::Accounting::Transaction
- Defined in:
- lib/merge_ruby_client/accounting/types/transaction.rb
Overview
The Transaction Object
Description
The Transaction common model includes records of all types of transactions
that do not appear in other common models. The type of transaction can be
identified through the type field. More specifically, it will contain all types
of transactions outside of:
- Credit Notes
- Expenses
- Invoices
- Journal Entries
- Payments
- Purchase Orders
- Vendor Credits
Usage Example
Fetch from the GET Transaction endpoint and view a company's transactions.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account ⇒ Merge::Accounting::TransactionAccount
readonly
The transaction's account.
-
#accounting_period ⇒ Merge::Accounting::TransactionAccountingPeriod
readonly
The accounting period that the Transaction was generated in.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ String
readonly
The company the transaction belongs to.
-
#contact ⇒ Merge::Accounting::TransactionContact
readonly
The contact to whom the transaction relates to.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The transaction's currency.
-
#exchange_rate ⇒ String
readonly
The transaction's exchange rate.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
-
#inclusive_of_tax ⇒ Boolean
readonly
If the transaction is inclusive or exclusive of tax.
- #line_items ⇒ Array<Merge::Accounting::TransactionLineItem> readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
-
#number ⇒ String
readonly
The transaction's number used for identifying purposes.
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#total_amount ⇒ String
readonly
The total amount being paid after taxes.
- #tracking_categories ⇒ Array<Merge::Accounting::TransactionTrackingCategoriesItem> readonly
-
#transaction_date ⇒ DateTime
readonly
The date upon which the transaction occurred.
-
#transaction_type ⇒ String
readonly
The type of transaction, which can by any transaction object not already included in Merge’s common model.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::Transaction
Deserialize a JSON object to an instance of Transaction.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_type: OMIT, number: OMIT, transaction_date: OMIT, account: OMIT, contact: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, tracking_categories: OMIT, line_items: OMIT, remote_was_deleted: OMIT, accounting_period: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::Transaction constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of Transaction to a JSON object.
Constructor Details
#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_type: OMIT, number: OMIT, transaction_date: OMIT, account: OMIT, contact: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, tracking_categories: OMIT, line_items: OMIT, remote_was_deleted: OMIT, accounting_period: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Accounting::Transaction
724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 724 def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, transaction_type: OMIT, number: OMIT, transaction_date: OMIT, account: OMIT, contact: OMIT, inclusive_of_tax: OMIT, total_amount: OMIT, currency: OMIT, exchange_rate: OMIT, company: OMIT, tracking_categories: OMIT, line_items: OMIT, remote_was_deleted: OMIT, accounting_period: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @transaction_type = transaction_type if transaction_type != OMIT @number = number if number != OMIT @transaction_date = transaction_date if transaction_date != OMIT @account = account if account != OMIT @contact = contact if contact != OMIT @inclusive_of_tax = inclusive_of_tax if inclusive_of_tax != OMIT @total_amount = total_amount if total_amount != OMIT @currency = currency if currency != OMIT @exchange_rate = exchange_rate if exchange_rate != OMIT @company = company if company != OMIT @tracking_categories = tracking_categories if tracking_categories != OMIT @line_items = line_items if line_items != OMIT @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @accounting_period = accounting_period if accounting_period != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "transaction_type": transaction_type, "number": number, "transaction_date": transaction_date, "account": account, "contact": contact, "inclusive_of_tax": inclusive_of_tax, "total_amount": total_amount, "currency": currency, "exchange_rate": exchange_rate, "company": company, "tracking_categories": tracking_categories, "line_items": line_items, "remote_was_deleted": remote_was_deleted, "accounting_period": accounting_period, "field_mappings": field_mappings, "remote_data": remote_data }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account ⇒ Merge::Accounting::TransactionAccount (readonly)
Returns The transaction's account.
48 49 50 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 48 def account @account end |
#accounting_period ⇒ Merge::Accounting::TransactionAccountingPeriod (readonly)
Returns The accounting period that the Transaction was generated in.
378 379 380 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 378 def accounting_period @accounting_period end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
384 385 386 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 384 def additional_properties @additional_properties end |
#company ⇒ String (readonly)
Returns The company the transaction belongs to.
367 368 369 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 367 def company @company end |
#contact ⇒ Merge::Accounting::TransactionContact (readonly)
Returns The contact to whom the transaction relates to.
50 51 52 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 50 def contact @contact end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
37 38 39 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 37 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns The transaction's currency.
XUA- ADB Unit of AccountAFN- Afghan AfghaniAFA- Afghan Afghani (1927–2002)ALL- Albanian LekALK- Albanian Lek (1946–1965)DZD- Algerian DinarADP- Andorran PesetaAOA- Angolan KwanzaAOK- Angolan Kwanza (1977–1991)AON- Angolan New Kwanza (1990–2000)AOR- Angolan Readjusted Kwanza (1995–1999)ARA- Argentine AustralARS- Argentine PesoARM- Argentine Peso (1881–1970)ARP- Argentine Peso (1983–1985)ARL- Argentine Peso Ley (1970–1983)AMD- Armenian DramAWG- Aruban FlorinAUD- Australian DollarATS- Austrian SchillingAZN- Azerbaijani ManatAZM- Azerbaijani Manat (1993–2006)BSD- Bahamian DollarBHD- Bahraini DinarBDT- Bangladeshi TakaBBD- Barbadian DollarBYN- Belarusian RubleBYB- Belarusian Ruble (1994–1999)BYR- Belarusian Ruble (2000–2016)BEF- Belgian FrancBEC- Belgian Franc (convertible)BEL- Belgian Franc (financial)BZD- Belize DollarBMD- Bermudan DollarBTN- Bhutanese NgultrumBOB- Bolivian BolivianoBOL- Bolivian Boliviano (1863–1963)BOV- Bolivian MvdolBOP- Bolivian PesoBAM- Bosnia-Herzegovina Convertible MarkBAD- Bosnia-Herzegovina Dinar (1992–1994)BAN- Bosnia-Herzegovina New Dinar (1994–1997)BWP- Botswanan PulaBRC- Brazilian Cruzado (1986–1989)BRZ- Brazilian Cruzeiro (1942–1967)BRE- Brazilian Cruzeiro (1990–1993)BRR- Brazilian Cruzeiro (1993–1994)BRN- Brazilian New Cruzado (1989–1990)BRB- Brazilian New Cruzeiro (1967–1986)BRL- Brazilian RealGBP- British PoundBND- Brunei DollarBGL- Bulgarian Hard LevBGN- Bulgarian LevBGO- Bulgarian Lev (1879–1952)BGM- Bulgarian Socialist LevBUK- Burmese KyatBIF- Burundian FrancXPF- CFP FrancKHR- Cambodian RielCAD- Canadian DollarCVE- Cape Verdean EscudoKYD- Cayman Islands DollarXAF- Central African CFA FrancCLE- Chilean EscudoCLP- Chilean PesoCLF- Chilean Unit of Account (UF)CNX- Chinese People’s Bank DollarCNY- Chinese YuanCNH- Chinese Yuan (offshore)COP- Colombian PesoCOU- Colombian Real Value UnitKMF- Comorian FrancCDF- Congolese FrancCRC- Costa Rican ColónHRD- Croatian DinarHRK- Croatian KunaCUC- Cuban Convertible PesoCUP- Cuban PesoCYP- Cypriot PoundCZK- Czech KorunaCSK- Czechoslovak Hard KorunaDKK- Danish KroneDJF- Djiboutian FrancDOP- Dominican PesoNLG- Dutch GuilderXCD- East Caribbean DollarDDM- East German MarkECS- Ecuadorian SucreECV- Ecuadorian Unit of Constant ValueEGP- Egyptian PoundGQE- Equatorial Guinean EkweleERN- Eritrean NakfaEEK- Estonian KroonETB- Ethiopian BirrEUR- EuroXBA- European Composite UnitXEU- European Currency UnitXBB- European Monetary UnitXBC- European Unit of Account (XBC)XBD- European Unit of Account (XBD)FKP- Falkland Islands PoundFJD- Fijian DollarFIM- Finnish MarkkaFRF- French FrancXFO- French Gold FrancXFU- French UIC-FrancGMD- Gambian DalasiGEK- Georgian Kupon LaritGEL- Georgian LariDEM- German MarkGHS- Ghanaian CediGHC- Ghanaian Cedi (1979–2007)GIP- Gibraltar PoundXAU- GoldGRD- Greek DrachmaGTQ- Guatemalan QuetzalGWP- Guinea-Bissau PesoGNF- Guinean FrancGNS- Guinean SyliGYD- Guyanaese DollarHTG- Haitian GourdeHNL- Honduran LempiraHKD- Hong Kong DollarHUF- Hungarian ForintIMP- IMPISK- Icelandic KrónaISJ- Icelandic Króna (1918–1981)INR- Indian RupeeIDR- Indonesian RupiahIRR- Iranian RialIQD- Iraqi DinarIEP- Irish PoundILS- Israeli New ShekelILP- Israeli PoundILR- Israeli Shekel (1980–1985)ITL- Italian LiraJMD- Jamaican DollarJPY- Japanese YenJOD- Jordanian DinarKZT- Kazakhstani TengeKES- Kenyan ShillingKWD- Kuwaiti DinarKGS- Kyrgystani SomLAK- Laotian KipLVL- Latvian LatsLVR- Latvian RubleLBP- Lebanese PoundLSL- Lesotho LotiLRD- Liberian DollarLYD- Libyan DinarLTL- Lithuanian LitasLTT- Lithuanian TalonasLUL- Luxembourg Financial FrancLUC- Luxembourgian Convertible FrancLUF- Luxembourgian FrancMOP- Macanese PatacaMKD- Macedonian DenarMKN- Macedonian Denar (1992–1993)MGA- Malagasy AriaryMGF- Malagasy FrancMWK- Malawian KwachaMYR- Malaysian RinggitMVR- Maldivian RufiyaaMVP- Maldivian Rupee (1947–1981)MLF- Malian FrancMTL- Maltese LiraMTP- Maltese PoundMRU- Mauritanian OuguiyaMRO- Mauritanian Ouguiya (1973–2017)MUR- Mauritian RupeeMXV- Mexican Investment UnitMXN- Mexican PesoMXP- Mexican Silver Peso (1861–1992)MDC- Moldovan CuponMDL- Moldovan LeuMCF- Monegasque FrancMNT- Mongolian TugrikMAD- Moroccan DirhamMAF- Moroccan FrancMZE- Mozambican EscudoMZN- Mozambican MeticalMZM- Mozambican Metical (1980–2006)MMK- Myanmar KyatNAD- Namibian DollarNPR- Nepalese RupeeANG- Netherlands Antillean GuilderTWD- New Taiwan DollarNZD- New Zealand DollarNIO- Nicaraguan CórdobaNIC- Nicaraguan Córdoba (1988–1991)NGN- Nigerian NairaKPW- North Korean WonNOK- Norwegian KroneOMR- Omani RialPKR- Pakistani RupeeXPD- PalladiumPAB- Panamanian BalboaPGK- Papua New Guinean KinaPYG- Paraguayan GuaraniPEI- Peruvian IntiPEN- Peruvian SolPES- Peruvian Sol (1863–1965)PHP- Philippine PesoXPT- PlatinumPLN- Polish ZlotyPLZ- Polish Zloty (1950–1995)PTE- Portuguese EscudoGWE- Portuguese Guinea EscudoQAR- Qatari RialXRE- RINET FundsRHD- Rhodesian DollarRON- Romanian LeuROL- Romanian Leu (1952–2006)RUB- Russian RubleRUR- Russian Ruble (1991–1998)RWF- Rwandan FrancSVC- Salvadoran ColónWST- Samoan TalaSAR- Saudi RiyalRSD- Serbian DinarCSD- Serbian Dinar (2002–2006)SCR- Seychellois RupeeSLL- Sierra Leonean LeoneXAG- SilverSGD- Singapore DollarSKK- Slovak KorunaSIT- Slovenian TolarSBD- Solomon Islands DollarSOS- Somali ShillingZAR- South African RandZAL- South African Rand (financial)KRH- South Korean Hwan (1953–1962)KRW- South Korean WonKRO- South Korean Won (1945–1953)SSP- South Sudanese PoundSUR- Soviet RoubleESP- Spanish PesetaESA- Spanish Peseta (A account)ESB- Spanish Peseta (convertible account)XDR- Special Drawing RightsLKR- Sri Lankan RupeeSHP- St. Helena PoundXSU- SucreSDD- Sudanese Dinar (1992–2007)SDG- Sudanese PoundSDP- Sudanese Pound (1957–1998)SRD- Surinamese DollarSRG- Surinamese GuilderSZL- Swazi LilangeniSEK- Swedish KronaCHF- Swiss FrancSYP- Syrian PoundSTN- São Tomé & Príncipe DobraSTD- São Tomé & Príncipe Dobra (1977–2017)TVD- TVDTJR- Tajikistani RubleTJS- Tajikistani SomoniTZS- Tanzanian ShillingXTS- Testing Currency CodeTHB- Thai BahtXXX- The codes assigned for transactions where no currency is involvedTPE- Timorese EscudoTOP- Tongan PaʻangaTTD- Trinidad & Tobago DollarTND- Tunisian DinarTRY- Turkish LiraTRL- Turkish Lira (1922–2005)TMT- Turkmenistani ManatTMM- Turkmenistani Manat (1993–2009)USD- US DollarUSN- US Dollar (Next day)USS- US Dollar (Same day)UGX- Ugandan ShillingUGS- Ugandan Shilling (1966–1987)UAH- Ukrainian HryvniaUAK- Ukrainian KarbovanetsAED- United Arab Emirates DirhamUYW- Uruguayan Nominal Wage Index UnitUYU- Uruguayan PesoUYP- Uruguayan Peso (1975–1993)UYI- Uruguayan Peso (Indexed Units)UZS- Uzbekistani SomVUV- Vanuatu VatuVES- Venezuelan BolívarVEB- Venezuelan Bolívar (1871–2008)VEF- Venezuelan Bolívar (2008–2018)VND- Vietnamese DongVNN- Vietnamese Dong (1978–1985)CHE- WIR EuroCHW- WIR FrancXOF- West African CFA FrancYDD- Yemeni DinarYER- Yemeni RialYUN- Yugoslavian Convertible Dinar (1990–1992)YUD- Yugoslavian Hard Dinar (1966–1990)YUM- Yugoslavian New Dinar (1994–2002)YUR- Yugoslavian Reformed Dinar (1992–1993)ZWN- ZWNZRN- Zairean New Zaire (1993–1998)ZRZ- Zairean Zaire (1971–1993)ZMW- Zambian KwachaZMK- Zambian Kwacha (1968–2012)ZWD- Zimbabwean Dollar (1980–2008)ZWR- Zimbabwean Dollar (2008)ZWL- Zimbabwean Dollar (2009).
363 364 365 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 363 def currency @currency end |
#exchange_rate ⇒ String (readonly)
Returns The transaction's exchange rate.
365 366 367 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 365 def exchange_rate @exchange_rate end |
#field_mappings ⇒ Hash{String => Object} (readonly)
380 381 382 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 380 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
33 34 35 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 33 def id @id end |
#inclusive_of_tax ⇒ Boolean (readonly)
Returns If the transaction is inclusive or exclusive of tax. True if inclusive,
False if exclusive.
53 54 55 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 53 def inclusive_of_tax @inclusive_of_tax end |
#line_items ⇒ Array<Merge::Accounting::TransactionLineItem> (readonly)
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 371 def line_items @line_items end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 39 def modified_at @modified_at end |
#number ⇒ String (readonly)
Returns The transaction's number used for identifying purposes.
44 45 46 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 44 def number @number end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
382 383 384 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 382 def remote_data @remote_data end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
35 36 37 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 35 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. Learn more.
376 377 378 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 376 def remote_was_deleted @remote_was_deleted end |
#total_amount ⇒ String (readonly)
Returns The total amount being paid after taxes.
55 56 57 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 55 def total_amount @total_amount end |
#tracking_categories ⇒ Array<Merge::Accounting::TransactionTrackingCategoriesItem> (readonly)
369 370 371 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 369 def tracking_categories @tracking_categories end |
#transaction_date ⇒ DateTime (readonly)
Returns The date upon which the transaction occurred.
46 47 48 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 46 def transaction_date @transaction_date end |
#transaction_type ⇒ String (readonly)
Returns The type of transaction, which can by any transaction object not already included in Merge’s common model.
42 43 44 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 42 def transaction_type @transaction_type end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::Transaction
Deserialize a JSON object to an instance of Transaction
777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 777 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) transaction_type = parsed_json["transaction_type"] number = parsed_json["number"] transaction_date = (DateTime.parse(parsed_json["transaction_date"]) unless parsed_json["transaction_date"].nil?) if parsed_json["account"].nil? account = nil else account = parsed_json["account"].to_json account = Merge::Accounting::TransactionAccount.from_json(json_object: account) end if parsed_json["contact"].nil? contact = nil else contact = parsed_json["contact"].to_json contact = Merge::Accounting::TransactionContact.from_json(json_object: contact) end inclusive_of_tax = parsed_json["inclusive_of_tax"] total_amount = parsed_json["total_amount"] currency = parsed_json["currency"] exchange_rate = parsed_json["exchange_rate"] company = parsed_json["company"] tracking_categories = parsed_json["tracking_categories"]&.map do |item| item = item.to_json Merge::Accounting::TransactionTrackingCategoriesItem.from_json(json_object: item) end line_items = parsed_json["line_items"]&.map do |item| item = item.to_json Merge::Accounting::TransactionLineItem.from_json(json_object: item) end remote_was_deleted = parsed_json["remote_was_deleted"] if parsed_json["accounting_period"].nil? accounting_period = nil else accounting_period = parsed_json["accounting_period"].to_json accounting_period = Merge::Accounting::TransactionAccountingPeriod.from_json(json_object: accounting_period) end field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, transaction_type: transaction_type, number: number, transaction_date: transaction_date, account: account, contact: contact, inclusive_of_tax: inclusive_of_tax, total_amount: total_amount, currency: currency, exchange_rate: exchange_rate, company: company, tracking_categories: tracking_categories, line_items: line_items, remote_was_deleted: remote_was_deleted, accounting_period: accounting_period, field_mappings: field_mappings, remote_data: remote_data, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 862 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.transaction_type&.is_a?(String) != false || raise("Passed value for field obj.transaction_type is not the expected type, validation failed.") obj.number&.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.") obj.transaction_date&.is_a?(DateTime) != false || raise("Passed value for field obj.transaction_date is not the expected type, validation failed.") obj.account.nil? || Merge::Accounting::TransactionAccount.validate_raw(obj: obj.account) obj.contact.nil? || Merge::Accounting::TransactionContact.validate_raw(obj: obj.contact) obj.inclusive_of_tax&.is_a?(Boolean) != false || raise("Passed value for field obj.inclusive_of_tax is not the expected type, validation failed.") obj.total_amount&.is_a?(String) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.exchange_rate&.is_a?(String) != false || raise("Passed value for field obj.exchange_rate is not the expected type, validation failed.") obj.company&.is_a?(String) != false || raise("Passed value for field obj.company is not the expected type, validation failed.") obj.tracking_categories&.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.line_items&.is_a?(Array) != false || raise("Passed value for field obj.line_items is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.accounting_period.nil? || Merge::Accounting::TransactionAccountingPeriod.validate_raw(obj: obj.accounting_period) obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of Transaction to a JSON object
852 853 854 |
# File 'lib/merge_ruby_client/accounting/types/transaction.rb', line 852 def to_json(*_args) @_field_set&.to_json end |