Class: Merge::Accounting::VendorCreditApplyLineForInvoice

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb

Overview

The VendorCreditApplyLine Object

Description

The VendorCreditApplyLine object is used to represent a applied vendor credit.

Usage Example

Fetch from the GET VendorCredit endpoint and view the vendor credit's applied to lines.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(remote_id: OMIT, created_at: OMIT, modified_at: OMIT, vendor_credit: OMIT, applied_date: OMIT, applied_amount: OMIT, remote_was_deleted: OMIT, additional_properties: nil) ⇒ Merge::Accounting::VendorCreditApplyLineForInvoice



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 54

def initialize(remote_id: OMIT, created_at: OMIT, modified_at: OMIT, vendor_credit: OMIT, applied_date: OMIT,
               applied_amount: OMIT, remote_was_deleted: OMIT, additional_properties: nil)
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @vendor_credit = vendor_credit if vendor_credit != OMIT
  @applied_date = applied_date if applied_date != OMIT
  @applied_amount = applied_amount if applied_amount != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "vendor_credit": vendor_credit,
    "applied_date": applied_date,
    "applied_amount": applied_amount,
    "remote_was_deleted": remote_was_deleted
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



35
36
37
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 35

def additional_properties
  @additional_properties
end

#applied_amountString (readonly)



28
29
30
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 28

def applied_amount
  @applied_amount
end

#applied_dateDateTime (readonly)



26
27
28
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 26

def applied_date
  @applied_date
end

#created_atDateTime (readonly)



20
21
22
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 20

def created_at
  @created_at
end

#modified_atDateTime (readonly)



22
23
24
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 22

def modified_at
  @modified_at
end

#remote_idString (readonly)



18
19
20
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 18

def remote_id
  @remote_id
end

#remote_was_deletedBoolean (readonly)



33
34
35
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 33

def remote_was_deleted
  @remote_was_deleted
end

#vendor_creditMerge::Accounting::VendorCreditApplyLineForInvoiceVendorCredit (readonly)



24
25
26
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 24

def vendor_credit
  @vendor_credit
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Accounting::VendorCreditApplyLineForInvoice

Deserialize a JSON object to an instance of VendorCreditApplyLineForInvoice



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 81

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  if parsed_json["vendor_credit"].nil?
    vendor_credit = nil
  else
    vendor_credit = parsed_json["vendor_credit"].to_json
    vendor_credit = Merge::Accounting::VendorCreditApplyLineForInvoiceVendorCredit.from_json(json_object: vendor_credit)
  end
  applied_date = (DateTime.parse(parsed_json["applied_date"]) unless parsed_json["applied_date"].nil?)
  applied_amount = parsed_json["applied_amount"]
  remote_was_deleted = parsed_json["remote_was_deleted"]
  new(
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    vendor_credit: vendor_credit,
    applied_date: applied_date,
    applied_amount: applied_amount,
    remote_was_deleted: remote_was_deleted,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



121
122
123
124
125
126
127
128
129
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 121

def self.validate_raw(obj:)
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.vendor_credit.nil? || Merge::Accounting::VendorCreditApplyLineForInvoiceVendorCredit.validate_raw(obj: obj.vendor_credit)
  obj.applied_date&.is_a?(DateTime) != false || raise("Passed value for field obj.applied_date is not the expected type, validation failed.")
  obj.applied_amount&.is_a?(String) != false || raise("Passed value for field obj.applied_amount is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of VendorCreditApplyLineForInvoice to a JSON object



111
112
113
# File 'lib/merge_ruby_client/accounting/types/vendor_credit_apply_line_for_invoice.rb', line 111

def to_json(*_args)
  @_field_set&.to_json
end