Class: Merge::Ats::RemoteUser

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/ats/types/remote_user.rb

Overview

The RemoteUser Object

Description

The RemoteUser object is used to represent a user with a login to the ATS system.

Usage Example

Fetch from the LIST RemoteUsers endpoint to show all users for a third party.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, first_name: OMIT, last_name: OMIT, email: OMIT, disabled: OMIT, remote_created_at: OMIT, access_role: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Ats::RemoteUser



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 83

def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, first_name: OMIT, last_name: OMIT,
               email: OMIT, disabled: OMIT, remote_created_at: OMIT, access_role: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil)
  @id = id if id != OMIT
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @first_name = first_name if first_name != OMIT
  @last_name = last_name if last_name != OMIT
  @email = email if email != OMIT
  @disabled = disabled if disabled != OMIT
  @remote_created_at = remote_created_at if remote_created_at != OMIT
  @access_role = access_role if access_role != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @field_mappings = field_mappings if field_mappings != OMIT
  @remote_data = remote_data if remote_data != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "id": id,
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "first_name": first_name,
    "last_name": last_name,
    "email": email,
    "disabled": disabled,
    "remote_created_at": remote_created_at,
    "access_role": access_role,
    "remote_was_deleted": remote_was_deleted,
    "field_mappings": field_mappings,
    "remote_data": remote_data
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#access_roleMerge::Ats::AccessRoleEnum (readonly)



42
43
44
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 42

def access_role
  @access_role
end

#additional_propertiesOpenStruct (readonly)



53
54
55
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 53

def additional_properties
  @additional_properties
end

#created_atDateTime (readonly)



23
24
25
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 23

def created_at
  @created_at
end

#disabledBoolean (readonly)



33
34
35
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 33

def disabled
  @disabled
end

#emailString (readonly)



31
32
33
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 31

def email
  @email
end

#field_mappingsHash{String => Object} (readonly)



49
50
51
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 49

def field_mappings
  @field_mappings
end

#first_nameString (readonly)



27
28
29
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 27

def first_name
  @first_name
end

#idString (readonly)



19
20
21
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 19

def id
  @id
end

#last_nameString (readonly)



29
30
31
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 29

def last_name
  @last_name
end

#modified_atDateTime (readonly)



25
26
27
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 25

def modified_at
  @modified_at
end

#remote_created_atDateTime (readonly)



35
36
37
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 35

def remote_created_at
  @remote_created_at
end

#remote_dataArray<Merge::Ats::RemoteData> (readonly)



51
52
53
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 51

def remote_data
  @remote_data
end

#remote_idString (readonly)



21
22
23
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 21

def remote_id
  @remote_id
end

#remote_was_deletedBoolean (readonly)



47
48
49
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 47

def remote_was_deleted
  @remote_was_deleted
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Ats::RemoteUser

Deserialize a JSON object to an instance of RemoteUser



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 122

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  id = parsed_json["id"]
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  first_name = parsed_json["first_name"]
  last_name = parsed_json["last_name"]
  email = parsed_json["email"]
  disabled = parsed_json["disabled"]
  remote_created_at = unless parsed_json["remote_created_at"].nil?
                        DateTime.parse(parsed_json["remote_created_at"])
                      end
  access_role = parsed_json["access_role"]
  remote_was_deleted = parsed_json["remote_was_deleted"]
  field_mappings = parsed_json["field_mappings"]
  remote_data = parsed_json["remote_data"]&.map do |item|
    item = item.to_json
    Merge::Ats::RemoteData.from_json(json_object: item)
  end
  new(
    id: id,
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    first_name: first_name,
    last_name: last_name,
    email: email,
    disabled: disabled,
    remote_created_at: remote_created_at,
    access_role: access_role,
    remote_was_deleted: remote_was_deleted,
    field_mappings: field_mappings,
    remote_data: remote_data,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 174

def self.validate_raw(obj:)
  obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.first_name&.is_a?(String) != false || raise("Passed value for field obj.first_name is not the expected type, validation failed.")
  obj.last_name&.is_a?(String) != false || raise("Passed value for field obj.last_name is not the expected type, validation failed.")
  obj.email&.is_a?(String) != false || raise("Passed value for field obj.email is not the expected type, validation failed.")
  obj.disabled&.is_a?(Boolean) != false || raise("Passed value for field obj.disabled is not the expected type, validation failed.")
  obj.remote_created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.remote_created_at is not the expected type, validation failed.")
  obj.access_role&.is_a?(Merge::Ats::AccessRoleEnum) != false || raise("Passed value for field obj.access_role is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
  obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.")
  obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of RemoteUser to a JSON object



164
165
166
# File 'lib/merge_ruby_client/ats/types/remote_user.rb', line 164

def to_json(*_args)
  @_field_set&.to_json
end