Class: Merge::Ats::ScreeningQuestionAnswer

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/ats/types/screening_question_answer.rb

Overview

The ScreeningQuestionAnswer Object

Description

The ScreeningQuestionAnswer object is used to represent candidate responses to a screening question, for a specific application.

Usage Example

TODO

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, question: OMIT, answer: OMIT, remote_was_deleted: OMIT, additional_properties: nil) ⇒ Merge::Ats::ScreeningQuestionAnswer



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 58

def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, question: OMIT, answer: OMIT,
               remote_was_deleted: OMIT, additional_properties: nil)
  @id = id if id != OMIT
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @question = question if question != OMIT
  @answer = answer if answer != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "id": id,
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "question": question,
    "answer": answer,
    "remote_was_deleted": remote_was_deleted
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



37
38
39
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 37

def additional_properties
  @additional_properties
end

#answerString (readonly)



30
31
32
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 30

def answer
  @answer
end

#created_atDateTime (readonly)



22
23
24
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 22

def created_at
  @created_at
end

#idString (readonly)



18
19
20
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 18

def id
  @id
end

#modified_atDateTime (readonly)



24
25
26
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 24

def modified_at
  @modified_at
end

#questionMerge::Ats::ScreeningQuestionAnswerQuestion (readonly)



28
29
30
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 28

def question
  @question
end

#remote_idString (readonly)



20
21
22
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 20

def remote_id
  @remote_id
end

#remote_was_deletedBoolean (readonly)



35
36
37
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 35

def remote_was_deleted
  @remote_was_deleted
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Ats::ScreeningQuestionAnswer

Deserialize a JSON object to an instance of ScreeningQuestionAnswer



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 85

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  id = parsed_json["id"]
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  if parsed_json["question"].nil?
    question = nil
  else
    question = parsed_json["question"].to_json
    question = Merge::Ats::ScreeningQuestionAnswerQuestion.from_json(json_object: question)
  end
  answer = parsed_json["answer"]
  remote_was_deleted = parsed_json["remote_was_deleted"]
  new(
    id: id,
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    question: question,
    answer: answer,
    remote_was_deleted: remote_was_deleted,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



125
126
127
128
129
130
131
132
133
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 125

def self.validate_raw(obj:)
  obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.question.nil? || Merge::Ats::ScreeningQuestionAnswerQuestion.validate_raw(obj: obj.question)
  obj.answer&.is_a?(String) != false || raise("Passed value for field obj.answer is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of ScreeningQuestionAnswer to a JSON object



115
116
117
# File 'lib/merge_ruby_client/ats/types/screening_question_answer.rb', line 115

def to_json(*_args)
  @_field_set&.to_json
end