Class: Merge::Ats::Url

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/ats/types/url.rb

Overview

The Url Object

Description

The Url object is used to represent hyperlinks associated with the parent model.

Usage Example

Fetch from the GET Candidate endpoint and view their website urls.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(created_at: OMIT, modified_at: OMIT, value: OMIT, url_type: OMIT, remote_was_deleted: OMIT, additional_properties: nil) ⇒ Merge::Ats::Url



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/merge_ruby_client/ats/types/url.rb', line 62

def initialize(created_at: OMIT, modified_at: OMIT, value: OMIT, url_type: OMIT, remote_was_deleted: OMIT,
               additional_properties: nil)
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @value = value if value != OMIT
  @url_type = url_type if url_type != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "created_at": created_at,
    "modified_at": modified_at,
    "value": value,
    "url_type": url_type,
    "remote_was_deleted": remote_was_deleted
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



38
39
40
# File 'lib/merge_ruby_client/ats/types/url.rb', line 38

def additional_properties
  @additional_properties
end

#created_atDateTime (readonly)



18
19
20
# File 'lib/merge_ruby_client/ats/types/url.rb', line 18

def created_at
  @created_at
end

#modified_atDateTime (readonly)



20
21
22
# File 'lib/merge_ruby_client/ats/types/url.rb', line 20

def modified_at
  @modified_at
end

#remote_was_deletedBoolean (readonly)



36
37
38
# File 'lib/merge_ruby_client/ats/types/url.rb', line 36

def remote_was_deleted
  @remote_was_deleted
end

#url_typeMerge::Ats::UrlTypeEnum (readonly)



31
32
33
# File 'lib/merge_ruby_client/ats/types/url.rb', line 31

def url_type
  @url_type
end

#valueString (readonly)



22
23
24
# File 'lib/merge_ruby_client/ats/types/url.rb', line 22

def value
  @value
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Ats::Url

Deserialize a JSON object to an instance of Url



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/merge_ruby_client/ats/types/url.rb', line 85

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  value = parsed_json["value"]
  url_type = parsed_json["url_type"]
  remote_was_deleted = parsed_json["remote_was_deleted"]
  new(
    created_at: created_at,
    modified_at: modified_at,
    value: value,
    url_type: url_type,
    remote_was_deleted: remote_was_deleted,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



116
117
118
119
120
121
122
# File 'lib/merge_ruby_client/ats/types/url.rb', line 116

def self.validate_raw(obj:)
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.value&.is_a?(String) != false || raise("Passed value for field obj.value is not the expected type, validation failed.")
  obj.url_type&.is_a?(Merge::Ats::UrlTypeEnum) != false || raise("Passed value for field obj.url_type is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Url to a JSON object



106
107
108
# File 'lib/merge_ruby_client/ats/types/url.rb', line 106

def to_json(*_args)
  @_field_set&.to_json
end