Class: Merge::Crm::AddressRequest
- Inherits:
-
Object
- Object
- Merge::Crm::AddressRequest
- Defined in:
- lib/merge_ruby_client/crm/types/address_request.rb
Overview
The Address Object
Description
The Address object is used to represent an entity's address.
Usage Example
TODO
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#address_type ⇒ Merge::Crm::AddressTypeEnum
readonly
The address type.
-
#city ⇒ String
readonly
The address's city.
-
#country ⇒ Merge::Crm::CountryEnum
readonly
The address's country.
- #integration_params ⇒ Hash{String => Object} readonly
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#postal_code ⇒ String
readonly
The address's postal code.
-
#state ⇒ String
readonly
The address's state.
-
#street_1 ⇒ String
readonly
Line 1 of the address's street.
-
#street_2 ⇒ String
readonly
Line 2 of the address's street.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Crm::AddressRequest
Deserialize a JSON object to an instance of AddressRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(street_1: OMIT, street_2: OMIT, city: OMIT, state: OMIT, postal_code: OMIT, country: OMIT, address_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) ⇒ Merge::Crm::AddressRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AddressRequest to a JSON object.
Constructor Details
#initialize(street_1: OMIT, street_2: OMIT, city: OMIT, state: OMIT, postal_code: OMIT, country: OMIT, address_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) ⇒ Merge::Crm::AddressRequest
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 555 def initialize(street_1: OMIT, street_2: OMIT, city: OMIT, state: OMIT, postal_code: OMIT, country: OMIT, address_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) @street_1 = street_1 if street_1 != OMIT @street_2 = street_2 if street_2 != OMIT @city = city if city != OMIT @state = state if state != OMIT @postal_code = postal_code if postal_code != OMIT @country = country if country != OMIT @address_type = address_type if address_type != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @additional_properties = additional_properties @_field_set = { "street_1": street_1, "street_2": street_2, "city": city, "state": state, "postal_code": postal_code, "country": country, "address_type": address_type, "integration_params": integration_params, "linked_account_params": linked_account_params }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
286 287 288 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 286 def additional_properties @additional_properties end |
#address_type ⇒ Merge::Crm::AddressTypeEnum (readonly)
Returns The address type.
BILLING- BILLINGSHIPPING- SHIPPING.
280 281 282 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 280 def address_type @address_type end |
#city ⇒ String (readonly)
Returns The address's city.
21 22 23 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 21 def city @city end |
#country ⇒ Merge::Crm::CountryEnum (readonly)
Returns The address's country.
AF- AfghanistanAX- Åland IslandsAL- AlbaniaDZ- AlgeriaAS- American SamoaAD- AndorraAO- AngolaAI- AnguillaAQ- AntarcticaAG- Antigua and BarbudaAR- ArgentinaAM- ArmeniaAW- ArubaAU- AustraliaAT- AustriaAZ- AzerbaijanBS- BahamasBH- BahrainBD- BangladeshBB- BarbadosBY- BelarusBE- BelgiumBZ- BelizeBJ- BeninBM- BermudaBT- BhutanBO- BoliviaBQ- Bonaire, Sint Eustatius and SabaBA- Bosnia and HerzegovinaBW- BotswanaBV- Bouvet IslandBR- BrazilIO- British Indian Ocean TerritoryBN- BruneiBG- BulgariaBF- Burkina FasoBI- BurundiCV- Cabo VerdeKH- CambodiaCM- CameroonCA- CanadaKY- Cayman IslandsCF- Central African RepublicTD- ChadCL- ChileCN- ChinaCX- Christmas IslandCC- Cocos (Keeling) IslandsCO- ColombiaKM- ComorosCG- CongoCD- Congo (the Democratic Republic of the)CK- Cook IslandsCR- Costa RicaCI- Côte d'IvoireHR- CroatiaCU- CubaCW- CuraçaoCY- CyprusCZ- CzechiaDK- DenmarkDJ- DjiboutiDM- DominicaDO- Dominican RepublicEC- EcuadorEG- EgyptSV- El SalvadorGQ- Equatorial GuineaER- EritreaEE- EstoniaSZ- EswatiniET- EthiopiaFK- Falkland Islands (Malvinas)FO- Faroe IslandsFJ- FijiFI- FinlandFR- FranceGF- French GuianaPF- French PolynesiaTF- French Southern TerritoriesGA- GabonGM- GambiaGE- GeorgiaDE- GermanyGH- GhanaGI- GibraltarGR- GreeceGL- GreenlandGD- GrenadaGP- GuadeloupeGU- GuamGT- GuatemalaGG- GuernseyGN- GuineaGW- Guinea-BissauGY- GuyanaHT- HaitiHM- Heard Island and McDonald IslandsVA- Holy SeeHN- HondurasHK- Hong KongHU- HungaryIS- IcelandIN- IndiaID- IndonesiaIR- IranIQ- IraqIE- IrelandIM- Isle of ManIL- IsraelIT- ItalyJM- JamaicaJP- JapanJE- JerseyJO- JordanKZ- KazakhstanKE- KenyaKI- KiribatiKW- KuwaitKG- KyrgyzstanLA- LaosLV- LatviaLB- LebanonLS- LesothoLR- LiberiaLY- LibyaLI- LiechtensteinLT- LithuaniaLU- LuxembourgMO- MacaoMG- MadagascarMW- MalawiMY- MalaysiaMV- MaldivesML- MaliMT- MaltaMH- Marshall IslandsMQ- MartiniqueMR- MauritaniaMU- MauritiusYT- MayotteMX- MexicoFM- Micronesia (Federated States of)MD- MoldovaMC- MonacoMN- MongoliaME- MontenegroMS- MontserratMA- MoroccoMZ- MozambiqueMM- MyanmarNA- NamibiaNR- NauruNP- NepalNL- NetherlandsNC- New CaledoniaNZ- New ZealandNI- NicaraguaNE- NigerNG- NigeriaNU- NiueNF- Norfolk IslandKP- North KoreaMK- North MacedoniaMP- Northern Mariana IslandsNO- NorwayOM- OmanPK- PakistanPW- PalauPS- Palestine, State ofPA- PanamaPG- Papua New GuineaPY- ParaguayPE- PeruPH- PhilippinesPN- PitcairnPL- PolandPT- PortugalPR- Puerto RicoQA- QatarRE- RéunionRO- RomaniaRU- RussiaRW- RwandaBL- Saint BarthélemySH- Saint Helena, Ascension and Tristan da CunhaKN- Saint Kitts and NevisLC- Saint LuciaMF- Saint Martin (French part)PM- Saint Pierre and MiquelonVC- Saint Vincent and the GrenadinesWS- SamoaSM- San MarinoST- Sao Tome and PrincipeSA- Saudi ArabiaSN- SenegalRS- SerbiaSC- SeychellesSL- Sierra LeoneSG- SingaporeSX- Sint Maarten (Dutch part)SK- SlovakiaSI- SloveniaSB- Solomon IslandsSO- SomaliaZA- South AfricaGS- South Georgia and the South Sandwich IslandsKR- South KoreaSS- South SudanES- SpainLK- Sri LankaSD- SudanSR- SurinameSJ- Svalbard and Jan MayenSE- SwedenCH- SwitzerlandSY- SyriaTW- TaiwanTJ- TajikistanTZ- TanzaniaTH- ThailandTL- Timor-LesteTG- TogoTK- TokelauTO- TongaTT- Trinidad and TobagoTN- TunisiaTR- TurkeyTM- TurkmenistanTC- Turks and Caicos IslandsTV- TuvaluUG- UgandaUA- UkraineAE- United Arab EmiratesGB- United KingdomUM- United States Minor Outlying IslandsUS- United States of AmericaUY- UruguayUZ- UzbekistanVU- VanuatuVE- VenezuelaVN- VietnamVG- Virgin Islands (British)VI- Virgin Islands (U.S.)WF- Wallis and FutunaEH- Western SaharaYE- YemenZM- ZambiaZW- Zimbabwe.
276 277 278 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 276 def country @country end |
#integration_params ⇒ Hash{String => Object} (readonly)
282 283 284 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 282 def integration_params @integration_params end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
284 285 286 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 284 def linked_account_params @linked_account_params end |
#postal_code ⇒ String (readonly)
Returns The address's postal code.
25 26 27 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 25 def postal_code @postal_code end |
#state ⇒ String (readonly)
Returns The address's state.
23 24 25 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 23 def state @state end |
#street_1 ⇒ String (readonly)
Returns Line 1 of the address's street.
17 18 19 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 17 def street_1 @street_1 end |
#street_2 ⇒ String (readonly)
Returns Line 2 of the address's street.
19 20 21 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 19 def street_2 @street_2 end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Crm::AddressRequest
Deserialize a JSON object to an instance of AddressRequest
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 586 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) street_1 = parsed_json["street_1"] street_2 = parsed_json["street_2"] city = parsed_json["city"] state = parsed_json["state"] postal_code = parsed_json["postal_code"] country = parsed_json["country"] address_type = parsed_json["address_type"] integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] new( street_1: street_1, street_2: street_2, city: city, state: state, postal_code: postal_code, country: country, address_type: address_type, integration_params: integration_params, linked_account_params: linked_account_params, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 625 def self.validate_raw(obj:) obj.street_1&.is_a?(String) != false || raise("Passed value for field obj.street_1 is not the expected type, validation failed.") obj.street_2&.is_a?(String) != false || raise("Passed value for field obj.street_2 is not the expected type, validation failed.") obj.city&.is_a?(String) != false || raise("Passed value for field obj.city is not the expected type, validation failed.") obj.state&.is_a?(String) != false || raise("Passed value for field obj.state is not the expected type, validation failed.") obj.postal_code&.is_a?(String) != false || raise("Passed value for field obj.postal_code is not the expected type, validation failed.") obj.country&.is_a?(Merge::Crm::CountryEnum) != false || raise("Passed value for field obj.country is not the expected type, validation failed.") obj.address_type&.is_a?(Merge::Crm::AddressTypeEnum) != false || raise("Passed value for field obj.address_type is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AddressRequest to a JSON object
615 616 617 |
# File 'lib/merge_ruby_client/crm/types/address_request.rb', line 615 def to_json(*_args) @_field_set&.to_json end |