Class: Merge::Crm::Engagement

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/crm/types/engagement.rb

Overview

The Engagement Object

Description

The Engagement object is used to represent an interaction noted in a CRM system.

Usage Example

TODO

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, owner: OMIT, content: OMIT, subject: OMIT, direction: OMIT, engagement_type: OMIT, start_time: OMIT, end_time: OMIT, account: OMIT, contacts: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Crm::Engagement



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 94

def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, owner: OMIT, content: OMIT,
               subject: OMIT, direction: OMIT, engagement_type: OMIT, start_time: OMIT, end_time: OMIT, account: OMIT, contacts: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil)
  @id = id if id != OMIT
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @owner = owner if owner != OMIT
  @content = content if content != OMIT
  @subject = subject if subject != OMIT
  @direction = direction if direction != OMIT
  @engagement_type = engagement_type if engagement_type != OMIT
  @start_time = start_time if start_time != OMIT
  @end_time = end_time if end_time != OMIT
  @account =  if  != OMIT
  @contacts = contacts if contacts != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @field_mappings = field_mappings if field_mappings != OMIT
  @remote_data = remote_data if remote_data != OMIT
  @remote_fields = remote_fields if remote_fields != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "id": id,
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "owner": owner,
    "content": content,
    "subject": subject,
    "direction": direction,
    "engagement_type": engagement_type,
    "start_time": start_time,
    "end_time": end_time,
    "account": ,
    "contacts": contacts,
    "remote_was_deleted": remote_was_deleted,
    "field_mappings": field_mappings,
    "remote_data": remote_data,
    "remote_fields": remote_fields
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#accountMerge::Crm::EngagementAccount (readonly)



48
49
50
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 48

def 
  @account
end

#additional_propertiesOpenStruct (readonly)



63
64
65
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 63

def additional_properties
  @additional_properties
end

#contactsArray<Merge::Crm::EngagementContactsItem> (readonly)



50
51
52
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 50

def contacts
  @contacts
end

#contentString (readonly)



34
35
36
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 34

def content
  @content
end

#created_atDateTime (readonly)



28
29
30
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 28

def created_at
  @created_at
end

#directionMerge::Crm::DirectionEnum (readonly)



40
41
42
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 40

def direction
  @direction
end

#end_timeDateTime (readonly)



46
47
48
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 46

def end_time
  @end_time
end

#engagement_typeMerge::Crm::EngagementEngagementType (readonly)



42
43
44
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 42

def engagement_type
  @engagement_type
end

#field_mappingsHash{String => Object} (readonly)



57
58
59
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 57

def field_mappings
  @field_mappings
end

#idString (readonly)



24
25
26
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 24

def id
  @id
end

#modified_atDateTime (readonly)



30
31
32
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 30

def modified_at
  @modified_at
end

#ownerMerge::Crm::EngagementOwner (readonly)



32
33
34
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 32

def owner
  @owner
end

#remote_dataArray<Merge::Crm::RemoteData> (readonly)



59
60
61
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 59

def remote_data
  @remote_data
end

#remote_fieldsArray<Merge::Crm::RemoteField> (readonly)



61
62
63
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 61

def remote_fields
  @remote_fields
end

#remote_idString (readonly)



26
27
28
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 26

def remote_id
  @remote_id
end

#remote_was_deletedBoolean (readonly)



55
56
57
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 55

def remote_was_deleted
  @remote_was_deleted
end

#start_timeDateTime (readonly)



44
45
46
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 44

def start_time
  @start_time
end

#subjectString (readonly)



36
37
38
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 36

def subject
  @subject
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Crm::Engagement

Deserialize a JSON object to an instance of Engagement



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 141

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  id = parsed_json["id"]
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  if parsed_json["owner"].nil?
    owner = nil
  else
    owner = parsed_json["owner"].to_json
    owner = Merge::Crm::EngagementOwner.from_json(json_object: owner)
  end
  content = parsed_json["content"]
  subject = parsed_json["subject"]
  direction = parsed_json["direction"]
  if parsed_json["engagement_type"].nil?
    engagement_type = nil
  else
    engagement_type = parsed_json["engagement_type"].to_json
    engagement_type = Merge::Crm::EngagementEngagementType.from_json(json_object: engagement_type)
  end
  start_time = (DateTime.parse(parsed_json["start_time"]) unless parsed_json["start_time"].nil?)
  end_time = (DateTime.parse(parsed_json["end_time"]) unless parsed_json["end_time"].nil?)
  if parsed_json["account"].nil?
     = nil
  else
     = parsed_json["account"].to_json
     = Merge::Crm::EngagementAccount.from_json(json_object: )
  end
  contacts = parsed_json["contacts"]&.map do |item|
    item = item.to_json
    Merge::Crm::EngagementContactsItem.from_json(json_object: item)
  end
  remote_was_deleted = parsed_json["remote_was_deleted"]
  field_mappings = parsed_json["field_mappings"]
  remote_data = parsed_json["remote_data"]&.map do |item|
    item = item.to_json
    Merge::Crm::RemoteData.from_json(json_object: item)
  end
  remote_fields = parsed_json["remote_fields"]&.map do |item|
    item = item.to_json
    Merge::Crm::RemoteField.from_json(json_object: item)
  end
  new(
    id: id,
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    owner: owner,
    content: content,
    subject: subject,
    direction: direction,
    engagement_type: engagement_type,
    start_time: start_time,
    end_time: end_time,
    account: ,
    contacts: contacts,
    remote_was_deleted: remote_was_deleted,
    field_mappings: field_mappings,
    remote_data: remote_data,
    remote_fields: remote_fields,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 220

def self.validate_raw(obj:)
  obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.owner.nil? || Merge::Crm::EngagementOwner.validate_raw(obj: obj.owner)
  obj.content&.is_a?(String) != false || raise("Passed value for field obj.content is not the expected type, validation failed.")
  obj.subject&.is_a?(String) != false || raise("Passed value for field obj.subject is not the expected type, validation failed.")
  obj.direction&.is_a?(Merge::Crm::DirectionEnum) != false || raise("Passed value for field obj.direction is not the expected type, validation failed.")
  obj.engagement_type.nil? || Merge::Crm::EngagementEngagementType.validate_raw(obj: obj.engagement_type)
  obj.start_time&.is_a?(DateTime) != false || raise("Passed value for field obj.start_time is not the expected type, validation failed.")
  obj.end_time&.is_a?(DateTime) != false || raise("Passed value for field obj.end_time is not the expected type, validation failed.")
  obj..nil? || Merge::Crm::EngagementAccount.validate_raw(obj: obj.)
  obj.contacts&.is_a?(Array) != false || raise("Passed value for field obj.contacts is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
  obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.")
  obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.")
  obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Engagement to a JSON object



210
211
212
# File 'lib/merge_ruby_client/crm/types/engagement.rb', line 210

def to_json(*_args)
  @_field_set&.to_json
end