Class: Merge::Crm::PatchedAccountRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/crm/types/patched_account_request.rb

Overview

The Account Object

Description

The Account object is used to represent a company in a CRM system.

Usage Example

TODO

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(owner: OMIT, name: OMIT, description: OMIT, industry: OMIT, website: OMIT, number_of_employees: OMIT, addresses: OMIT, last_activity_at: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Crm::PatchedAccountRequest



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 62

def initialize(owner: OMIT, name: OMIT, description: OMIT, industry: OMIT, website: OMIT,
               number_of_employees: OMIT, addresses: OMIT, last_activity_at: OMIT, integration_params: OMIT, linked_account_params: OMIT, remote_fields: OMIT, additional_properties: nil)
  @owner = owner if owner != OMIT
  @name = name if name != OMIT
  @description = description if description != OMIT
  @industry = industry if industry != OMIT
  @website = website if website != OMIT
  @number_of_employees = number_of_employees if number_of_employees != OMIT
  @addresses = addresses if addresses != OMIT
  @last_activity_at = last_activity_at if last_activity_at != OMIT
  @integration_params = integration_params if integration_params != OMIT
   =  if  != OMIT
  @remote_fields = remote_fields if remote_fields != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "owner": owner,
    "name": name,
    "description": description,
    "industry": industry,
    "website": website,
    "number_of_employees": number_of_employees,
    "addresses": addresses,
    "last_activity_at": last_activity_at,
    "integration_params": integration_params,
    "linked_account_params": ,
    "remote_fields": remote_fields
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



41
42
43
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 41

def additional_properties
  @additional_properties
end

#addressesArray<Merge::Crm::AddressRequest> (readonly)



30
31
32
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 30

def addresses
  @addresses
end

#descriptionString (readonly)



22
23
24
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 22

def description
  @description
end

#industryString (readonly)



24
25
26
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 24

def industry
  @industry
end

#integration_paramsHash{String => Object} (readonly)



35
36
37
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 35

def integration_params
  @integration_params
end

#last_activity_atDateTime (readonly)



33
34
35
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 33

def last_activity_at
  @last_activity_at
end

#linked_account_paramsHash{String => Object} (readonly)



37
38
39
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 37

def 
  
end

#nameString (readonly)



20
21
22
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 20

def name
  @name
end

#number_of_employeesInteger (readonly)



28
29
30
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 28

def number_of_employees
  @number_of_employees
end

#ownerString (readonly)



18
19
20
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 18

def owner
  @owner
end

#remote_fieldsArray<Merge::Crm::RemoteFieldRequest> (readonly)



39
40
41
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 39

def remote_fields
  @remote_fields
end

#websiteString (readonly)



26
27
28
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 26

def website
  @website
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Crm::PatchedAccountRequest

Deserialize a JSON object to an instance of PatchedAccountRequest



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 97

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  owner = parsed_json["owner"]
  name = parsed_json["name"]
  description = parsed_json["description"]
  industry = parsed_json["industry"]
  website = parsed_json["website"]
  number_of_employees = parsed_json["number_of_employees"]
  addresses = parsed_json["addresses"]&.map do |item|
    item = item.to_json
    Merge::Crm::AddressRequest.from_json(json_object: item)
  end
  last_activity_at = (DateTime.parse(parsed_json["last_activity_at"]) unless parsed_json["last_activity_at"].nil?)
  integration_params = parsed_json["integration_params"]
   = parsed_json["linked_account_params"]
  remote_fields = parsed_json["remote_fields"]&.map do |item|
    item = item.to_json
    Merge::Crm::RemoteFieldRequest.from_json(json_object: item)
  end
  new(
    owner: owner,
    name: name,
    description: description,
    industry: industry,
    website: website,
    number_of_employees: number_of_employees,
    addresses: addresses,
    last_activity_at: last_activity_at,
    integration_params: integration_params,
    linked_account_params: ,
    remote_fields: remote_fields,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 146

def self.validate_raw(obj:)
  obj.owner&.is_a?(String) != false || raise("Passed value for field obj.owner is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.")
  obj.industry&.is_a?(String) != false || raise("Passed value for field obj.industry is not the expected type, validation failed.")
  obj.website&.is_a?(String) != false || raise("Passed value for field obj.website is not the expected type, validation failed.")
  obj.number_of_employees&.is_a?(Integer) != false || raise("Passed value for field obj.number_of_employees is not the expected type, validation failed.")
  obj.addresses&.is_a?(Array) != false || raise("Passed value for field obj.addresses is not the expected type, validation failed.")
  obj.last_activity_at&.is_a?(DateTime) != false || raise("Passed value for field obj.last_activity_at is not the expected type, validation failed.")
  obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.")
  obj.&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.")
  obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of PatchedAccountRequest to a JSON object



136
137
138
# File 'lib/merge_ruby_client/crm/types/patched_account_request.rb', line 136

def to_json(*_args)
  @_field_set&.to_json
end