Class: Merge::Crm::PhoneNumberRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/crm/types/phone_number_request.rb

Overview

The PhoneNumber Object

Description

The PhoneNumber object is used to represent an entity's phone number.

Usage Example

Fetch from the GET Contact endpoint and view their phone numbers.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(phone_number: OMIT, phone_number_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) ⇒ Merge::Crm::PhoneNumberRequest

Parameters:

  • phone_number (String) (defaults to: OMIT)

    The phone number.

  • phone_number_type (String) (defaults to: OMIT)

    The phone number's type.

  • integration_params (Hash{String => Object}) (defaults to: OMIT)
  • linked_account_params (Hash{String => Object}) (defaults to: OMIT)
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 36

def initialize(phone_number: OMIT, phone_number_type: OMIT, integration_params: OMIT,
               linked_account_params: OMIT, additional_properties: nil)
  @phone_number = phone_number if phone_number != OMIT
  @phone_number_type = phone_number_type if phone_number_type != OMIT
  @integration_params = integration_params if integration_params != OMIT
  @linked_account_params =  if  != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "phone_number": phone_number,
    "phone_number_type": phone_number_type,
    "integration_params": integration_params,
    "linked_account_params": 
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



23
24
25
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 23

def additional_properties
  @additional_properties
end

#integration_paramsHash{String => Object} (readonly)

Returns:

  • (Hash{String => Object})


19
20
21
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 19

def integration_params
  @integration_params
end

#linked_account_paramsHash{String => Object} (readonly)

Returns:

  • (Hash{String => Object})


21
22
23
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 21

def 
  @linked_account_params
end

#phone_numberString (readonly)

Returns The phone number.

Returns:

  • (String)

    The phone number.



15
16
17
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 15

def phone_number
  @phone_number
end

#phone_number_typeString (readonly)

Returns The phone number's type.

Returns:

  • (String)

    The phone number's type.



17
18
19
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 17

def phone_number_type
  @phone_number_type
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Crm::PhoneNumberRequest

Deserialize a JSON object to an instance of PhoneNumberRequest

Parameters:

  • json_object (String)

Returns:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 57

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  phone_number = parsed_json["phone_number"]
  phone_number_type = parsed_json["phone_number_type"]
  integration_params = parsed_json["integration_params"]
   = parsed_json["linked_account_params"]
  new(
    phone_number: phone_number,
    phone_number_type: phone_number_type,
    integration_params: integration_params,
    linked_account_params: ,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


86
87
88
89
90
91
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 86

def self.validate_raw(obj:)
  obj.phone_number&.is_a?(String) != false || raise("Passed value for field obj.phone_number is not the expected type, validation failed.")
  obj.phone_number_type&.is_a?(String) != false || raise("Passed value for field obj.phone_number_type is not the expected type, validation failed.")
  obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.")
  obj.&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of PhoneNumberRequest to a JSON object

Returns:

  • (String)


76
77
78
# File 'lib/merge_ruby_client/crm/types/phone_number_request.rb', line 76

def to_json(*_args)
  @_field_set&.to_json
end