Class: Merge::Filestorage::SyncStatusClient
- Inherits:
-
Object
- Object
- Merge::Filestorage::SyncStatusClient
- Defined in:
- lib/merge_ruby_client/filestorage/sync_status/client.rb
Instance Attribute Summary collapse
Instance Method Summary collapse
- #initialize(request_client:) ⇒ Merge::Filestorage::SyncStatusClient constructor
-
#list(cursor: nil, page_size: nil, request_options: nil) ⇒ Merge::Filestorage::PaginatedSyncStatusList
Get sync status for the current sync and the most recently finished sync.
Constructor Details
#initialize(request_client:) ⇒ Merge::Filestorage::SyncStatusClient
15 16 17 |
# File 'lib/merge_ruby_client/filestorage/sync_status/client.rb', line 15 def initialize(request_client:) @request_client = request_client end |
Instance Attribute Details
#request_client ⇒ Merge::RequestClient (readonly)
11 12 13 |
# File 'lib/merge_ruby_client/filestorage/sync_status/client.rb', line 11 def request_client @request_client end |
Instance Method Details
#list(cursor: nil, page_size: nil, request_options: nil) ⇒ Merge::Filestorage::PaginatedSyncStatusList
Get sync status for the current sync and the most recently finished sync.
last_sync_start represents the most recent time any sync began.
last_sync_finished represents the most recent time any sync completed. These
timestamps may correspond to different sync instances which may result in a sync
start time being later than a separate sync completed time. To ensure you are
retrieving the latest available data reference the last_sync_finished
timestamp where last_sync_result is DONE. Possible values for status and
last_sync_result are DISABLED, DONE, FAILED, PARTIALLY_SYNCED,
PAUSED, SYNCING. Learn more about sync status in our Help
Center.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/merge_ruby_client/filestorage/sync_status/client.rb', line 41 def list(cursor: nil, page_size: nil, request_options: nil) response = @request_client.conn.get do |req| req..timeout = .timeout_in_seconds unless &.timeout_in_seconds.nil? req.headers["Authorization"] = .api_key unless &.api_key.nil? req.headers["X-Account-Token"] = .account_token unless &.account_token.nil? req.headers = { **(req.headers || {}), **@request_client.get_headers, **(&.additional_headers || {}) }.compact req.params = { **(&.additional_query_parameters || {}), "cursor": cursor, "page_size": page_size }.compact unless .nil? || &.additional_body_parameters.nil? req.body = { **(&.additional_body_parameters || {}) }.compact end req.url "#{@request_client.get_url(request_options: )}/filestorage/v1/sync-status" end Merge::Filestorage::PaginatedSyncStatusList.from_json(json_object: response.body) end |