Class: Merge::Hris::Earning

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/hris/types/earning.rb

Overview

The Earning Object

Description

The Earning object is used to represent an array of different compensations that an employee receives within specific wage categories.

Usage Example

Fetch from the LIST Earnings endpoint and filter by ID to show all earnings.

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, employee_payroll_run: OMIT, amount: OMIT, type: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil) ⇒ Merge::Hris::Earning



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 72

def initialize(id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, employee_payroll_run: OMIT,
               amount: OMIT, type: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, additional_properties: nil)
  @id = id if id != OMIT
  @remote_id = remote_id if remote_id != OMIT
  @created_at = created_at if created_at != OMIT
  @modified_at = modified_at if modified_at != OMIT
  @employee_payroll_run = employee_payroll_run if employee_payroll_run != OMIT
  @amount = amount if amount != OMIT
  @type = type if type != OMIT
  @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT
  @field_mappings = field_mappings if field_mappings != OMIT
  @remote_data = remote_data if remote_data != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "id": id,
    "remote_id": remote_id,
    "created_at": created_at,
    "modified_at": modified_at,
    "employee_payroll_run": employee_payroll_run,
    "amount": amount,
    "type": type,
    "remote_was_deleted": remote_was_deleted,
    "field_mappings": field_mappings,
    "remote_data": remote_data
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)



46
47
48
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 46

def additional_properties
  @additional_properties
end

#amountFloat (readonly)



29
30
31
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 29

def amount
  @amount
end

#created_atDateTime (readonly)



23
24
25
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 23

def created_at
  @created_at
end

#employee_payroll_runString (readonly)



27
28
29
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 27

def employee_payroll_run
  @employee_payroll_run
end

#field_mappingsHash{String => Object} (readonly)



42
43
44
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 42

def field_mappings
  @field_mappings
end

#idString (readonly)



19
20
21
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 19

def id
  @id
end

#modified_atDateTime (readonly)



25
26
27
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 25

def modified_at
  @modified_at
end

#remote_dataArray<Merge::Hris::RemoteData> (readonly)



44
45
46
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 44

def remote_data
  @remote_data
end

#remote_idString (readonly)



21
22
23
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 21

def remote_id
  @remote_id
end

#remote_was_deletedBoolean (readonly)



40
41
42
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 40

def remote_was_deleted
  @remote_was_deleted
end

#typeMerge::Hris::EarningTypeEnum (readonly)



35
36
37
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 35

def type
  @type
end

Class Method Details

.from_json(json_object:) ⇒ Merge::Hris::Earning

Deserialize a JSON object to an instance of Earning



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 105

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  id = parsed_json["id"]
  remote_id = parsed_json["remote_id"]
  created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?)
  modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?)
  employee_payroll_run = parsed_json["employee_payroll_run"]
  amount = parsed_json["amount"]
  type = parsed_json["type"]
  remote_was_deleted = parsed_json["remote_was_deleted"]
  field_mappings = parsed_json["field_mappings"]
  remote_data = parsed_json["remote_data"]&.map do |item|
    item = item.to_json
    Merge::Hris::RemoteData.from_json(json_object: item)
  end
  new(
    id: id,
    remote_id: remote_id,
    created_at: created_at,
    modified_at: modified_at,
    employee_payroll_run: employee_payroll_run,
    amount: amount,
    type: type,
    remote_was_deleted: remote_was_deleted,
    field_mappings: field_mappings,
    remote_data: remote_data,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 149

def self.validate_raw(obj:)
  obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.")
  obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.")
  obj.employee_payroll_run&.is_a?(String) != false || raise("Passed value for field obj.employee_payroll_run is not the expected type, validation failed.")
  obj.amount&.is_a?(Float) != false || raise("Passed value for field obj.amount is not the expected type, validation failed.")
  obj.type&.is_a?(Merge::Hris::EarningTypeEnum) != false || raise("Passed value for field obj.type is not the expected type, validation failed.")
  obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.")
  obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.")
  obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Earning to a JSON object



139
140
141
# File 'lib/merge_ruby_client/hris/types/earning.rb', line 139

def to_json(*_args)
  @_field_set&.to_json
end