Class: Merge::Ticketing::AsyncProjectsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/merge_ruby_client/ticketing/projects/client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(request_client:) ⇒ Merge::Ticketing::AsyncProjectsClient

Parameters:



180
181
182
# File 'lib/merge_ruby_client/ticketing/projects/client.rb', line 180

def initialize(request_client:)
  @request_client = request_client
end

Instance Attribute Details

#request_clientMerge::AsyncRequestClient (readonly)



176
177
178
# File 'lib/merge_ruby_client/ticketing/projects/client.rb', line 176

def request_client
  @request_client
end

Instance Method Details

#list(created_after: nil, created_before: nil, cursor: nil, include_deleted_data: nil, include_remote_data: nil, include_shell_data: nil, modified_after: nil, modified_before: nil, page_size: nil, remote_id: nil, request_options: nil) ⇒ Merge::Ticketing::PaginatedProjectList

Returns a list of Project objects.

Examples:

api = Merge::Client.new(
  base_url: "https://api.example.com",
  environment: Merge::Environment::PRODUCTION,
  api_key: "YOUR_AUTH_TOKEN"
)
api.ticketing.projects.list(cursor: "cD0yMDIxLTAxLTA2KzAzJTNBMjQlM0E1My40MzQzMjYlMkIwMCUzQTAw")

Parameters:

  • created_after (DateTime) (defaults to: nil)

    If provided, will only return objects created after this datetime.

  • created_before (DateTime) (defaults to: nil)

    If provided, will only return objects created before this datetime.

  • cursor (String) (defaults to: nil)

    The pagination cursor value.

  • include_deleted_data (Boolean) (defaults to: nil)

    Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. [Learn more](docs.merge.dev/integrations/hris/supported-features/).

  • include_remote_data (Boolean) (defaults to: nil)

    Whether to include the original data Merge fetched from the third-party to produce these models.

  • include_shell_data (Boolean) (defaults to: nil)

    Whether to include shell records. Shell records are empty records (they may contain some metadata but all other fields are null).

  • modified_after (DateTime) (defaults to: nil)

    If provided, only objects synced by Merge after this date time will be returned.

  • modified_before (DateTime) (defaults to: nil)

    If provided, only objects synced by Merge before this date time will be returned.

  • page_size (Integer) (defaults to: nil)

    Number of results to return per page.

  • remote_id (String) (defaults to: nil)

    The API provider’s ID for the given object.

  • request_options (Merge::RequestOptions) (defaults to: nil)

Returns:



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/merge_ruby_client/ticketing/projects/client.rb', line 211

def list(created_after: nil, created_before: nil, cursor: nil, include_deleted_data: nil,
         include_remote_data: nil, include_shell_data: nil, modified_after: nil, modified_before: nil, page_size: nil, remote_id: nil, request_options: nil)
  Async do
    response = @request_client.conn.get do |req|
      req.options.timeout = request_options.timeout_in_seconds unless request_options&.timeout_in_seconds.nil?
      req.headers["Authorization"] = request_options.api_key unless request_options&.api_key.nil?
      req.headers["X-Account-Token"] = request_options. unless request_options&..nil?
      req.headers = {
    **(req.headers || {}),
    **@request_client.get_headers,
    **(request_options&.additional_headers || {})
      }.compact
      req.params = {
        **(request_options&.additional_query_parameters || {}),
        "created_after": created_after,
        "created_before": created_before,
        "cursor": cursor,
        "include_deleted_data": include_deleted_data,
        "include_remote_data": include_remote_data,
        "include_shell_data": include_shell_data,
        "modified_after": modified_after,
        "modified_before": modified_before,
        "page_size": page_size,
        "remote_id": remote_id
      }.compact
      unless request_options.nil? || request_options&.additional_body_parameters.nil?
        req.body = { **(request_options&.additional_body_parameters || {}) }.compact
      end
      req.url "#{@request_client.get_url(request_options: request_options)}/ticketing/v1/projects"
    end
    Merge::Ticketing::PaginatedProjectList.from_json(json_object: response.body)
  end
end

#retrieve(id:, include_remote_data: nil, include_shell_data: nil, request_options: nil) ⇒ Merge::Ticketing::Project

Returns a Project object with the given id.

Examples:

api = Merge::Client.new(
  base_url: "https://api.example.com",
  environment: Merge::Environment::PRODUCTION,
  api_key: "YOUR_AUTH_TOKEN"
)
api.ticketing.projects.retrieve(id: "id")

Parameters:

  • id (String)
  • include_remote_data (Boolean) (defaults to: nil)

    Whether to include the original data Merge fetched from the third-party to produce these models.

  • include_shell_data (Boolean) (defaults to: nil)

    Whether to include shell records. Shell records are empty records (they may contain some metadata but all other fields are null).

  • request_options (Merge::RequestOptions) (defaults to: nil)

Returns:



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/merge_ruby_client/ticketing/projects/client.rb', line 261

def retrieve(id:, include_remote_data: nil, include_shell_data: nil, request_options: nil)
  Async do
    response = @request_client.conn.get do |req|
      req.options.timeout = request_options.timeout_in_seconds unless request_options&.timeout_in_seconds.nil?
      req.headers["Authorization"] = request_options.api_key unless request_options&.api_key.nil?
      req.headers["X-Account-Token"] = request_options. unless request_options&..nil?
      req.headers = {
    **(req.headers || {}),
    **@request_client.get_headers,
    **(request_options&.additional_headers || {})
      }.compact
      req.params = {
        **(request_options&.additional_query_parameters || {}),
        "include_remote_data": include_remote_data,
        "include_shell_data": include_shell_data
      }.compact
      unless request_options.nil? || request_options&.additional_body_parameters.nil?
        req.body = { **(request_options&.additional_body_parameters || {}) }.compact
      end
      req.url "#{@request_client.get_url(request_options: request_options)}/ticketing/v1/projects/#{id}"
    end
    Merge::Ticketing::Project.from_json(json_object: response.body)
  end
end

#users_list(parent_id:, cursor: nil, expand: nil, include_deleted_data: nil, include_remote_data: nil, include_shell_data: nil, page_size: nil, request_options: nil) ⇒ Merge::Ticketing::PaginatedUserList

Returns a list of User objects.

Examples:

api = Merge::Client.new(
  base_url: "https://api.example.com",
  environment: Merge::Environment::PRODUCTION,
  api_key: "YOUR_AUTH_TOKEN"
)
api.ticketing.projects.users_list(parent_id: "parent_id", cursor: "cD0yMDIxLTAxLTA2KzAzJTNBMjQlM0E1My40MzQzMjYlMkIwMCUzQTAw")

Parameters:

  • parent_id (String)
  • cursor (String) (defaults to: nil)

    The pagination cursor value.

  • expand (Merge::Ticketing::Projects::ProjectsUsersListRequestExpand) (defaults to: nil)

    Which relations should be returned in expanded form. Multiple relation names should be comma separated without spaces.

  • include_deleted_data (Boolean) (defaults to: nil)

    Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. [Learn more](docs.merge.dev/integrations/hris/supported-features/).

  • include_remote_data (Boolean) (defaults to: nil)

    Whether to include the original data Merge fetched from the third-party to produce these models.

  • include_shell_data (Boolean) (defaults to: nil)

    Whether to include shell records. Shell records are empty records (they may contain some metadata but all other fields are null).

  • page_size (Integer) (defaults to: nil)

    Number of results to return per page.

  • request_options (Merge::RequestOptions) (defaults to: nil)

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/merge_ruby_client/ticketing/projects/client.rb', line 310

def users_list(parent_id:, cursor: nil, expand: nil, include_deleted_data: nil, include_remote_data: nil,
               include_shell_data: nil, page_size: nil, request_options: nil)
  Async do
    response = @request_client.conn.get do |req|
      req.options.timeout = request_options.timeout_in_seconds unless request_options&.timeout_in_seconds.nil?
      req.headers["Authorization"] = request_options.api_key unless request_options&.api_key.nil?
      req.headers["X-Account-Token"] = request_options. unless request_options&..nil?
      req.headers = {
    **(req.headers || {}),
    **@request_client.get_headers,
    **(request_options&.additional_headers || {})
      }.compact
      req.params = {
        **(request_options&.additional_query_parameters || {}),
        "cursor": cursor,
        "expand": expand,
        "include_deleted_data": include_deleted_data,
        "include_remote_data": include_remote_data,
        "include_shell_data": include_shell_data,
        "page_size": page_size
      }.compact
      unless request_options.nil? || request_options&.additional_body_parameters.nil?
        req.body = { **(request_options&.additional_body_parameters || {}) }.compact
      end
      req.url "#{@request_client.get_url(request_options: request_options)}/ticketing/v1/projects/#{parent_id}/users"
    end
    Merge::Ticketing::PaginatedUserList.from_json(json_object: response.body)
  end
end