Class: Merge::Accounting::BankFeedAccountRequest
- Inherits:
-
Object
- Object
- Merge::Accounting::BankFeedAccountRequest
- Defined in:
- lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb
Overview
The BankFeedAccount Object
Description
The BankFeedAccount object represents a bank feed account, detailing various
attributes including account identifiers, names, currency, and balance
information. This object is central to managing and tracking bank feed accounts
within the system.
Usage Example
Fetch from the GET BankFeedAccount endpoint to view details of a bank feed
account.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#account_type ⇒ Merge::Accounting::BankFeedAccountAccountTypeEnum
readonly
The type of the account.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
The currency code of the bank feed.
-
#feed_start_date ⇒ DateTime
readonly
The start date of the bank feed’s transactions.
-
#feed_status ⇒ Merge::Accounting::FeedStatusEnum
readonly
The status of the bank feed.
- #integration_params ⇒ Hash{String => Object} readonly
- #linked_account_params ⇒ Hash{String => Object} readonly
-
#source_account_balance ⇒ Float
readonly
The current balance of funds in the source account.
-
#source_account_id ⇒ String
readonly
The unique identifier of the source account from our customer’s platform.
-
#source_account_name ⇒ String
readonly
The name of the source account as stored in our customer’s platform.
-
#source_account_number ⇒ String
readonly
The human-readable account number of the source account as stored in our customer’s platform.
-
#target_account_id ⇒ String
readonly
The unique identifier of the target account from the third party software.
-
#target_account_name ⇒ String
readonly
The name of the target account from the third party software.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::BankFeedAccountRequest
Deserialize a JSON object to an instance of BankFeedAccountRequest.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) ⇒ Merge::Accounting::BankFeedAccountRequest constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of BankFeedAccountRequest to a JSON object.
Constructor Details
#initialize(source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) ⇒ Merge::Accounting::BankFeedAccountRequest
690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 690 def initialize(source_account_id: OMIT, target_account_id: OMIT, source_account_name: OMIT, source_account_number: OMIT, target_account_name: OMIT, currency: OMIT, feed_status: OMIT, feed_start_date: OMIT, source_account_balance: OMIT, account_type: OMIT, integration_params: OMIT, linked_account_params: OMIT, additional_properties: nil) @source_account_id = source_account_id if source_account_id != OMIT @target_account_id = target_account_id if target_account_id != OMIT @source_account_name = source_account_name if source_account_name != OMIT @source_account_number = source_account_number if source_account_number != OMIT @target_account_name = target_account_name if target_account_name != OMIT @currency = currency if currency != OMIT @feed_status = feed_status if feed_status != OMIT @feed_start_date = feed_start_date if feed_start_date != OMIT @source_account_balance = source_account_balance if source_account_balance != OMIT @account_type = account_type if account_type != OMIT @integration_params = integration_params if integration_params != OMIT @linked_account_params = linked_account_params if linked_account_params != OMIT @additional_properties = additional_properties @_field_set = { "source_account_id": source_account_id, "target_account_id": target_account_id, "source_account_name": source_account_name, "source_account_number": source_account_number, "target_account_name": target_account_name, "currency": currency, "feed_status": feed_status, "feed_start_date": feed_start_date, "source_account_balance": source_account_balance, "account_type": account_type, "integration_params": integration_params, "linked_account_params": linked_account_params }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#account_type ⇒ Merge::Accounting::BankFeedAccountAccountTypeEnum (readonly)
352 353 354 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 352 def account_type @account_type end |
#additional_properties ⇒ OpenStruct (readonly)
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 358 def additional_properties @additional_properties end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
340 341 342 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 340 def currency @currency end |
#feed_start_date ⇒ DateTime (readonly)
346 347 348 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 346 def feed_start_date @feed_start_date end |
#feed_status ⇒ Merge::Accounting::FeedStatusEnum (readonly)
344 345 346 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 344 def feed_status @feed_status end |
#integration_params ⇒ Hash{String => Object} (readonly)
354 355 356 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 354 def integration_params @integration_params end |
#linked_account_params ⇒ Hash{String => Object} (readonly)
356 357 358 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 356 def linked_account_params @linked_account_params end |
#source_account_balance ⇒ Float (readonly)
348 349 350 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 348 def source_account_balance @source_account_balance end |
#source_account_id ⇒ String (readonly)
23 24 25 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 23 def source_account_id @source_account_id end |
#source_account_name ⇒ String (readonly)
27 28 29 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 27 def source_account_name @source_account_name end |
#source_account_number ⇒ String (readonly)
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 30 def source_account_number @source_account_number end |
#target_account_id ⇒ String (readonly)
25 26 27 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 25 def target_account_id @target_account_id end |
#target_account_name ⇒ String (readonly)
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 32 def target_account_name @target_account_name end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::BankFeedAccountRequest
Deserialize a JSON object to an instance of BankFeedAccountRequest
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 727 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) source_account_id = parsed_json["source_account_id"] target_account_id = parsed_json["target_account_id"] source_account_name = parsed_json["source_account_name"] source_account_number = parsed_json["source_account_number"] target_account_name = parsed_json["target_account_name"] currency = parsed_json["currency"] feed_status = parsed_json["feed_status"] feed_start_date = (DateTime.parse(parsed_json["feed_start_date"]) unless parsed_json["feed_start_date"].nil?) source_account_balance = parsed_json["source_account_balance"] account_type = parsed_json["account_type"] integration_params = parsed_json["integration_params"] linked_account_params = parsed_json["linked_account_params"] new( source_account_id: source_account_id, target_account_id: target_account_id, source_account_name: source_account_name, source_account_number: source_account_number, target_account_name: target_account_name, currency: currency, feed_status: feed_status, feed_start_date: feed_start_date, source_account_balance: source_account_balance, account_type: account_type, integration_params: integration_params, linked_account_params: linked_account_params, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 772 def self.validate_raw(obj:) obj.source_account_id&.is_a?(String) != false || raise("Passed value for field obj.source_account_id is not the expected type, validation failed.") obj.target_account_id&.is_a?(String) != false || raise("Passed value for field obj.target_account_id is not the expected type, validation failed.") obj.source_account_name&.is_a?(String) != false || raise("Passed value for field obj.source_account_name is not the expected type, validation failed.") obj.source_account_number&.is_a?(String) != false || raise("Passed value for field obj.source_account_number is not the expected type, validation failed.") obj.target_account_name&.is_a?(String) != false || raise("Passed value for field obj.target_account_name is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.feed_status&.is_a?(Merge::Accounting::FeedStatusEnum) != false || raise("Passed value for field obj.feed_status is not the expected type, validation failed.") obj.feed_start_date&.is_a?(DateTime) != false || raise("Passed value for field obj.feed_start_date is not the expected type, validation failed.") obj.source_account_balance&.is_a?(Float) != false || raise("Passed value for field obj.source_account_balance is not the expected type, validation failed.") obj.account_type&.is_a?(Merge::Accounting::BankFeedAccountAccountTypeEnum) != false || raise("Passed value for field obj.account_type is not the expected type, validation failed.") obj.integration_params&.is_a?(Hash) != false || raise("Passed value for field obj.integration_params is not the expected type, validation failed.") obj.linked_account_params&.is_a?(Hash) != false || raise("Passed value for field obj.linked_account_params is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of BankFeedAccountRequest to a JSON object
762 763 764 |
# File 'lib/merge_ruby_client/accounting/types/bank_feed_account_request.rb', line 762 def to_json(*_args) @_field_set&.to_json end |