Class: Merge::Accounting::ExpenseReport
- Inherits:
-
Object
- Object
- Merge::Accounting::ExpenseReport
- Defined in:
- lib/merge_ruby_client/accounting/types/expense_report.rb
Overview
# The ExpenseReport Object
### Description
The `ExpenseReport` object represents a collection of expenses submitted for
review and reimbursement.
It includes details about the submitter, status, amounts, and associated
.
### Usage Example
Fetch from the `GET ExpenseReport` endpoint to view details of expense reports
and their line items.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#accounting_period ⇒ String
readonly
The accounting period the report was posted in.
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company ⇒ Merge::Accounting::ExpenseReportCompany
readonly
The subsidiary that the expense report is created in.
-
#created_at ⇒ DateTime
readonly
The datetime that this object was created by Merge.
-
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum
readonly
Currency code for the expense report *
XUA- ADB Unit of Account *AFN- Afghan Afghani *AFA- Afghan Afghani (1927–2002) *ALL- Albanian Lek *ALK- Albanian Lek (1946–1965) *DZD- Algerian Dinar *ADP- Andorran Peseta *AOA- Angolan Kwanza *AOK- Angolan Kwanza (1977–1991) *AON- Angolan New Kwanza (1990–2000) *AOR- Angolan Readjusted Kwanza (1995–1999) *ARA- Argentine Austral *ARS- Argentine Peso *ARM- Argentine Peso (1881–1970) *ARP- Argentine Peso (1983–1985) *ARL- Argentine Peso Ley (1970–1983) *AMD- Armenian Dram *AWG- Aruban Florin *AUD- Australian Dollar *ATS- Austrian Schilling *AZN- Azerbaijani Manat *AZM- Azerbaijani Manat (1993–2006) *BSD- Bahamian Dollar *BHD- Bahraini Dinar *BDT- Bangladeshi Taka *BBD- Barbadian Dollar *BYN- Belarusian Ruble *BYB- Belarusian Ruble (1994–1999) *BYR- Belarusian Ruble (2000–2016) *BEF- Belgian Franc *BEC- Belgian Franc (convertible) *BEL- Belgian Franc (financial) *BZD- Belize Dollar *BMD- Bermudan Dollar *BTN- Bhutanese Ngultrum *BOB- Bolivian Boliviano *BOL- Bolivian Boliviano (1863–1963) *BOV- Bolivian Mvdol *BOP- Bolivian Peso *BAM- Bosnia-Herzegovina Convertible Mark *BAD- Bosnia-Herzegovina Dinar (1992–1994) *BAN- Bosnia-Herzegovina New Dinar (1994–1997) *BWP- Botswanan Pula *BRC- Brazilian Cruzado (1986–1989) *BRZ- Brazilian Cruzeiro (1942–1967) *BRE- Brazilian Cruzeiro (1990–1993) *BRR- Brazilian Cruzeiro (1993–1994) *BRN- Brazilian New Cruzado (1989–1990) *BRB- Brazilian New Cruzeiro (1967–1986) *BRL- Brazilian Real *GBP- British Pound *BND- Brunei Dollar *BGL- Bulgarian Hard Lev *BGN- Bulgarian Lev *BGO- Bulgarian Lev (1879–1952) *BGM- Bulgarian Socialist Lev *BUK- Burmese Kyat *BIF- Burundian Franc *XPF- CFP Franc *KHR- Cambodian Riel *CAD- Canadian Dollar *CVE- Cape Verdean Escudo *KYD- Cayman Islands Dollar *XAF- Central African CFA Franc *CLE- Chilean Escudo *CLP- Chilean Peso *CLF- Chilean Unit of Account (UF) *CNX- Chinese People’s Bank Dollar *CNY- Chinese Yuan *CNH- Chinese Yuan (offshore) *COP- Colombian Peso *COU- Colombian Real Value Unit *KMF- Comorian Franc *CDF- Congolese Franc *CRC- Costa Rican Colón *HRD- Croatian Dinar *HRK- Croatian Kuna *CUC- Cuban Convertible Peso *CUP- Cuban Peso *CYP- Cypriot Pound *CZK- Czech Koruna *CSK- Czechoslovak Hard Koruna *DKK- Danish Krone *DJF- Djiboutian Franc *DOP- Dominican Peso *NLG- Dutch Guilder *XCD- East Caribbean Dollar *DDM- East German Mark *ECS- Ecuadorian Sucre *ECV- Ecuadorian Unit of Constant Value *EGP- Egyptian Pound *GQE- Equatorial Guinean Ekwele *ERN- Eritrean Nakfa *EEK- Estonian Kroon *ETB- Ethiopian Birr *EUR- Euro *XBA- European Composite Unit *XEU- European Currency Unit *XBB- European Monetary Unit *XBC- European Unit of Account (XBC) *XBD- European Unit of Account (XBD) *FKP- Falkland Islands Pound *FJD- Fijian Dollar *FIM- Finnish Markka *FRF- French Franc *XFO- French Gold Franc *XFU- French UIC-Franc *GMD- Gambian Dalasi *GEK- Georgian Kupon Larit *GEL- Georgian Lari *DEM- German Mark *GHS- Ghanaian Cedi *GHC- Ghanaian Cedi (1979–2007) *GIP- Gibraltar Pound *XAU- Gold *GRD- Greek Drachma *GTQ- Guatemalan Quetzal *GWP- Guinea-Bissau Peso *GNF- Guinean Franc *GNS- Guinean Syli *GYD- Guyanaese Dollar *HTG- Haitian Gourde *HNL- Honduran Lempira *HKD- Hong Kong Dollar *HUF- Hungarian Forint *IMP- IMP *ISK- Icelandic Króna *ISJ- Icelandic Króna (1918–1981) *INR- Indian Rupee *IDR- Indonesian Rupiah *IRR- Iranian Rial *IQD- Iraqi Dinar *IEP- Irish Pound *ILS- Israeli New Shekel *ILP- Israeli Pound *ILR- Israeli Shekel (1980–1985) *ITL- Italian Lira *JMD- Jamaican Dollar *JPY- Japanese Yen *JOD- Jordanian Dinar *KZT- Kazakhstani Tenge *KES- Kenyan Shilling *KWD- Kuwaiti Dinar *KGS- Kyrgystani Som *LAK- Laotian Kip *LVL- Latvian Lats *LVR- Latvian Ruble *LBP- Lebanese Pound *LSL- Lesotho Loti *LRD- Liberian Dollar *LYD- Libyan Dinar *LTL- Lithuanian Litas *LTT- Lithuanian Talonas *LUL- Luxembourg Financial Franc *LUC- Luxembourgian Convertible Franc *LUF- Luxembourgian Franc *MOP- Macanese Pataca *MKD- Macedonian Denar *MKN- Macedonian Denar (1992–1993) *MGA- Malagasy Ariary *MGF- Malagasy Franc *MWK- Malawian Kwacha *MYR- Malaysian Ringgit *MVR- Maldivian Rufiyaa *MVP- Maldivian Rupee (1947–1981) *MLF- Malian Franc *MTL- Maltese Lira *MTP- Maltese Pound *MRU- Mauritanian Ouguiya *MRO- Mauritanian Ouguiya (1973–2017) *MUR- Mauritian Rupee *MXV- Mexican Investment Unit *MXN- Mexican Peso *MXP- Mexican Silver Peso (1861–1992) *MDC- Moldovan Cupon *MDL- Moldovan Leu *MCF- Monegasque Franc *MNT- Mongolian Tugrik *MAD- Moroccan Dirham *MAF- Moroccan Franc *MZE- Mozambican Escudo *MZN- Mozambican Metical *MZM- Mozambican Metical (1980–2006) *MMK- Myanmar Kyat *NAD- Namibian Dollar *NPR- Nepalese Rupee *ANG- Netherlands Antillean Guilder *TWD- New Taiwan Dollar *NZD- New Zealand Dollar *NIO- Nicaraguan Córdoba *NIC- Nicaraguan Córdoba (1988–1991) *NGN- Nigerian Naira *KPW- North Korean Won *NOK- Norwegian Krone *OMR- Omani Rial *PKR- Pakistani Rupee *XPD- Palladium *PAB- Panamanian Balboa *PGK- Papua New Guinean Kina *PYG- Paraguayan Guarani *PEI- Peruvian Inti *PEN- Peruvian Sol *PES- Peruvian Sol (1863–1965) *PHP- Philippine Peso *XPT- Platinum *PLN- Polish Zloty *PLZ- Polish Zloty (1950–1995) *PTE- Portuguese Escudo *GWE- Portuguese Guinea Escudo *QAR- Qatari Rial *XRE- RINET Funds *RHD- Rhodesian Dollar *RON- Romanian Leu *ROL- Romanian Leu (1952–2006) *RUB- Russian Ruble *RUR- Russian Ruble (1991–1998) *RWF- Rwandan Franc *SVC- Salvadoran Colón *WST- Samoan Tala *SAR- Saudi Riyal *RSD- Serbian Dinar *CSD- Serbian Dinar (2002–2006) *SCR- Seychellois Rupee *SLL- Sierra Leonean Leone *XAG- Silver *SGD- Singapore Dollar *SKK- Slovak Koruna *SIT- Slovenian Tolar *SBD- Solomon Islands Dollar *SOS- Somali Shilling *ZAR- South African Rand *ZAL- South African Rand (financial) *KRH- South Korean Hwan (1953–1962) *KRW- South Korean Won *KRO- South Korean Won (1945–1953) *SSP- South Sudanese Pound *SUR- Soviet Rouble *ESP- Spanish Peseta *ESA- Spanish Peseta (A account) *ESB- Spanish Peseta (convertible account) *XDR- Special Drawing Rights *LKR- Sri Lankan Rupee *SHP- St. -
#description ⇒ String
readonly
A brief description or purpose for the expense report.
-
#employee ⇒ String
readonly
Identifier for the employee who submitted or is associated with the expense report.
- #field_mappings ⇒ Hash{String => Object} readonly
- #id ⇒ String readonly
- #lines ⇒ Array<Merge::Accounting::ExpenseReportLine> readonly
-
#modified_at ⇒ DateTime
readonly
The datetime that this object was modified by Merge.
- #remote_data ⇒ Array<Merge::Accounting::RemoteData> readonly
- #remote_fields ⇒ Array<Merge::Accounting::RemoteField> readonly
-
#remote_id ⇒ String
readonly
The third-party API ID of the matching object.
-
#remote_was_deleted ⇒ Boolean
readonly
Indicates whether or not this object has been deleted in the third party platform.
-
#report_date ⇒ DateTime
readonly
The date of the expense report.
-
#report_identifier ⇒ String
readonly
Human-readable expense report identifier.
-
#status ⇒ Merge::Accounting::ExpenseReportStatusEnum
readonly
Overall status of the expense report.
-
#total_amount ⇒ Float
readonly
Total amount of the expense report.
-
#tracking_categories ⇒ Array<String>
readonly
The related tracking categories associated with the expense report.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseReport
Deserialize a JSON object to an instance of ExpenseReport.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, report_date: OMIT, report_identifier: OMIT, employee: OMIT, status: OMIT, total_amount: OMIT, lines: OMIT, currency: OMIT, description: OMIT, accounting_period: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseReport constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseReport to a JSON object.
Constructor Details
#initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, report_date: OMIT, report_identifier: OMIT, employee: OMIT, status: OMIT, total_amount: OMIT, lines: OMIT, currency: OMIT, description: OMIT, accounting_period: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) ⇒ Merge::Accounting::ExpenseReport
722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 722 def initialize(tracking_categories:, id: OMIT, remote_id: OMIT, created_at: OMIT, modified_at: OMIT, report_date: OMIT, report_identifier: OMIT, employee: OMIT, status: OMIT, total_amount: OMIT, lines: OMIT, currency: OMIT, description: OMIT, accounting_period: OMIT, company: OMIT, remote_was_deleted: OMIT, field_mappings: OMIT, remote_data: OMIT, remote_fields: OMIT, additional_properties: nil) @id = id if id != OMIT @remote_id = remote_id if remote_id != OMIT @created_at = created_at if created_at != OMIT @modified_at = modified_at if modified_at != OMIT @report_date = report_date if report_date != OMIT @report_identifier = report_identifier if report_identifier != OMIT @employee = employee if employee != OMIT @status = status if status != OMIT @total_amount = total_amount if total_amount != OMIT @lines = lines if lines != OMIT @currency = currency if currency != OMIT @description = description if description != OMIT @accounting_period = accounting_period if accounting_period != OMIT @company = company if company != OMIT @tracking_categories = tracking_categories @remote_was_deleted = remote_was_deleted if remote_was_deleted != OMIT @field_mappings = field_mappings if field_mappings != OMIT @remote_data = remote_data if remote_data != OMIT @remote_fields = remote_fields if remote_fields != OMIT @additional_properties = additional_properties @_field_set = { "id": id, "remote_id": remote_id, "created_at": created_at, "modified_at": modified_at, "report_date": report_date, "report_identifier": report_identifier, "employee": employee, "status": status, "total_amount": total_amount, "lines": lines, "currency": currency, "description": description, "accounting_period": accounting_period, "company": company, "tracking_categories": tracking_categories, "remote_was_deleted": remote_was_deleted, "field_mappings": field_mappings, "remote_data": remote_data, "remote_fields": remote_fields }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#accounting_period ⇒ String (readonly)
Returns The accounting period the report was posted in.
362 363 364 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 362 def accounting_period @accounting_period end |
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
379 380 381 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 379 def additional_properties @additional_properties end |
#company ⇒ Merge::Accounting::ExpenseReportCompany (readonly)
Returns The subsidiary that the expense report is created in.
364 365 366 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 364 def company @company end |
#created_at ⇒ DateTime (readonly)
Returns The datetime that this object was created by Merge.
30 31 32 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 30 def created_at @created_at end |
#currency ⇒ Merge::Accounting::TransactionCurrencyEnum (readonly)
Returns Currency code for the expense report
-
XUA- ADB Unit of Account -
AFN- Afghan Afghani -
AFA- Afghan Afghani (1927–2002) -
ALL- Albanian Lek -
ALK- Albanian Lek (1946–1965) -
DZD- Algerian Dinar -
ADP- Andorran Peseta -
AOA- Angolan Kwanza -
AOK- Angolan Kwanza (1977–1991) -
AON- Angolan New Kwanza (1990–2000) -
AOR- Angolan Readjusted Kwanza (1995–1999) -
ARA- Argentine Austral -
ARS- Argentine Peso -
ARM- Argentine Peso (1881–1970) -
ARP- Argentine Peso (1983–1985) -
ARL- Argentine Peso Ley (1970–1983) -
AMD- Armenian Dram -
AWG- Aruban Florin -
AUD- Australian Dollar -
ATS- Austrian Schilling -
AZN- Azerbaijani Manat -
AZM- Azerbaijani Manat (1993–2006) -
BSD- Bahamian Dollar -
BHD- Bahraini Dinar -
BDT- Bangladeshi Taka -
BBD- Barbadian Dollar -
BYN- Belarusian Ruble -
BYB- Belarusian Ruble (1994–1999) -
BYR- Belarusian Ruble (2000–2016) -
BEF- Belgian Franc -
BEC- Belgian Franc (convertible) -
BEL- Belgian Franc (financial) -
BZD- Belize Dollar -
BMD- Bermudan Dollar -
BTN- Bhutanese Ngultrum -
BOB- Bolivian Boliviano -
BOL- Bolivian Boliviano (1863–1963) -
BOV- Bolivian Mvdol -
BOP- Bolivian Peso -
BAM- Bosnia-Herzegovina Convertible Mark -
BAD- Bosnia-Herzegovina Dinar (1992–1994) -
BAN- Bosnia-Herzegovina New Dinar (1994–1997) -
BWP- Botswanan Pula -
BRC- Brazilian Cruzado (1986–1989) -
BRZ- Brazilian Cruzeiro (1942–1967) -
BRE- Brazilian Cruzeiro (1990–1993) -
BRR- Brazilian Cruzeiro (1993–1994) -
BRN- Brazilian New Cruzado (1989–1990) -
BRB- Brazilian New Cruzeiro (1967–1986) -
BRL- Brazilian Real -
GBP- British Pound -
BND- Brunei Dollar -
BGL- Bulgarian Hard Lev -
BGN- Bulgarian Lev -
BGO- Bulgarian Lev (1879–1952) -
BGM- Bulgarian Socialist Lev -
BUK- Burmese Kyat -
BIF- Burundian Franc -
XPF- CFP Franc -
KHR- Cambodian Riel -
CAD- Canadian Dollar -
CVE- Cape Verdean Escudo -
KYD- Cayman Islands Dollar -
XAF- Central African CFA Franc -
CLE- Chilean Escudo -
CLP- Chilean Peso -
CLF- Chilean Unit of Account (UF) -
CNX- Chinese People’s Bank Dollar -
CNY- Chinese Yuan -
CNH- Chinese Yuan (offshore) -
COP- Colombian Peso -
COU- Colombian Real Value Unit -
KMF- Comorian Franc -
CDF- Congolese Franc -
CRC- Costa Rican Colón -
HRD- Croatian Dinar -
HRK- Croatian Kuna -
CUC- Cuban Convertible Peso -
CUP- Cuban Peso -
CYP- Cypriot Pound -
CZK- Czech Koruna -
CSK- Czechoslovak Hard Koruna -
DKK- Danish Krone -
DJF- Djiboutian Franc -
DOP- Dominican Peso -
NLG- Dutch Guilder -
XCD- East Caribbean Dollar -
DDM- East German Mark -
ECS- Ecuadorian Sucre -
ECV- Ecuadorian Unit of Constant Value -
EGP- Egyptian Pound -
GQE- Equatorial Guinean Ekwele -
ERN- Eritrean Nakfa -
EEK- Estonian Kroon -
ETB- Ethiopian Birr -
EUR- Euro -
XBA- European Composite Unit -
XEU- European Currency Unit -
XBB- European Monetary Unit -
XBC- European Unit of Account (XBC) -
XBD- European Unit of Account (XBD) -
FKP- Falkland Islands Pound -
FJD- Fijian Dollar -
FIM- Finnish Markka -
FRF- French Franc -
XFO- French Gold Franc -
XFU- French UIC-Franc -
GMD- Gambian Dalasi -
GEK- Georgian Kupon Larit -
GEL- Georgian Lari -
DEM- German Mark -
GHS- Ghanaian Cedi -
GHC- Ghanaian Cedi (1979–2007) -
GIP- Gibraltar Pound -
XAU- Gold -
GRD- Greek Drachma -
GTQ- Guatemalan Quetzal -
GWP- Guinea-Bissau Peso -
GNF- Guinean Franc -
GNS- Guinean Syli -
GYD- Guyanaese Dollar -
HTG- Haitian Gourde -
HNL- Honduran Lempira -
HKD- Hong Kong Dollar -
HUF- Hungarian Forint -
IMP- IMP -
ISK- Icelandic Króna -
ISJ- Icelandic Króna (1918–1981) -
INR- Indian Rupee -
IDR- Indonesian Rupiah -
IRR- Iranian Rial -
IQD- Iraqi Dinar -
IEP- Irish Pound -
ILS- Israeli New Shekel -
ILP- Israeli Pound -
ILR- Israeli Shekel (1980–1985) -
ITL- Italian Lira -
JMD- Jamaican Dollar -
JPY- Japanese Yen -
JOD- Jordanian Dinar -
KZT- Kazakhstani Tenge -
KES- Kenyan Shilling -
KWD- Kuwaiti Dinar -
KGS- Kyrgystani Som -
LAK- Laotian Kip -
LVL- Latvian Lats -
LVR- Latvian Ruble -
LBP- Lebanese Pound -
LSL- Lesotho Loti -
LRD- Liberian Dollar -
LYD- Libyan Dinar -
LTL- Lithuanian Litas -
LTT- Lithuanian Talonas -
LUL- Luxembourg Financial Franc -
LUC- Luxembourgian Convertible Franc -
LUF- Luxembourgian Franc -
MOP- Macanese Pataca -
MKD- Macedonian Denar -
MKN- Macedonian Denar (1992–1993) -
MGA- Malagasy Ariary -
MGF- Malagasy Franc -
MWK- Malawian Kwacha -
MYR- Malaysian Ringgit -
MVR- Maldivian Rufiyaa -
MVP- Maldivian Rupee (1947–1981) -
MLF- Malian Franc -
MTL- Maltese Lira -
MTP- Maltese Pound -
MRU- Mauritanian Ouguiya -
MRO- Mauritanian Ouguiya (1973–2017) -
MUR- Mauritian Rupee -
MXV- Mexican Investment Unit -
MXN- Mexican Peso -
MXP- Mexican Silver Peso (1861–1992) -
MDC- Moldovan Cupon -
MDL- Moldovan Leu -
MCF- Monegasque Franc -
MNT- Mongolian Tugrik -
MAD- Moroccan Dirham -
MAF- Moroccan Franc -
MZE- Mozambican Escudo -
MZN- Mozambican Metical -
MZM- Mozambican Metical (1980–2006) -
MMK- Myanmar Kyat -
NAD- Namibian Dollar -
NPR- Nepalese Rupee -
ANG- Netherlands Antillean Guilder -
TWD- New Taiwan Dollar -
NZD- New Zealand Dollar -
NIO- Nicaraguan Córdoba -
NIC- Nicaraguan Córdoba (1988–1991) -
NGN- Nigerian Naira -
KPW- North Korean Won -
NOK- Norwegian Krone -
OMR- Omani Rial -
PKR- Pakistani Rupee -
XPD- Palladium -
PAB- Panamanian Balboa -
PGK- Papua New Guinean Kina -
PYG- Paraguayan Guarani -
PEI- Peruvian Inti -
PEN- Peruvian Sol -
PES- Peruvian Sol (1863–1965) -
PHP- Philippine Peso -
XPT- Platinum -
PLN- Polish Zloty -
PLZ- Polish Zloty (1950–1995) -
PTE- Portuguese Escudo -
GWE- Portuguese Guinea Escudo -
QAR- Qatari Rial -
XRE- RINET Funds -
RHD- Rhodesian Dollar -
RON- Romanian Leu -
ROL- Romanian Leu (1952–2006) -
RUB- Russian Ruble -
RUR- Russian Ruble (1991–1998) -
RWF- Rwandan Franc -
SVC- Salvadoran Colón -
WST- Samoan Tala -
SAR- Saudi Riyal -
RSD- Serbian Dinar -
CSD- Serbian Dinar (2002–2006) -
SCR- Seychellois Rupee -
SLL- Sierra Leonean Leone -
XAG- Silver -
SGD- Singapore Dollar -
SKK- Slovak Koruna -
SIT- Slovenian Tolar -
SBD- Solomon Islands Dollar -
SOS- Somali Shilling -
ZAR- South African Rand -
ZAL- South African Rand (financial) -
KRH- South Korean Hwan (1953–1962) -
KRW- South Korean Won -
KRO- South Korean Won (1945–1953) -
SSP- South Sudanese Pound -
SUR- Soviet Rouble -
ESP- Spanish Peseta -
ESA- Spanish Peseta (A account) -
ESB- Spanish Peseta (convertible account) -
XDR- Special Drawing Rights -
LKR- Sri Lankan Rupee -
SHP- St. Helena Pound -
XSU- Sucre -
SDD- Sudanese Dinar (1992–2007) -
SDG- Sudanese Pound -
SDP- Sudanese Pound (1957–1998) -
SRD- Surinamese Dollar -
SRG- Surinamese Guilder -
SZL- Swazi Lilangeni -
SEK- Swedish Krona -
CHF- Swiss Franc -
SYP- Syrian Pound -
STN- São Tomé & Príncipe Dobra -
STD- São Tomé & Príncipe Dobra (1977–2017) -
TVD- TVD -
TJR- Tajikistani Ruble -
TJS- Tajikistani Somoni -
TZS- Tanzanian Shilling -
XTS- Testing Currency Code -
THB- Thai Baht -
XXX- The codes assigned for transactions where no currency is involved -
TPE- Timorese Escudo -
TOP- Tongan Paʻanga -
TTD- Trinidad & Tobago Dollar -
TND- Tunisian Dinar -
TRY- Turkish Lira -
TRL- Turkish Lira (1922–2005) -
TMT- Turkmenistani Manat -
TMM- Turkmenistani Manat (1993–2009) -
USD- US Dollar -
USN- US Dollar (Next day) -
USS- US Dollar (Same day) -
UGX- Ugandan Shilling -
UGS- Ugandan Shilling (1966–1987) -
UAH- Ukrainian Hryvnia -
UAK- Ukrainian Karbovanets -
AED- United Arab Emirates Dirham -
UYW- Uruguayan Nominal Wage Index Unit -
UYU- Uruguayan Peso -
UYP- Uruguayan Peso (1975–1993) -
UYI- Uruguayan Peso (Indexed Units) -
UZS- Uzbekistani Som -
VUV- Vanuatu Vatu -
VES- Venezuelan Bolívar -
VEB- Venezuelan Bolívar (1871–2008) -
VEF- Venezuelan Bolívar (2008–2018) -
VND- Vietnamese Dong -
VNN- Vietnamese Dong (1978–1985) -
CHE- WIR Euro -
CHW- WIR Franc -
XOF- West African CFA Franc -
YDD- Yemeni Dinar -
YER- Yemeni Rial -
YUN- Yugoslavian Convertible Dinar (1990–1992) -
YUD- Yugoslavian Hard Dinar (1966–1990) -
YUM- Yugoslavian New Dinar (1994–2002) -
YUR- Yugoslavian Reformed Dinar (1992–1993) -
ZWN- ZWN -
ZRN- Zairean New Zaire (1993–1998) -
ZRZ- Zairean Zaire (1971–1993) -
ZMW- Zambian Kwacha -
ZMK- Zambian Kwacha (1968–2012) -
ZWD- Zimbabwean Dollar (1980–2008) -
ZWR- Zimbabwean Dollar (2008) -
ZWL- Zimbabwean Dollar (2009).
358 359 360 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 358 def currency @currency end |
#description ⇒ String (readonly)
Returns A brief description or purpose for the expense report.
360 361 362 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 360 def description @description end |
#employee ⇒ String (readonly)
Returns Identifier for the employee who submitted or is associated with the expense report.
39 40 41 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 39 def employee @employee end |
#field_mappings ⇒ Hash{String => Object} (readonly)
373 374 375 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 373 def field_mappings @field_mappings end |
#id ⇒ String (readonly)
26 27 28 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 26 def id @id end |
#lines ⇒ Array<Merge::Accounting::ExpenseReportLine> (readonly)
50 51 52 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 50 def lines @lines end |
#modified_at ⇒ DateTime (readonly)
Returns The datetime that this object was modified by Merge.
32 33 34 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 32 def modified_at @modified_at end |
#remote_data ⇒ Array<Merge::Accounting::RemoteData> (readonly)
375 376 377 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 375 def remote_data @remote_data end |
#remote_fields ⇒ Array<Merge::Accounting::RemoteField> (readonly)
377 378 379 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 377 def remote_fields @remote_fields end |
#remote_id ⇒ String (readonly)
Returns The third-party API ID of the matching object.
28 29 30 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 28 def remote_id @remote_id end |
#remote_was_deleted ⇒ Boolean (readonly)
Returns Indicates whether or not this object has been deleted in the third party platform. Full coverage deletion detection is a premium add-on. Native deletion detection is offered for free with limited coverage. [Learn more](docs.merge.dev/integrations/hris/supported-features/).
371 372 373 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 371 def remote_was_deleted @remote_was_deleted end |
#report_date ⇒ DateTime (readonly)
Returns The date of the expense report.
34 35 36 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 34 def report_date @report_date end |
#report_identifier ⇒ String (readonly)
Returns Human-readable expense report identifier.
36 37 38 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 36 def report_identifier @report_identifier end |
#status ⇒ Merge::Accounting::ExpenseReportStatusEnum (readonly)
Returns Overall status of the expense report. One of DRAFT, SUBMITTED, APPROVED, REJECTED
-
DRAFT- DRAFT -
SUBMITTED- SUBMITTED -
APPROVED- APPROVED -
REJECTED- REJECTED.
46 47 48 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 46 def status @status end |
#total_amount ⇒ Float (readonly)
Returns Total amount of the expense report.
48 49 50 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 48 def total_amount @total_amount end |
#tracking_categories ⇒ Array<String> (readonly)
Returns The related tracking categories associated with the expense report.
366 367 368 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 366 def tracking_categories @tracking_categories end |
Class Method Details
.from_json(json_object:) ⇒ Merge::Accounting::ExpenseReport
Deserialize a JSON object to an instance of ExpenseReport
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 773 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) id = parsed_json["id"] remote_id = parsed_json["remote_id"] created_at = (DateTime.parse(parsed_json["created_at"]) unless parsed_json["created_at"].nil?) modified_at = (DateTime.parse(parsed_json["modified_at"]) unless parsed_json["modified_at"].nil?) report_date = (DateTime.parse(parsed_json["report_date"]) unless parsed_json["report_date"].nil?) report_identifier = parsed_json["report_identifier"] employee = parsed_json["employee"] status = parsed_json["status"] total_amount = parsed_json["total_amount"] lines = parsed_json["lines"]&.map do |item| item = item.to_json Merge::Accounting::ExpenseReportLine.from_json(json_object: item) end currency = parsed_json["currency"] description = parsed_json["description"] accounting_period = parsed_json["accounting_period"] if parsed_json["company"].nil? company = nil else company = parsed_json["company"].to_json company = Merge::Accounting::ExpenseReportCompany.from_json(json_object: company) end tracking_categories = parsed_json["tracking_categories"] remote_was_deleted = parsed_json["remote_was_deleted"] field_mappings = parsed_json["field_mappings"] remote_data = parsed_json["remote_data"]&.map do |item| item = item.to_json Merge::Accounting::RemoteData.from_json(json_object: item) end remote_fields = parsed_json["remote_fields"]&.map do |item| item = item.to_json Merge::Accounting::RemoteField.from_json(json_object: item) end new( id: id, remote_id: remote_id, created_at: created_at, modified_at: modified_at, report_date: report_date, report_identifier: report_identifier, employee: employee, status: status, total_amount: total_amount, lines: lines, currency: currency, description: description, accounting_period: accounting_period, company: company, tracking_categories: tracking_categories, remote_was_deleted: remote_was_deleted, field_mappings: field_mappings, remote_data: remote_data, remote_fields: remote_fields, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 846 def self.validate_raw(obj:) obj.id&.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.remote_id&.is_a?(String) != false || raise("Passed value for field obj.remote_id is not the expected type, validation failed.") obj.created_at&.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.modified_at&.is_a?(DateTime) != false || raise("Passed value for field obj.modified_at is not the expected type, validation failed.") obj.report_date&.is_a?(DateTime) != false || raise("Passed value for field obj.report_date is not the expected type, validation failed.") obj.report_identifier&.is_a?(String) != false || raise("Passed value for field obj.report_identifier is not the expected type, validation failed.") obj.employee&.is_a?(String) != false || raise("Passed value for field obj.employee is not the expected type, validation failed.") obj.status&.is_a?(Merge::Accounting::ExpenseReportStatusEnum) != false || raise("Passed value for field obj.status is not the expected type, validation failed.") obj.total_amount&.is_a?(Float) != false || raise("Passed value for field obj.total_amount is not the expected type, validation failed.") obj.lines&.is_a?(Array) != false || raise("Passed value for field obj.lines is not the expected type, validation failed.") obj.currency&.is_a?(Merge::Accounting::TransactionCurrencyEnum) != false || raise("Passed value for field obj.currency is not the expected type, validation failed.") obj.description&.is_a?(String) != false || raise("Passed value for field obj.description is not the expected type, validation failed.") obj.accounting_period&.is_a?(String) != false || raise("Passed value for field obj.accounting_period is not the expected type, validation failed.") obj.company.nil? || Merge::Accounting::ExpenseReportCompany.validate_raw(obj: obj.company) obj.tracking_categories.is_a?(Array) != false || raise("Passed value for field obj.tracking_categories is not the expected type, validation failed.") obj.remote_was_deleted&.is_a?(Boolean) != false || raise("Passed value for field obj.remote_was_deleted is not the expected type, validation failed.") obj.field_mappings&.is_a?(Hash) != false || raise("Passed value for field obj.field_mappings is not the expected type, validation failed.") obj.remote_data&.is_a?(Array) != false || raise("Passed value for field obj.remote_data is not the expected type, validation failed.") obj.remote_fields&.is_a?(Array) != false || raise("Passed value for field obj.remote_fields is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ExpenseReport to a JSON object
836 837 838 |
# File 'lib/merge_ruby_client/accounting/types/expense_report.rb', line 836 def to_json(*_args) @_field_set&.to_json end |